@@ -2,11 +2,10 @@
  *
  * redland.h - Redland RDF Application Framework public API
  *
- * $Id: librdf.h,v 1.53 2005/05/20 15:04:50 cmdjb Exp $
+ * $Id: librdf.h 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -65,37 +64,177 @@ extern "C" {
 
 
 /* Public typedefs (references to private structures) */
+
+/**
+ * librdf_world:
+ *
+ * Redland world class.
+ */
 typedef struct librdf_world_s librdf_world;
+
+/**
+ * librdf_hash:
+ *
+ * Redland hash class.
+ */
 typedef struct librdf_hash_s librdf_hash;
+
+/**
+ * librdf_hash_cursor:
+ *
+ * Redland hash cursor class.
+ */
 typedef struct librdf_hash_cursor_s librdf_hash_cursor;
+
+/**
+ * librdf_digest:
+ *
+ * Redland content digest class.
+ */
 typedef struct librdf_digest_s librdf_digest;
+
+/**
+ * librdf_digest_factory:
+ *
+ * Redland digest factory class.
+ */
 typedef struct librdf_digest_factory_s librdf_digest_factory;
+
+/**
+ * librdf_uri:
+ *
+ * Redland URI class.
+ */
 typedef struct librdf_uri_s librdf_uri;
+
+/**
+ * librdf_list:
+ *
+ * Redland list class.
+ */
 typedef struct librdf_list_s librdf_list;
+
+/**
+ * librdf_iterator:
+ *
+ * Redland iterator class.
+ */
 typedef struct librdf_iterator_s librdf_iterator;
+
+/**
+ * librdf_node:
+ *
+ * Redland node class.
+ */
 typedef struct librdf_node_s librdf_node;
+
+/**
+ * librdf_statement:
+ *
+ * Redland statement class.
+ */
 typedef struct librdf_statement_s librdf_statement;
+
+/**
+ * librdf_model:
+ *
+ * Redland model class.
+ */
 typedef struct librdf_model_s librdf_model;
+
+/**
+ * librdf_model_factory:
+ *
+ * Redland model factory class.
+ */
 typedef struct librdf_model_factory_s librdf_model_factory;
+
+/**
+ * librdf_storage:
+ *
+ * Redland storage class.
+ */
 typedef struct librdf_storage_s librdf_storage;
+
+/**
+ * librdf_storage_factory:
+ *
+ * Redland storage factory class.
+ */
 typedef struct librdf_storage_factory_s librdf_storage_factory;
+
+/**
+ * librdf_stream:
+ *
+ * Redland stream class.
+ */
 typedef struct librdf_stream_s librdf_stream;
+
+/**
+ * librdf_parser:
+ *
+ * Redland parser class.
+ */
 typedef struct librdf_parser_s librdf_parser;
+
+/**
+ * librdf_parser_factory:
+ *
+ * Redland parser factory class.
+ */
 typedef struct librdf_parser_factory_s librdf_parser_factory;
+
+/**
+ * librdf_query:
+ *
+ * Redland query class.
+ */
 typedef struct librdf_query_s librdf_query;
+
+/**
+ * librdf_query_factory:
+ *
+ * Redland query factory class.
+ */
 typedef struct librdf_query_factory_s librdf_query_factory;
+
+/**
+ * librdf_query_results:
+ *
+ * Redland query results class.
+ */
 typedef struct librdf_query_results_s librdf_query_results;
+
+/**
+ * librdf_serializer:
+ *
+ * Redland serializer class.
+ */
 typedef struct librdf_serializer_s librdf_serializer;
+
+/**
+ * librdf_serializer_factory:
+ *
+ * Redland serializer factory class.
+ */
 typedef struct librdf_serializer_factory_s librdf_serializer_factory;
 
+
 /* Public statics */
-REDLAND_API extern const char * const librdf_short_copyright_string;
-REDLAND_API extern const char * const librdf_copyright_string;
-REDLAND_API extern const char * const librdf_version_string;
-REDLAND_API extern const unsigned int librdf_version_major;
-REDLAND_API extern const unsigned int librdf_version_minor;
-REDLAND_API extern const unsigned int librdf_version_release;
-REDLAND_API extern const unsigned int librdf_version_decimal;
+REDLAND_API
+extern const char * const librdf_short_copyright_string;
+REDLAND_API
+extern const char * const librdf_copyright_string;
+REDLAND_API
+extern const char * const librdf_version_string;
+REDLAND_API
+extern const unsigned int librdf_version_major;
+REDLAND_API
+extern const unsigned int librdf_version_minor;
+REDLAND_API
+extern const unsigned int librdf_version_release;
+REDLAND_API
+extern const unsigned int librdf_version_decimal;
 
 /* Required for va_list in error handler function registrations
  * which are in the public API
