@@ -2,11 +2,10 @@
  *
  * rdf_hash.c - RDF Hash interface - set of (key: value) pairs with dups
  *
- * $Id: rdf_hash.c,v 1.84 2005/05/23 14:17:42 cmdjb Exp $
+ * $Id: rdf_hash.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -47,10 +46,6 @@
 #include <redland.h>
 
 #include <rdf_hash.h>
-#ifdef HAVE_BDB_HASH
-#include <rdf_hash_bdb.h>
-#endif
-#include <rdf_hash_memory.h>
 #include <rdf_heuristics.h>
 
 #ifndef STANDALONE
@@ -78,7 +73,9 @@ static void librdf_hash_keys_iterator_finished(void* iterator);
 
 
 /**
- * librdf_init_hash - INTERNAL - Initialise the librdf_hash module
+ * librdf_init_hash:
+ *
+ * INTERNAL - Initialise the librdf_hash module.
  *
  * Initialises and registers all
  * compiled hash modules.  Must be called before using any of the hash
@@ -99,8 +96,11 @@ librdf_init_hash(librdf_world *world)
 
 
 /**
- * librdf_finish_hash - INTERNAL - Terminate the librdf_hash module
+ * librdf_finish_hash:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_hash module.
+ *
  **/
 void
 librdf_finish_hash(librdf_world *world) 
@@ -151,12 +151,14 @@ librdf_free_hash_datums(librdf_world *world)
 
 
 /**
- * librdf_new_hash_datum - Constructor - Create a new hash datum object
+ * librdf_new_hash_datum:
  * @world: redland world object
  * @data: data to store
  * @size: size of data
+ *
+ * Constructor - Create a new #librdf_hash_datum object.
  * 
- * Return value: New &librdf_hash_datum object or NULL on failure
+ * Return value: New #librdf_hash_datum object or NULL on failure
  **/
 librdf_hash_datum*
 librdf_new_hash_datum(librdf_world *world, void *data, size_t size)
@@ -181,8 +183,11 @@ librdf_new_hash_datum(librdf_world *world, void *data, size_t size)
 
 
 /**
- * librdf_free_hash_datum - Destructor - destroy a hash datum object
+ * librdf_free_hash_datum:
  * @datum: hash datum object
+ *
+ * Destructor - destroy a #librdf_hash_datum object.
+ *
  **/
 void
 librdf_free_hash_datum(librdf_hash_datum *datum) 
@@ -197,10 +202,12 @@ librdf_free_hash_datum(librdf_hash_datum *datum)
 /* class methods */
 
 /**
- * librdf_hash_register_factory - Register a hash factory
+ * librdf_hash_register_factory:
  * @world: redland world object
  * @name: the hash factory name
  * @factory: pointer to function to call to register the factory
+ *
+ * Register a hash factory.
  * 
  **/
 void
@@ -250,9 +257,11 @@ librdf_hash_register_factory(librdf_world *world, const char *name,
 
 
 /**
- * librdf_get_hash_factory - Get a hash factory by name
+ * librdf_get_hash_factory:
  * @world: redland world object
  * @name: the factory name or NULL for the default factory
+ *
+ * Get a hash factory by name.
  * 
  * FIXME: several bits of code assume the default hash factory is
  * in memory.
@@ -288,11 +297,13 @@ librdf_get_hash_factory(librdf_world *world, const char *name)
 
 
 /**
- * librdf_new_hash -  Constructor - create a new librdf_hash object
+ * librdf_new_hash:
  * @world: redland world object
  * @name: factory name
  *
- * Return value: a new &librdf_hash object or NULL on failure
+ * Constructor - create a new #librdf_hash object.
+ *
+ * Return value: a new #librdf_hash object or NULL on failure
  */
 librdf_hash*
 librdf_new_hash(librdf_world *world, const char* name)
@@ -308,11 +319,13 @@ librdf_new_hash(librdf_world *world, const char* name)
 
 
 /**
- * librdf_new_hash_from_factory -  Constructor - create a new librdf_hash object from a factory
+ * librdf_new_hash_from_factory:
  * @world: redland world object
  * @factory: the factory to use to construct the hash
  *
- * Return value: a new &librdf_hash object or NULL on failure
+ * Constructor - create a new #librdf_hash object from a factory.
+ *
+ * Return value: a new #librdf_hash object or NULL on failure
  */
 librdf_hash*
 librdf_new_hash_from_factory (librdf_world *world,
@@ -343,14 +356,16 @@ librdf_new_hash_from_factory (librdf_world *world,
 
 
 /**
- * librdf_new_hash_from_string -  Constructor - create a new librdf_hash object from a string
+ * librdf_new_hash_from_string:
  * @world: redland world object
  * @name: hash name
  * @string: hash encoded as a string
  * 
- * See &librdf_hash_from_string for the string format.
+ * Constructor - create a new #librdf_hash object from a string.
+ *
+ * See #librdf_hash_from_string for the string format.
  * 
- * Return value: a new &librdf_hash object or NULL on failure
+ * Return value: a new #librdf_hash object or NULL on failure
  */
 librdf_hash*
 librdf_new_hash_from_string(librdf_world *world, const char *name,
@@ -372,12 +387,14 @@ librdf_new_hash_from_string(librdf_world *world, const char *name,
 
 
 /**
- * librdf_new_hash_from_array_of_strings -  Constructor - create a new librdf_hash object from an array of strings
+ * librdf_new_hash_from_array_of_strings:
  * @world: redland world object
  * @name: hash name
  * @array: address of the start of the array of char* pointers
  *
- * Return value: a new &librdf_hash object or NULL on failure
+ * Constructor - create a new #librdf_hash object from an array of strings.
+ *
+ * Return value: a new #librdf_hash object or NULL on failure
  */
 librdf_hash*
 librdf_new_hash_from_array_of_strings(librdf_world *world, const char *name,
@@ -399,10 +416,12 @@ librdf_new_hash_from_array_of_strings(librdf_world *world, const char *name,
 
 
 /**
- * librdf_new_hash_from_hash -  Copy Constructor - create a new librdf_hash object from an existing one
+ * librdf_new_hash_from_hash:
  * @old_hash: the hash to use to construct the hash
  *
- * Return value: a new &librdf_hash object or NULL on failure
+ * Copy Constructor - create a new #librdf_hash object from an existing one.
+ *
+ * Return value: a new #librdf_hash object or NULL on failure
  */
 librdf_hash*
 librdf_new_hash_from_hash(librdf_hash* old_hash)
@@ -445,10 +464,11 @@ librdf_new_hash_from_hash(librdf_hash* old_hash)
 
 
 /**
- * librdf_free_hash - Destructor - destroy a librdf_hash object
- *
+ * librdf_free_hash:
  * @hash: hash object
- **/
+ *
+ * Destructor - destroy a #librdf_hash object.
+ */
 void
 librdf_free_hash(librdf_hash* hash) 
 {
@@ -465,13 +485,15 @@ librdf_free_hash(librdf_hash* hash)
 /* methods */
 
 /**
- * librdf_hash_open - Start a hash association 
+ * librdf_hash_open:
  * @hash: hash object
  * @identifier: indentifier for the hash factory - usually a URI or file name
  * @mode: hash access mode
  * @is_writable: is hash writable?
  * @is_new: is hash new?
  * @options: a hash of options for the hash factory or NULL if there are none.
+ *
+ * Start a hash association .
  * 
  * This method opens and/or creates a new hash with any resources it
  * needs.
@@ -501,8 +523,10 @@ librdf_hash_open(librdf_hash* hash, char *identifier,
 
 
 /**
- * librdf_hash_close - End a hash association
+ * librdf_hash_close:
  * @hash: hash object
+ *
+ * End a hash association.
  * 
  * Return value: non 0 on failure
  **/
@@ -519,8 +543,10 @@ librdf_hash_close(librdf_hash* hash)
 
 
 /**
- * librdf_hash_values_count - Get the number of values in the hash
+ * librdf_hash_values_count:
  * @hash: 
+ *
+ * Get the number of values in the hash.
  * 
  * Return value: integer number of values in the hash or <0 if cannot be determined
  **/
@@ -532,9 +558,11 @@ librdf_hash_values_count(librdf_hash* hash)
 
 
 /**
- * librdf_hash_get - Retrieve one value from hash for a given key as string
+ * librdf_hash_get:
  * @hash: hash object
  * @key: pointer to key
+ *
+ * Retrieve one value from hash for a given key as string.
  * 
  * The value returned is from newly allocated memory which the
  * caller must free.
@@ -574,9 +602,11 @@ librdf_hash_get(librdf_hash* hash, const char *key)
 
 
 /**
- * librdf_hash_get_one - Retrieve one value from hash for a given key
+ * librdf_hash_get_one:
  * @hash: hash object
  * @key: pointer to key
+ *
+ * Retrieve one value from hash for a given key.
  * 
  * The value returned is from newly allocated memory which the
  * caller must free.
@@ -641,15 +671,17 @@ typedef struct {
 
 
 /**
- * librdf_hash_get_all - Retrieve all values from hash for a given key
+ * librdf_hash_get_all:
  * @hash: hash object
  * @key: pointer to key
  * @value: pointer to value
+ *
+ * Retrieve all values from hash for a given key.
  * 
- * The iterator returns &librdf_hash_datum objects containing the values.
+ * The iterator returns #librdf_hash_datum objects containing the values.
  * These are newly allocated memory which the caller must free.
  * 
- * Return value: a &librdf_iterator serialization of all values or NULL on failure
+ * Return value: a #librdf_iterator serialization of all values or NULL on failure
  **/
 librdf_iterator*
 librdf_hash_get_all(librdf_hash* hash, 
@@ -761,7 +793,7 @@ librdf_hash_get_all_iterator_get_method(void* iterator, int flags)
     default:
       librdf_log(context->hash->world, 
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_HASH, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       result=NULL;
       break;
   }
@@ -788,9 +820,11 @@ librdf_hash_get_all_iterator_finished(void* iterator)
 
 
 /**
- * librdf_hash_get_del - Retrieve one value from hash for a given key as string and remove all values with that key
+ * librdf_hash_get_del:
  * @hash: hash object
  * @key: pointer to key
+ *
+ * Retrieve one value from hash for a given key as string and remove all values with that key.
  * 
  * The value returned is from newly allocated memory which the
  * caller must free.
@@ -818,10 +852,12 @@ librdf_hash_get_del(librdf_hash* hash, const char *key)
 
 
 /**
- * librdf_hash_put - Insert key/value pairs into the hash according to flags
+ * librdf_hash_put:
  * @hash: hash object
  * @key: key 
  * @value: value
+ *
+ * Insert key/value pairs into the hash according to flags.
  * 
  * The key and values are copied into the hash; the original pointers
  * can be deleted.
@@ -837,10 +873,12 @@ librdf_hash_put(librdf_hash* hash, librdf_hash_datum *key,
 
 
 /**
- * librdf_hash_exists - Check if a given key/value is in the hash
+ * librdf_hash_exists:
  * @hash: hash object
  * @key: key
  * @value: value
+ *
+ * Check if a given key/value is in the hash.
  * 
  * Return value: >0 if the key/value exists in the hash, 0 if not, <0 on failure
  **/
@@ -853,10 +891,12 @@ librdf_hash_exists(librdf_hash* hash, librdf_hash_datum *key,
 
 
 /**
- * librdf_hash_delete - Delete a key/value pair from the hash
+ * librdf_hash_delete:
  * @hash: hash object
  * @key: key
  * @value: value
+ *
+ * Delete a key/value pair from the hash.
  * 
  * Return value: non 0 on failure (including pair not present)
  **/
@@ -869,9 +909,11 @@ librdf_hash_delete(librdf_hash* hash, librdf_hash_datum *key,
 
 
 /**
- * librdf_hash_delete_all - Delete a key and all values from the hash
+ * librdf_hash_delete_all:
  * @hash: hash object
  * @key: key
+ *
+ * Delete a key and all values from the hash.
  * 
  * Return value: non 0 on failure (including pair not present)
  **/
@@ -894,14 +936,16 @@ typedef struct {
 
 
 /**
- * librdf_hash_keys - Get the hash keys
+ * librdf_hash_keys:
  * @hash: hash object
  * @key: pointer to key
+ *
+ * Get the hash keys.
  * 
- * The iterator returns &librdf_hash_datum objects containingvalue returned is from newly allocated memory which the
+ * The iterator returns #librdf_hash_datum objects containingvalue returned is from newly allocated memory which the
  * caller must free.
  * 
- * Return value: &librdf_iterator serialisation of keys or NULL on failure
+ * Return value: #librdf_iterator serialisation of keys or NULL on failure
  **/
 librdf_iterator*
 librdf_hash_keys(librdf_hash* hash, librdf_hash_datum *key)
@@ -1020,8 +1064,10 @@ librdf_hash_keys_iterator_finished(void* iterator)
 
 
 /**
- * librdf_hash_sync - Flush any cached information to disk if appropriate
+ * librdf_hash_sync:
  * @hash: hash object
+ *
+ * Flush any cached information to disk if appropriate.
  * 
  * Return value: non 0 on failure
  **/
@@ -1033,8 +1079,10 @@ librdf_hash_sync(librdf_hash* hash)
 
 
 /**
- * librdf_hash_get_fd - Get the file descriptor for the hash
+ * librdf_hash_get_fd:
  * @hash: hash object
+ *
+ * Get the file descriptor for the hash.
  * 
  * This returns the file descriptor if it is file based for
  * use with file locking.
@@ -1049,9 +1097,12 @@ librdf_hash_get_fd(librdf_hash* hash)
 
 
 /**
- * librdf_hash_print - pretty print the hash to a file descriptor
+ * librdf_hash_print:
  * @hash: the hash
  * @fh: file handle
+ *
+ * Pretty print the hash to a file descriptor.
+ *
  **/
 void
 librdf_hash_print(librdf_hash* hash, FILE *fh) 
@@ -1073,9 +1124,9 @@ librdf_hash_print(librdf_hash* hash, FILE *fh)
     v=(librdf_hash_datum *)librdf_iterator_get_value(iterator);
     
     fputs("  '", fh);
-    fwrite(k->data, k->size, 1, fh);
+    (void)fwrite(k->data, k->size, 1, fh);
     fputs("'=>'", fh);
-    fwrite(v->data, v->size, 1, fh);
+    (void)fwrite(v->data, v->size, 1, fh);
     fputs("'\n", fh);
 
     librdf_iterator_next(iterator);
@@ -1091,9 +1142,12 @@ librdf_hash_print(librdf_hash* hash, FILE *fh)
 
 
 /**
- * librdf_hash_print_keys - pretty print the keys to a file descriptor
+ * librdf_hash_print_keys:
  * @hash: the hash
  * @fh: file handle
+ *
+ * Pretty print the keys to a file descriptor.
+ *
  **/
 void
 librdf_hash_print_keys(librdf_hash* hash, FILE *fh) 
@@ -1110,7 +1164,7 @@ librdf_hash_print_keys(librdf_hash* hash, FILE *fh)
     librdf_hash_datum *k=(librdf_hash_datum *)librdf_iterator_get_key(iterator);
 
     fputs("  '", fh);
-    fwrite(k->data, k->size, 1, fh);
+    (void)fwrite(k->data, k->size, 1, fh);
     fputs("'\n", fh);
 
     librdf_iterator_next(iterator);
@@ -1125,10 +1179,13 @@ librdf_hash_print_keys(librdf_hash* hash, FILE *fh)
 
 
 /**
- * librdf_hash_print_values - pretty print the values of one key to a file descriptor
+ * librdf_hash_print_values:
  * @hash: the hash
  * @key_string: the key as a string
  * @fh: file handle
+ *
+ * Pretty print the values of one key to a file descriptor.
+ *
  **/
 void
 librdf_hash_print_values(librdf_hash* hash, char *key_string, FILE *fh)
@@ -1156,7 +1213,7 @@ librdf_hash_print_values(librdf_hash* hash, char *key_string, FILE *fh)
       fputs(", ", fh);
       
     fputc('\'', fh);
-    fwrite(v->data, v->size, 1, fh);
+    (void)fwrite(v->data, v->size, 1, fh);
     fputc('\'', fh);
     first=0;
     librdf_iterator_next(iterator);
@@ -1183,9 +1240,11 @@ typedef enum {
 
 
 /**
- * librdf_hash_from_string - Initialise a hash from a string
+ * librdf_hash_from_string:
  * @hash: hash object
  * @string: hash encoded as a string
+ *
+ * Initialise a hash from a string.
  * 
  * The string format is something like:
  * key1='value1',key2='value2', key3='\'quoted value\''
@@ -1374,9 +1433,11 @@ librdf_hash_from_string(librdf_hash* hash, const char *string)
 
 
 /**
- * librdf_hash_from_array_of_strings - Initialise a hash from an array of strings
+ * librdf_hash_from_array_of_strings:
  * @hash: hash object
  * @array: address of the start of the array of char* pointers
+ *
+ * Initialise a hash from an array of strings.
  * 
  * Return value:  non 0 on failure
  **/
@@ -1403,9 +1464,11 @@ librdf_hash_from_array_of_strings(librdf_hash* hash, const char **array)
 
 
 /**
- * librdf_hash_get_as_boolean - lookup a hash key and decode value as a boolean
- * @hash: &librdf_hash object
+ * librdf_hash_get_as_boolean:
+ * @hash: #librdf_hash object
  * @key: key string to look up
+ *
+ * Lookup a hash key and decode value as a boolean.
  * 
  * Return value: >0 (for true), 0 (for false) or <0 (for key not found or not known boolean value)
  **/
@@ -1447,9 +1510,11 @@ librdf_hash_get_as_boolean (librdf_hash* hash, const char *key)
 
 
 /**
- * librdf_hash_get_as_long - lookup a hash key and decode value as a long
- * @hash: &librdf_hash object
+ * librdf_hash_get_as_long:
+ * @hash: #librdf_hash object
  * @key: key string to look up
+ *
+ * Lookup a hash key and decode value as a long.
  * 
  * Return value: >0 (for success), <0 (for key not found or not known boolean value)
  **/
@@ -1477,10 +1542,12 @@ librdf_hash_get_as_long (librdf_hash* hash, const char *key)
 }
 
 /**
- * librdf_hash_put_strings - Insert key/value pairs into the hash as strings
+ * librdf_hash_put_strings:
  * @hash: hash object
  * @key: key 
  * @value: value
+ *
+ * Insert key/value pairs into the hash as strings.
  * 
  * The key and values are copied into the hash, no sharing i s done.
  * 
