@@ -2,11 +2,10 @@
  *
  * rdf_init.c - Redland library initialisation / termination
  *
- * $Id: rdf_init.c,v 1.65 2005/05/18 16:22:28 cmdjb Exp $
+ * $Id: rdf_init.c 10718 2006-03-28 07:26:14Z dajobe $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -55,25 +54,66 @@
 #endif
 
 #include <redland.h>
+/* for getpid */
+#include <sys/types.h>
+#ifdef HAVE_UNISTD
+#include <unistd.h>
+#endif
 
 
-const char * const librdf_short_copyright_string = "Copyright (C) 2000-2005 David Beckett, ILRT, University of Bristol";
 
-const char * const librdf_copyright_string = "Copyright (C) 2000-2005 David Beckett - http://purl.org/net/dajobe/\nInstitute for Learning and Research Technology - http://www.ilrt.bristol.ac.uk/,\nUniversity of Bristol - http://www.bristol.ac.uk/";
+const char * const librdf_short_copyright_string = "Copyright 2000-2006 David Beckett. Copyright 2000-2005 University of Bristol";
 
+const char * const librdf_copyright_string = "Copyright (C) 2000-2006 David Beckett - http://purl.org/net/dajobe/\nCopyright (C) 2000-2005 University of Bristol - http://www.bristol.ac.uk/";
+
+/**
+ * librdf_version_string:
+ *
+ * Library full version as a string.
+ *
+ * See also #librdf_version_decimal.
+ */
 const char * const librdf_version_string = VERSION;
 
+/**
+ * librdf_version_major:
+ *
+ * Library major version number as a decimal integer.
+ */
 const unsigned int librdf_version_major = LIBRDF_VERSION_MAJOR;
+
+/**
+ * librdf_version_minor:
+ *
+ * Library minor version number as a decimal integer.
+ */
 const unsigned int librdf_version_minor = LIBRDF_VERSION_MINOR;
+
+/**
+ * librdf_version_release:
+ *
+ * Library release version number as a decimal integer.
+ */
 const unsigned int librdf_version_release = LIBRDF_VERSION_RELEASE;
 
+/**
+ * librdf_version_decimal:
+ *
+ * Library full version as a decimal integer.
+ *
+ * See also #librdf_version_string.
+ */
 const unsigned int librdf_version_decimal = LIBRDF_VERSION_DECIMAL;
 
 
 
 
 /**
- * librdf_new_world - Creates a new Redland execution environment
+ * librdf_new_world:
+ *
+ * Create a new redland execution environment.
+ *
+ * Returns: a new #librdf_world or NULL on failure
  */
 librdf_world*
 librdf_new_world(void) {
@@ -99,10 +139,10 @@ librdf_new_world(void) {
 
 
 /**
- * librdf_free_world - Terminate the library
+ * librdf_free_world
  * @world: redland world object
- * 
- * Terminates and frees the resources.
+ *
+ * Terminate the library and frees all allocated resources.
  **/
 void
 librdf_free_world(librdf_world *world)
@@ -151,8 +191,10 @@ librdf_free_world(librdf_world *world)
 
 
 /**
- * librdf_world_init_mutex - INTERNAL - Create the world mutex
+ * librdf_world_init_mutex:
  * @world: redland world object
+ *
+ * INTERNAL - Create the world mutex.
  */
 void
 librdf_world_init_mutex(librdf_world* world)
@@ -172,9 +214,10 @@ librdf_world_init_mutex(librdf_world* world)
 
 
 /**
- * librdf_world_open - Open an environment
+ * librdf_world_open
  * @world: redland world object
- * 
+ *
+ * Open a created redland world environment.
  **/
 void
 librdf_world_open(librdf_world *world)
@@ -219,13 +262,16 @@ librdf_world_open(librdf_world *world)
 
 
 /**
- * librdf_world_set_error - Set the world error handling function
+ * librdf_world_set_error:
  * @world: redland world object
  * @user_data: user data to pass to function
  * @error_handler: pointer to the function
+ *
+ * Set the world error handling function.
  * 
  * The function will receive callbacks when the world fails.
- * 
+ * librdf_world_set_logger() provides richer access to all log messages
+ * and should be used in preference.
  **/
 void
 librdf_world_set_error(librdf_world* world, void *user_data,
@@ -237,13 +283,16 @@ librdf_world_set_error(librdf_world* world, void *user_data,
 
 
 /**
- * librdf_world_set_warning - Set the world warning handling function
+ * librdf_world_set_warning:
  * @world: redland world object
  * @user_data: user data to pass to function
  * @warning_handler: pointer to the function
+ *
+ * Set the world warning handling function.
  * 
  * The function will receive callbacks when the world gives a warning.
- * 
+ * librdf_world_set_logger() provides richer access to all log messages
+ * and should be used in preference.
  **/
 void
 librdf_world_set_warning(librdf_world* world, void *user_data,
@@ -256,13 +305,14 @@ librdf_world_set_warning(librdf_world* world, void *user_data,
 
 
 /**
- * librdf_world_set_logger - Set the world log handling function
+ * librdf_world_set_logger:
  * @world: redland world object
  * @user_data: user data to pass to function
  * @log_handler: pointer to the function
+ *
+ * Set the world log handling function.
  * 
  * The function will receive callbacks when redland generates a log message
- * 
  **/
 void
 librdf_world_set_logger(librdf_world* world, void *user_data,
@@ -275,13 +325,14 @@ librdf_world_set_logger(librdf_world* world, void *user_data,
 
 
 /**
- * librdf_world_set_digest - Set the default digest name
+ * librdf_world_set_digest:
  * @world: redland world object
  * @name: Digest factory name
  *
+ * Set the default content digest name.
+ *
  * Sets the digest factory for various modules that need to make
  * digests of their objects.
- * 
  */
 void
 librdf_world_set_digest(librdf_world* world, const char *name) {
@@ -290,11 +341,13 @@ librdf_world_set_digest(librdf_world* world, const char *name) {
 
 
 /**
- * librdf_world_get_feature - get the value of a world feature 
- * @world: &librdf_world object
- * @feature: &librdf_uri feature property
+ * librdf_world_get_feature:
+ * @world: #librdf_world object
+ * @feature: #librdf_uri feature property
  * 
- * Return value: new &librdf_node feature value or NULL if no such feature
+ * Get the value of a world feature.
+ *
+ * Return value: new #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 librdf_node*
@@ -305,10 +358,12 @@ librdf_world_get_feature(librdf_world* world, librdf_uri *feature)
 
 
 /**
- * librdf_world_set_feature - set the value of a world feature
- * @world: &librdf_world object
- * @feature: &librdf_uri feature property
- * @value: &librdf_node feature property value
+ * librdf_world_set_feature:
+ * @world: #librdf_world object
+ * @feature: #librdf_uri feature property
+ * @value: #librdf_node feature property value
+ *
+ * Set the value of a world feature.
  * 
  * Return value: non 0 on failure (negative if no such feature)
  **/
@@ -365,7 +420,7 @@ librdf_world_set_feature(librdf_world* world, librdf_uri* feature,
 unsigned char*
 librdf_world_get_genid(librdf_world* world)
 {
-  int id, tmpid, counter, tmpcounter;
+  int id, tmpid, counter, tmpcounter, pid, tmppid;
   int length;
   unsigned char *buffer;
 
@@ -380,18 +435,28 @@ librdf_world_get_genid(librdf_world* world)
   pthread_mutex_unlock(world->mutex);
 #endif
 
+  /* Add the process ID to the seed to differentiate between
+   * simultaneously executed child processes.
+   */
+  pid=(int) getpid();
+  if(!pid)
+    pid=1;
+  tmppid=pid;
 
-  length=5;  /* min length 1 + "r" + min length 1 + "r" \0 */
+
+  length=7;  /* min length 1 + "r" + min length 1 + "r" + min length 1 + "r" \0 */
   while(tmpid/=10)
     length++;
   while(tmpcounter/=10)
     length++;
+  while(tmppid/=10)
+    length++;
   
   buffer=(unsigned char*)LIBRDF_MALLOC(cstring, length);
   if(!buffer)
     return NULL;
 
-  sprintf((char*)buffer, "r%dr%d", id, counter);
+  sprintf((char*)buffer, "r%dr%dr%d", id, pid, counter);
   return buffer;
 }
 
@@ -403,14 +468,16 @@ librdf_world_get_genid(librdf_world* world)
 static librdf_world* RDF_World;
 
 /**
- * librdf_init_world - Initialise the library (DEPRECATED)
+ * librdf_init_world:
  * @digest_factory_name: Name of digest factory to use
  * @not_used2: Not used
  *
- * Use librdf_new_world and librdf_world_open on librdf_world object
+ * Initialise the library
+ * @deprecated: Do not use.
+ *
+ * Use librdf_new_world() and librdf_world_open() on #librdf_world object
  * 
- * See librdf_world_set_digest_factory_name and
- * librdf_world_set_uris_hash for documentation on arguments.
+ * See librdf_world_set_digest_factory_name() for documentation on arguments.
  **/
 void
 librdf_init_world(char *digest_factory_name, void* not_used2)
@@ -425,9 +492,12 @@ librdf_init_world(char *digest_factory_name, void* not_used2)
 
 
 /**
- * librdf_destroy_world - Terminate the library (DEPRECATED)
+ * librdf_destroy_world:
  *
- * Use librdf_free_world on librdf_world object
+ * Terminate the library
+ * @deprecated: Do not use.
+ *
+ * Use librdf_free_world() on #librdf_world object
  * 
  * Terminates and frees the resources.
  **/
