@@ -2,11 +2,10 @@
  *
  * rdf_list.c - RDF List Implementation
  *
- * $Id: rdf_list.c,v 1.29 2004/11/01 20:43:33 cmdjb Exp $
+ * $Id: rdf_list.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2000-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -72,10 +71,12 @@ librdf_list_find_node(librdf_list* list, void *data)
 
 
 /**
- * librdf_new_list - Constructor - create a new librdf_list
+ * librdf_new_list:
  * @world: redland world object
+ *
+ * Constructor - create a new #librdf_list.
  * 
- * Return value: a new &librdf_list or NULL on failure
+ * Return value: a new #librdf_list or NULL on failure
  **/
 librdf_list*
 librdf_new_list(librdf_world *world)
@@ -93,8 +94,10 @@ librdf_new_list(librdf_world *world)
 
 
 /**
- * librdf_free_list - Destructor - destroy a librdf_list object
- * @list: &librdf_list object
+ * librdf_free_list:
+ * @list: #librdf_list object
+ *
+ * Destructor - destroy a #librdf_list object.
  * 
  **/
 void
@@ -106,8 +109,10 @@ librdf_free_list(librdf_list* list)
 
 
 /**
- * librdf_list_clear - empty an librdf_list
- * @list: &librdf_list object
+ * librdf_list_clear:
+ * @list: #librdf_list object
+ *
+ * Empty an librdf_list.
  * 
  **/
 void
@@ -123,9 +128,11 @@ librdf_list_clear(librdf_list* list)
 
 
 /**
- * librdf_list_add - add a data item to the end of a librdf_list
- * @list: &librdf_list object
+ * librdf_list_add:
+ * @list: #librdf_list object
  * @data: the data value
+ *
+ * Add a data item to the end of a librdf_list.
  * 
  * Equivalent to the list 'push' notion, thus if librdf_list_pop()
  * is called after this, it will return the value added here.
@@ -166,9 +173,11 @@ librdf_list_add(librdf_list* list, void *data)
 
 
 /**
- * librdf_list_unshift - add a data item to the start of a librdf_list
- * @list: &librdf_list object
+ * librdf_list_unshift:
+ * @list: #librdf_list object
  * @data: the data value
+ *
+ * Add a data item to the start of a librdf_list.
  * 
  * if librdf_list_shift() is called after this, it will return the value
  * added here.
@@ -209,9 +218,11 @@ librdf_list_unshift(librdf_list* list, void *data)
 
 
 /**
- * librdf_list_remove - remove a data item from an librdf_list
- * @list: &librdf_list object
+ * librdf_list_remove:
+ * @list: #librdf_list object
  * @data: the data item
+ *
+ * Remove a data item from an librdf_list.
  * 
  * The search is done using the 'equals' function which may be set
  * by librdf_list_set_equals() or by straight comparison of pointers
@@ -251,8 +262,10 @@ librdf_list_remove(librdf_list* list, void *data)
 
 
 /**
- * librdf_list_shift - remove and return the data at the start of the list
- * @list: &librdf_list object
+ * librdf_list_shift:
+ * @list: #librdf_list object
+ *
+ * Remove and return the data at the start of the list.
  * 
  * Return value: the data object or NULL if the list is empty
  **/
@@ -287,8 +300,10 @@ librdf_list_shift(librdf_list* list)
 
 
 /**
- * librdf_list_pop - remove and return the data at the end of the list
- * @list: &librdf_list object
+ * librdf_list_pop:
+ * @list: #librdf_list object
+ *
+ * Remove and return the data at the end of the list.
  * 
  * Return value: the data object or NULL if the list is empty
  **/
@@ -323,9 +338,11 @@ librdf_list_pop(librdf_list* list)
 
 
 /**
- * librdf_list_contains - check for presence of data item in list
- * @list: &librdf_list object
+ * librdf_list_contains:
+ * @list: #librdf_list object
  * @data: the data value
+ *
+ * Check for presence of data item in list.
  * 
  * The search is done using the 'equals' function which may be set
  * by librdf_list_set_equals() or by straight comparison of pointers
@@ -344,8 +361,10 @@ librdf_list_contains(librdf_list* list, void *data)
 
 
 /**
- * librdf_list_size - return the length of the list
- * @list: &librdf_list object
+ * librdf_list_size:
+ * @list: #librdf_list object
+ *
+ * Return the length of the list.
  * 
  * Return value: length of the list
  **/
@@ -357,9 +376,11 @@ librdf_list_size(librdf_list* list)
 
 
 /**
- * librdf_list_set_equals - set the equals function for the list
- * @list: &librdf_list object
+ * librdf_list_set_equals:
+ * @list: #librdf_list object
  * @equals: the equals function
+ *
+ * Set the equals function for the list.
  * 
  * The function given is used when comparing items in the list
  * during searches such as those done in librdf_list_remove() or
@@ -382,10 +403,12 @@ typedef struct {
 
 
 /**
- * librdf_list_get_iterator - get an iterator for the list
- * @list: &librdf_list object
+ * librdf_list_get_iterator:
+ * @list: #librdf_list object
+ *
+ * Get an iterator for the list.
  * 
- * Return value: a new &librdf_iterator object or NULL on failure
+ * Return value: a new #librdf_iterator object or NULL on failure
  **/
 librdf_iterator*
 librdf_list_get_iterator(librdf_list* list)
@@ -447,7 +470,7 @@ librdf_list_iterator_get_method(void* iterator, int flags)
 
   librdf_log(context->list->world,
              0, LIBRDF_LOG_ERROR, LIBRDF_FROM_LIST, NULL,
-             "Unsupported iterator method flag %d\n", flags);
+             "Unsupported iterator method flag %d", flags);
   return NULL;
 }
 
@@ -461,10 +484,12 @@ librdf_list_iterator_finished(void* iterator)
 
 
 /**
- * librdf_list_foreach - apply a function for each data item in a librdf_list
- * @list: &librdf_list object
+ * librdf_list_foreach:
+ * @list: #librdf_list object
  * @fn: pointer to function to apply that takes data pointer and user data parameters
  * @user_data: user data for applied function 
+ *
+ * Apply a function for each data item in a librdf_list.
  * 
  **/
 void
