@@ -2,11 +2,10 @@
  *
  * rdf_model.c - RDF Graph (Model) interface
  *
- * $Id: rdf_model.c,v 1.105 2005/05/20 14:25:13 cmdjb Exp $
+ * $Id: rdf_model.c 8535 2006-01-26 05:02:23Z cmdjb $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, Copyright (C) 2000-2006, Copyright (C) 2000-2006, Copyright (C) 2000-2006, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -48,8 +47,11 @@ static void librdf_delete_model_factories(void);
 
 
 /**
- * librdf_init_model - INTERNAL - Initialise librdf_model class
+ * librdf_init_model:
  * @world: redland world object
+ *
+ * INTERNAL - Initialise librdf_model class.
+ *
  **/
 void
 librdf_init_model(librdf_world *world)
@@ -60,8 +62,11 @@ librdf_init_model(librdf_world *world)
 
 
 /**
- * librdf_finish_model - INTERNAL - Terminate librdf_model class
+ * librdf_finish_model:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate librdf_model class.
+ *
  **/
 void
 librdf_finish_model(librdf_world *world)
@@ -106,10 +111,12 @@ librdf_model_supports_contexts(librdf_model* model) {
 /* class methods */
 
 /**
- * librdf_model_register_factory - Register a model factory
+ * librdf_model_register_factory:
  * @world: redland world object
  * @name: the model factory name
  * @factory: pointer to function to call to register the factory
+ *
+ * Register a model factory.
  * 
  **/
 void
@@ -159,8 +166,10 @@ librdf_model_register_factory(librdf_world *world, const char *name,
 
 
 /**
- * librdf_get_model_factory - Get a model factory by name
+ * librdf_get_model_factory:
  * @name: the factory name or NULL for the default factory
+ *
+ * Get a model factory by name.
  * 
  * Return value: the factory object or NULL if there is no such factory
  **/
@@ -196,15 +205,17 @@ librdf_get_model_factory (const char *name)
 
 
 /**
- * librdf_new_model - Constructor - create a new storage librdf_model object
+ * librdf_new_model:
  * @world: redland world object
- * @storage: &librdf_storage to use
+ * @storage: #librdf_storage to use
  * @options_string: options to initialise model
  *
+ * Constructor - create a new storage #librdf_model object.
+ *
  * The options are encoded as described in librdf_hash_from_string()
  * and can be NULL if none are required.
  *
- * Return value: a new &librdf_model object or NULL on failure
+ * Return value: a new #librdf_model object or NULL on failure
  */
 librdf_model*
 librdf_new_model (librdf_world *world,
@@ -233,14 +244,16 @@ librdf_new_model (librdf_world *world,
 
 
 /**
- * librdf_new_model_with_options - Constructor - Create a new librdf_model with storage
+ * librdf_new_model_with_options:
  * @world: redland world object
- * @storage: &librdf_storage storage to use
- * @options: &librdf_hash of options to use
+ * @storage: #librdf_storage storage to use
+ * @options: #librdf_hash of options to use
  * 
+ * Constructor - Create a new #librdf_model with storage.
+ *
  * Options are presently not used.
  *
- * Return value: a new &librdf_model object or NULL on failure
+ * Return value: a new #librdf_model object or NULL on failure
  **/
 librdf_model*
 librdf_new_model_with_options(librdf_world *world,
@@ -291,13 +304,15 @@ librdf_new_model_with_options(librdf_world *world,
 
 
 /**
- * librdf_new_model_from_model - Copy constructor - create a new librdf_model from an existing one
- * @model: the existing &librdf_model
+ * librdf_new_model_from_model:
+ * @model: the existing #librdf_model
+ *
+ * Copy constructor - create a new librdf_model from an existing one.
  * 
  * Creates a new model as a copy of the existing model in the same
  * storage context.
  * 
- * Return value: a new &librdf_model or NULL on failure
+ * Return value: a new #librdf_model or NULL on failure
  **/
 librdf_model*
 librdf_new_model_from_model(librdf_model* model)
@@ -314,8 +329,10 @@ librdf_new_model_from_model(librdf_model* model)
 
 
 /**
- * librdf_free_model - Destructor - Destroy a librdf_model object
- * @model: &librdf_model model to destroy
+ * librdf_free_model:
+ * @model: #librdf_model model to destroy
+ *
+ * Destructor - Destroy a #librdf_model object.
  * 
  **/
 void
@@ -366,8 +383,10 @@ librdf_model_remove_reference(librdf_model *model)
 /* methods */
 
 /**
- * librdf_model_size - get the number of statements in the model
- * @model: &librdf_model object
+ * librdf_model_size:
+ * @model: #librdf_model object
+ *
+ * Get the number of statements in the model.
  * 
  * WARNING: Not all underlying stores can return the size of the graph
  * In which case the return value will be negative.
@@ -384,9 +403,11 @@ librdf_model_size(librdf_model* model)
 
 
 /**
- * librdf_model_add_statement - Add a statement to the model
+ * librdf_model_add_statement:
  * @model: model object
  * @statement: statement object
+ *
+ * Add a statement to the model.
  * 
  * The passed-in statement is copied when added to the model, not
  * shared with the model.  It must be a complete statement - all
@@ -394,7 +415,7 @@ librdf_model_size(librdf_model* model)
  *
  * If the statement already exists in the model, it is not added.
  * Duplicate statements can be added when used with Redland Contexts
- * such as with &librdf_model_context_add_statement
+ * such as with #librdf_model_context_add_statement
  *
  * Return value: non 0 on failure
  **/
@@ -416,13 +437,15 @@ librdf_model_add_statement(librdf_model* model, librdf_statement* statement)
 
 
 /**
- * librdf_model_add_statements - Add a stream of statements to the model
+ * librdf_model_add_statements:
  * @model: model object
  * @statement_stream: stream of statements to use
+ *
+ * Add a stream of statements to the model.
  * 
  * If any of the statements already exists in the store, they are not
  * added unless Redland contexts are being used.  See also
- * &librdf_model_context_add_statements
+ * #librdf_model_context_add_statements
  *
  * Return value: non 0 on failure
  **/
@@ -437,13 +460,15 @@ librdf_model_add_statements(librdf_model* model, librdf_stream* statement_stream
 
 
 /**
- * librdf_model_add - Create and add a new statement about a resource to the model
+ * librdf_model_add:
  * @model: model object
- * @subject: &librdf_node of subject
- * @predicate: &librdf_node of predicate
- * @object: &librdf_node of object (literal or resource)
+ * @subject: #librdf_node of subject
+ * @predicate: #librdf_node of predicate
+ * @object: #librdf_node of object (literal or resource)
+ *
+ * Create and add a new statement about a resource to the model.
  * 
- * After this method, the &librdf_node objects become owned by the model.
+ * After this method, the #librdf_node objects become owned by the model.
  * All of subject, predicate and object must be non-NULL.
  * 
  * Return value: non 0 on failure
@@ -479,15 +504,17 @@ librdf_model_add(librdf_model* model, librdf_node* subject,
 
 
 /**
- * librdf_model_add_typed_literal_statement - Create and add a new statement about a typed literal to the model
+ * librdf_model_add_typed_literal_statement:
  * @model: model object
- * @subject: &librdf_node of subject
- * @predicate: &librdf_node of predicate
+ * @subject: #librdf_node of subject
+ * @predicate: #librdf_node of predicate
  * @literal: string literal content
  * @xml_language: language of literal
- * @datatype_uri: datatype &librdf_uri
+ * @datatype_uri: datatype #librdf_uri
+ *
+ * Create and add a new statement about a typed literal to the model.
  * 
- * After this method, the &librdf_node subject and predicate become
+ * After this method, the #librdf_node subject and predicate become
  * owned by the model.
  * 
  * The language can be set to NULL if not used.
@@ -524,13 +551,15 @@ librdf_model_add_typed_literal_statement(librdf_model* model,
 
 
 /**
- * librdf_model_add_string_literal_statement - Create and add a new statement about a literal to the model
+ * librdf_model_add_string_literal_statement:
  * @model: model object
- * @subject: &librdf_node of subject
- * @predicate: &librdf_node of predicate
+ * @subject: #librdf_node of subject
+ * @predicate: #librdf_node of predicate
  * @literal: string literal conten
  * @xml_language: language of literal
  * @is_wf_xml: literal is XML
+ *
+ * Create and add a new statement about a literal to the model.
  * 
  * The language can be set to NULL if not used.
  * All of subject, predicate and literal must be non-NULL.
@@ -573,10 +602,12 @@ librdf_model_add_string_literal_statement(librdf_model* model,
 
 
 /**
- * librdf_model_remove_statement - Remove a known statement from the model
+ * librdf_model_remove_statement:
  * @model: the model object
  * @statement: the statement
  *
+ * Remove a known statement from the model.
+ *
  * It must be a complete statement - all of subject, predicate, object
  * parts must be present.
  *
@@ -596,9 +627,11 @@ librdf_model_remove_statement(librdf_model* model, librdf_statement* statement)
 
 
 /**
- * librdf_model_contains_statement - Check for a statement in the model
+ * librdf_model_contains_statement:
  * @model: the model object
  * @statement: the statement
+ *
+ * Check for a statement in the model.
  * 
  * It must be a complete statement - all of subject, predicate, object
  * parts must be present.  Use librdf_model_find_statements to search
@@ -625,10 +658,12 @@ librdf_model_contains_statement(librdf_model* model, librdf_statement* statement
 
 
 /**
- * librdf_model_as_stream - list the model contents as a stream of statements
+ * librdf_model_as_stream:
  * @model: the model object
+ *
+ * List the model contents as a stream of statements.
  * 
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 librdf_stream*
 librdf_model_as_stream(librdf_model* model)
@@ -640,13 +675,15 @@ librdf_model_as_stream(librdf_model* model)
 
 
 /**
- * librdf_model_serialise - serialise the entire model as a stream (DEPRECATED)
+ * librdf_model_serialise:
  * @model: the model object
+ *
+ * Serialise the entire model as a stream (DEPRECATED).
  * 
  * DEPRECATED to reduce confusion with the librdf_serializer class.
  * Please use librdf_model_as_stream.
  *
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 librdf_stream*
 librdf_model_serialise(librdf_model* model)
@@ -658,15 +695,17 @@ librdf_model_serialise(librdf_model* model)
 
 
 /**
- * librdf_model_find_statements - find matching statements in the model
+ * librdf_model_find_statements:
  * @model: the model object
  * @statement: the partial statement to match
+ *
+ * Find matching statements in the model.
  * 
  * The partial statement is a statement where the subject, predicate
  * and/or object can take the value NULL which indicates a match with
  * any value in the model
  * 
- * Return value: a &librdf_stream of statements (can be empty) or NULL
+ * Return value: a #librdf_stream of statements (can be empty) or NULL
  * on failure.
  **/
 librdf_stream*
@@ -681,15 +720,17 @@ librdf_model_find_statements(librdf_model* model,
 
 
 /**
- * librdf_model_get_sources - return the sources (subjects) of arc in an RDF graph given arc (predicate) and target (object)
- * @model: &librdf_model object
- * @arc: &librdf_node arc
- * @target: &librdf_node target
+ * librdf_model_get_sources:
+ * @model: #librdf_model object
+ * @arc: #librdf_node arc
+ * @target: #librdf_node target
+ *
+ * Return the sources (subjects) of arc in an RDF graph given arc (predicate) and target (object).
  * 
  * Searches the model for arcs matching the given arc and target
- * and returns a list of the source &librdf_node objects as an iterator
+ * and returns a list of the source #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_model_get_sources(librdf_model *model,
@@ -704,15 +745,17 @@ librdf_model_get_sources(librdf_model *model,
 
 
 /**
- * librdf_model_get_arcs - return the arcs (predicates) of an arc in an RDF graph given source (subject) and target (object)
- * @model: &librdf_model object
- * @source: &librdf_node source
- * @target: &librdf_node target
+ * librdf_model_get_arcs:
+ * @model: #librdf_model object
+ * @source: #librdf_node source
+ * @target: #librdf_node target
+ *
+ * Return the arcs (predicates) of an arc in an RDF graph given source (subject) and target (object).
  * 
  * Searches the model for arcs matching the given source and target
- * and returns a list of the arc &librdf_node objects as an iterator
+ * and returns a list of the arc #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_model_get_arcs(librdf_model *model,
@@ -727,15 +770,17 @@ librdf_model_get_arcs(librdf_model *model,
 
 
 /**
- * librdf_model_get_targets - return the targets (objects) of an arc in an RDF graph given source (subject) and arc (predicate)
- * @model: &librdf_model object
- * @source: &librdf_node source
- * @arc: &librdf_node arc
+ * librdf_model_get_targets:
+ * @model: #librdf_model object
+ * @source: #librdf_node source
+ * @arc: #librdf_node arc
+ *
+ * Return the targets (objects) of an arc in an RDF graph given source (subject) and arc (predicate).
  * 
  * Searches the model for targets matching the given source and arc
- * and returns a list of the source &librdf_node objects as an iterator
+ * and returns a list of the source #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_model_get_targets(librdf_model *model,
@@ -750,15 +795,17 @@ librdf_model_get_targets(librdf_model *model,
 
 
 /**
- * librdf_model_get_source - return one source (subject) of arc in an RDF graph given arc (predicate) and target (object)
- * @model: &librdf_model object
- * @arc: &librdf_node arc
- * @target: &librdf_node target
+ * librdf_model_get_source:
+ * @model: #librdf_model object
+ * @arc: #librdf_node arc
+ * @target: #librdf_node target
+ *
+ * Return one source (subject) of arc in an RDF graph given arc (predicate) and target (object).
  * 
  * Searches the model for arcs matching the given arc and target
- * and returns one &librdf_node object
+ * and returns one #librdf_node object
  * 
- * Return value:  a new &librdf_node object or NULL on failure
+ * Return value:  a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_model_get_source(librdf_model *model,
@@ -784,15 +831,17 @@ librdf_model_get_source(librdf_model *model,
 
 
 /**
- * librdf_model_get_arc - return one arc (predicate) of an arc in an RDF graph given source (subject) and target (object)
- * @model: &librdf_model object
- * @source: &librdf_node source
- * @target: &librdf_node target
+ * librdf_model_get_arc:
+ * @model: #librdf_model object
+ * @source: #librdf_node source
+ * @target: #librdf_node target
+ *
+ * Return one arc (predicate) of an arc in an RDF graph given source (subject) and target (object).
  * 
  * Searches the model for arcs matching the given source and target
- * and returns one &librdf_node object
+ * and returns one #librdf_node object
  * 
- * Return value:  a new &librdf_node object or NULL on failure
+ * Return value:  a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_model_get_arc(librdf_model *model,
@@ -818,15 +867,17 @@ librdf_model_get_arc(librdf_model *model,
 
 
 /**
- * librdf_model_get_target - return one target (object) of an arc in an RDF graph given source (subject) and arc (predicate)
- * @model: &librdf_model object
- * @source: &librdf_node source
- * @arc: &librdf_node arc
+ * librdf_model_get_target:
+ * @model: #librdf_model object
+ * @source: #librdf_node source
+ * @arc: #librdf_node arc
+ *
+ * Return one target (object) of an arc in an RDF graph given source (subject) and arc (predicate).
  * 
  * Searches the model for targets matching the given source and arc
- * and returns one &librdf_node object
+ * and returns one #librdf_node object
  * 
- * Return value:  a new &librdf_node object or NULL on failure
+ * Return value:  a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_model_get_target(librdf_model *model,
@@ -852,9 +903,11 @@ librdf_model_get_target(librdf_model *model,
 
 
 /**
- * librdf_model_add_submodel - add a sub-model to the model
+ * librdf_model_add_submodel:
  * @model: the model object
  * @sub_model: the sub model to add
+ *
+ * Add a sub-model to the model.
  * 
  * FIXME: Not tested
  * 
@@ -884,9 +937,11 @@ librdf_model_add_submodel(librdf_model* model, librdf_model* sub_model)
 
 
 /**
- * librdf_model_remove_submodel - remove a sub-model from the model
+ * librdf_model_remove_submodel:
  * @model: the model object
  * @sub_model: the sub model to remove
+ *
+ * Remove a sub-model from the model.
  * 
  * FIXME: Not tested
  * 
@@ -911,11 +966,13 @@ librdf_model_remove_submodel(librdf_model* model, librdf_model* sub_model)
 
 
 /**
- * librdf_model_get_arcs_in - return the properties pointing to the given resource
- * @model: &librdf_model object
- * @node: &librdf_node resource node
+ * librdf_model_get_arcs_in:
+ * @model: #librdf_model object
+ * @node: #librdf_node resource node
+ *
+ * Return the properties pointing to the given resource.
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_model_get_arcs_in(librdf_model *model, librdf_node *node) 
@@ -928,11 +985,13 @@ librdf_model_get_arcs_in(librdf_model *model, librdf_node *node)
 
 
 /**
- * librdf_model_get_arcs_out - return the properties pointing from the given resource
- * @model: &librdf_model object
- * @node: &librdf_node resource node
+ * librdf_model_get_arcs_out:
+ * @model: #librdf_model object
+ * @node: #librdf_node resource node
+ *
+ * Return the properties pointing from the given resource.
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_model_get_arcs_out(librdf_model *model, librdf_node *node) 
@@ -945,10 +1004,12 @@ librdf_model_get_arcs_out(librdf_model *model, librdf_node *node)
 
 
 /**
- * librdf_model_has_arc_in - check if a node has a given property pointing to it
- * @model: &librdf_model object
- * @node: &librdf_node resource node
- * @property: &librdf_node property node
+ * librdf_model_has_arc_in:
+ * @model: #librdf_model object
+ * @node: #librdf_node resource node
+ * @property: #librdf_node property node
+ *
+ * Check if a node has a given property pointing to it.
  * 
  * Return value: non 0 if arc property does point to the resource node
  **/
@@ -965,10 +1026,12 @@ librdf_model_has_arc_in(librdf_model *model, librdf_node *node,
 
 
 /**
- * librdf_model_has_arc_out - check if a node has a given property pointing from it
- * @model: &librdf_model object
- * @node: &librdf_node resource node
- * @property: &librdf_node property node
+ * librdf_model_has_arc_out:
+ * @model: #librdf_model object
+ * @node: #librdf_node resource node
+ * @property: #librdf_node property node
+ *
+ * Check if a node has a given property pointing from it.
  * 
  * Return value: non 0 if arc property does point from the resource node
  **/
@@ -987,9 +1050,11 @@ librdf_model_has_arc_out(librdf_model *model, librdf_node *node,
 
 
 /**
- * librdf_model_print - print the model
+ * librdf_model_print:
  * @model: the model object
  * @fh: the FILE stream to print to
+ *
+ * Print the model.
  * 
  * This method is for debugging and the format of the output should
  * not be relied on.
@@ -1013,10 +1078,12 @@ librdf_model_print(librdf_model *model, FILE *fh)
 
 
 /**
- * librdf_model_context_add_statement - Add a statement to a model with a context
- * @model: &librdf_model object
- * @context: &librdf_node context
- * @statement: &librdf_statement statement object
+ * librdf_model_context_add_statement:
+ * @model: #librdf_model object
+ * @context: #librdf_node context
+ * @statement: #librdf_statement statement object
+ *
+ * Add a statement to a model with a context.
  * 
  * It must be a complete statement - all
  * of subject, predicate, object parts must be present.
@@ -1048,10 +1115,12 @@ librdf_model_context_add_statement(librdf_model* model,
 
 
 /**
- * librdf_model_context_add_statements - Add statements to a model with a context
- * @model: &librdf_model object
- * @context: &librdf_node context
- * @stream: &librdf_stream stream object
+ * librdf_model_context_add_statements:
+ * @model: #librdf_model object
+ * @context: #librdf_node context
+ * @stream: #librdf_stream stream object
+ *
+ * Add statements to a model with a context.
  * 
  * If @context is NULL, this is equivalent to librdf_model_add_statements
  *
@@ -1095,10 +1164,12 @@ librdf_model_context_add_statements(librdf_model* model,
 
 
 /**
- * librdf_model_context_remove_statement - Remove a statement from a model in a context
- * @model: &librdf_model object
- * @context: &librdf_uri context
- * @statement: &librdf_statement statement
+ * librdf_model_context_remove_statement:
+ * @model: #librdf_model object
+ * @context: #librdf_uri context
+ * @statement: #librdf_statement statement
+ *
+ * Remove a statement from a model in a context.
  * 
  * It must be a complete statement - all of subject, predicate, object
  * parts must be present.
@@ -1129,9 +1200,11 @@ librdf_model_context_remove_statement(librdf_model* model,
 
 
 /**
- * librdf_model_context_remove_statements - Remove statements from a model with the given context
- * @model: &librdf_model object
- * @context: &librdf_uri context
+ * librdf_model_context_remove_statements:
+ * @model: #librdf_model object
+ * @context: #librdf_uri context
+ *
+ * Remove statements from a model with the given context.
  * 
  * Return value: Non 0 on failure
  **/
@@ -1170,11 +1243,13 @@ librdf_model_context_remove_statements(librdf_model* model,
 
 
 /**
- * librdf_model_context_as_stream - list all statements in a model context
- * @model: &librdf_model object
- * @context: &librdf_uri context
+ * librdf_model_context_as_stream:
+ * @model: #librdf_model object
+ * @context: #librdf_uri context
+ *
+ * List all statements in a model context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure
+ * Return value: #librdf_stream of statements or NULL on failure
  **/
 librdf_stream*
 librdf_model_context_as_stream(librdf_model* model, librdf_node* context) 
@@ -1193,14 +1268,16 @@ librdf_model_context_as_stream(librdf_model* model, librdf_node* context)
 
 
 /**
- * librdf_model_context_serialize - List all statements in a model context
- * @model: &librdf_model object
- * @context: &librdf_uri context
+ * librdf_model_context_serialize:
+ * @model: #librdf_model object
+ * @context: #librdf_uri context
+ *
+ * List all statements in a model context.
  * 
  * DEPRECATED to reduce confusion with the librdf_serializer class.
  * Please use librdf_model_context_as_stream.
  *
- * Return value: &librdf_stream of statements or NULL on failure
+ * Return value: #librdf_stream of statements or NULL on failure
  **/
 librdf_stream*
 librdf_model_context_serialize(librdf_model* model, librdf_node* context) 
@@ -1219,14 +1296,16 @@ librdf_model_context_serialize(librdf_model* model, librdf_node* context)
 
 
 /**
- * librdf_model_query_execute - Execute a query against the model
- * @model: &librdf_model object
- * @query: &librdf_query object
+ * librdf_model_query_execute:
+ * @model: #librdf_model object
+ * @query: #librdf_query object
+ *
+ * Execute a query against the model.
  * 
- * Run the given query against the model and return a &librdf_stream of
- * matching &librdf_statement objects
+ * Run the given query against the model and return a #librdf_stream of
+ * matching #librdf_statement objects
  * 
- * Return value: &librdf_query_results or NULL on failure
+ * Return value: #librdf_query_results or NULL on failure
  **/
 librdf_query_results*
 librdf_model_query_execute(librdf_model* model, librdf_query* query) 
@@ -1239,8 +1318,10 @@ librdf_model_query_execute(librdf_model* model, librdf_query* query)
 
 
 /**
- * librdf_model_sync - Synchronise the model to the model implementation
- * @model: &librdf_model object
+ * librdf_model_sync:
+ * @model: #librdf_model object
+ *
+ * Synchronise the model to the model implementation.
  * 
  * Return value: non-0 on failure
  **/
@@ -1257,14 +1338,16 @@ librdf_model_sync(librdf_model* model)
 
 
 /**
- * librdf_model_get_storage - return the storage of this model
- * @model: &librdf_model object
+ * librdf_model_get_storage:
+ * @model: #librdf_model object
+ *
+ * Return the storage of this model.
  * 
  * Note: this can only return one storage, so model implementations
- * that have multiple &librdf_storage internally may chose not to
+ * that have multiple #librdf_storage internally may chose not to
  * implement this.
  *
- * Return value:  &librdf_storage or NULL if this has no store
+ * Return value:  #librdf_storage or NULL if this has no store
  **/
 librdf_storage*
 librdf_model_get_storage(librdf_model *model)
@@ -1279,17 +1362,19 @@ librdf_model_get_storage(librdf_model *model)
 
 
 /**
- * librdf_model_find_statements_in_context - search the model for matching statements in a given context
- * @model: &librdf_model object
- * @statement: &librdf_statement partial statement to find
- * @context_node: context &librdf_node (or NULL)
+ * librdf_model_find_statements_in_context:
+ * @model: #librdf_model object
+ * @statement: #librdf_statement partial statement to find
+ * @context_node: context #librdf_node (or NULL)
+ *
+ * Search the model for matching statements in a given context.
  * 
  * Searches the model for a (partial) statement as described in
  * librdf_statement_match() in the given context and returns a
- * &librdf_stream of matching &librdf_statement objects.  If
+ * #librdf_stream of matching #librdf_statement objects.  If
  * context is NULL, this is equivalent to librdf_model_find_statements.
  * 
- * Return value: &librdf_stream of matching statements (may be empty) or NULL on failure
+ * Return value: #librdf_stream of matching statements (may be empty) or NULL on failure
  **/
 librdf_stream*
 librdf_model_find_statements_in_context(librdf_model* model, librdf_statement* statement, librdf_node* context_node) 
@@ -1327,13 +1412,15 @@ librdf_model_find_statements_in_context(librdf_model* model, librdf_statement* s
 
 
 /**
- * librdf_model_get_contexts - return the list of contexts in the graph
- * @model: &librdf_model object
+ * librdf_model_get_contexts:
+ * @model: #librdf_model object
+ *
+ * Return the list of contexts in the graph.
  * 
- * Returns an iterator of &librdf_node context nodes for each
+ * Returns an iterator of #librdf_node context nodes for each
  * context in the graph.
  *
- * Return value: &librdf_iterator of context nodes or NULL on failure or if contexts are not supported
+ * Return value: #librdf_iterator of context nodes or NULL on failure or if contexts are not supported
  **/
 librdf_iterator*
 librdf_model_get_contexts(librdf_model* model) 
@@ -1354,11 +1441,13 @@ librdf_model_get_contexts(librdf_model* model)
 
 
 /**
- * librdf_model_get_feature - get the value of a graph feature 
- * @model: &librdf_model object
- * @feature: &librdf_uri feature property
+ * librdf_model_get_feature:
+ * @model: #librdf_model object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a graph feature .
  * 
- * Return value: new &librdf_node feature value or NULL if no such feature
+ * Return value: new #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 librdf_node*
@@ -1374,10 +1463,12 @@ librdf_model_get_feature(librdf_model* model, librdf_uri* feature)
 
 
 /**
- * librdf_model_set_feature - set the value of a graph feature
- * @model: &librdf_model object
- * @feature: &librdf_uri feature property
- * @value: &librdf_node feature property value
+ * librdf_model_set_feature:
+ * @model: #librdf_model object
+ * @feature: #librdf_uri feature property
+ * @value: #librdf_node feature property value
+ *
+ * Set the value of a graph feature.
  * 
  * Return value: non 0 on failure (negative if no such feature)
  **/
@@ -1396,21 +1487,23 @@ librdf_model_set_feature(librdf_model* model, librdf_uri* feature,
 
 
 /**
- * librdf_model_find_statements_with_options - search the model for matching statements with match options
- * @model: &librdf_model object
- * @statement: &librdf_statement partial statement to find
- * @context_node: &librdf_node context node or NULL.
- * @options: &librdf_hash of matching options or NULL
+ * librdf_model_find_statements_with_options:
+ * @model: #librdf_model object
+ * @statement: #librdf_statement partial statement to find
+ * @context_node: #librdf_node context node or NULL.
+ * @options: #librdf_hash of matching options or NULL
+ *
+ * Search the model for matching statements with match options.
  * 
  * Searches the model for a (partial) statement as described in
- * librdf_statement_match() and returns a &librdf_stream of
- * matching &librdf_statement objects.
+ * librdf_statement_match() and returns a #librdf_stream of
+ * matching #librdf_statement objects.
  * 
  * If options is given then the match is made according to
  * the given options.  If options is NULL, this is equivalent
  * to librdf_model_find_statements_in_context.
  * 
- * Return value:  &librdf_stream of matching statements (may be empty) or NULL on failure
+ * Return value:  #librdf_stream of matching statements (may be empty) or NULL on failure
  **/
 librdf_stream*
 librdf_model_find_statements_with_options(librdf_model* model,
@@ -1432,13 +1525,15 @@ librdf_model_find_statements_with_options(librdf_model* model,
 
 
 /**
- * librdf_model_load - Load content from a URI into the model
- * @model: &librdf_model object
+ * librdf_model_load:
+ * @model: #librdf_model object
  * @uri: the URI to read the content
  * @name: the name of the parser (or NULL)
  * @mime_type: the MIME type of the syntax (NULL if not used)
  * @type_uri: URI identifying the syntax (NULL if not used)
  *
+ * Load content from a URI into the model.
+ *
  * If the name field is NULL, the library will try to guess
  * the parser to use from the uri, mime_type and type_uri fields.
  * This is done via the raptor_guess_parser_name function.
@@ -1472,14 +1567,16 @@ librdf_model_load(librdf_model* model, librdf_uri *uri,
 
 
 /**
- * librdf_model_to_counted_string - Write serialized model to a string
- * @model: &librdf_model object
+ * librdf_model_to_counted_string:
+ * @model: #librdf_model object
  * @uri: base URI to use in serializing (or NULL if not used)
  * @name: the name of the serializer (or NULL for default)
  * @mime_type: the MIME type of the syntax (NULL if not used)
  * @type_uri: URI identifying the syntax (NULL if not used)
  * @string_length_p: pointer to location to store string length (or NULL)
  *
+ * Write serialized model to a string.
+ *
  * If the name field is NULL, the default serializer will be used.
  *
  * Note: the returned string must be freed by the caller.
@@ -1512,13 +1609,15 @@ librdf_model_to_counted_string(librdf_model* model, librdf_uri *uri,
 
 
 /**
- * librdf_model_to_string - Write serialized model to a string
- * @model: &librdf_model object
+ * librdf_model_to_string:
+ * @model: #librdf_model object
  * @uri: base URI to use in serializing (or NULL if not used)
  * @name: the name of the serializer (or NULL for default)
  * @mime_type: the MIME type of the syntax (NULL if not used)
  * @type_uri: URI identifying the syntax (NULL if not used)
  *
+ * Write serialized model to a string.
+ *
  * If the name field is NULL, the default serializer will be used.
  *
  * Note: the returned string must be freed by the caller.
@@ -1536,9 +1635,11 @@ librdf_model_to_string(librdf_model* model, librdf_uri *uri,
 
 
 /**
- * librdf_model_contains_context - Check for a context in the model
+ * librdf_model_contains_context:
  * @model: the model object
  * @context: the contest
+ *
+ * Check for a context in the model.
  * 
  * Return value: non 0 if the model contains the context node
  **/
@@ -1615,7 +1716,7 @@ main(int argc, char *argv[])
   librdf_node *n1, *n2;
   int count;
   int expected_count;
-#define EXPECTED_BAD_STRING_LENGTH 299
+#define EXPECTED_BAD_STRING_LENGTH 281
   librdf_uri* base_uri;
   unsigned char *string;
   size_t string_length=0;
@@ -1643,7 +1744,7 @@ main(int argc, char *argv[])
 
   statement=librdf_new_statement(world);
   /* after this, nodes become owned by model */
-  librdf_statement_set_subject(statement, librdf_new_node_from_uri_string(world, (const unsigned char*)"http://www.ilrt.bris.ac.uk/people/cmdjb/"));
+  librdf_statement_set_subject(statement, librdf_new_node_from_uri_string(world, (const unsigned char*)"http://www.dajobe.org/"));
   librdf_statement_set_predicate(statement, librdf_new_node_from_uri_string(world, (const unsigned char*)"http://purl.org/dc/elements/1.1/creator"));
 
   if(!librdf_model_add_statement(model, statement)) {
