@@ -2,11 +2,10 @@
  *
  * rdf_node.c - RDF Node (RDF URI, Literal, Blank Node) Interface
  *
- * $Id: rdf_node.c,v 1.106 2005/04/17 21:00:05 cmdjb Exp $
+ * $Id: rdf_node.c 10927 2006-05-02 20:16:37Z dajobe $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, Copyright (C) 2000-2006, Copyright (C) 2000-2006, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -61,8 +60,10 @@ enum {
 /* class functions */
 
 /**
- * librdf_init_node - INTERNAL - Initialise the node module.
+ * librdf_init_node:
  * @world: redland world object
+ *
+ * INTERNAL - Initialise the node module.
  * 
  **/
 void
@@ -82,8 +83,11 @@ librdf_init_node(librdf_world* world)
 
 
 /**
- * librdf_finish_node - INTERNAL - Terminate the librdf_node module
+ * librdf_finish_node:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_node module.
+ *
  **/
 void
 librdf_finish_node(librdf_world *world)
@@ -103,14 +107,16 @@ librdf_finish_node(librdf_world *world)
 /* constructors */
 
 /**
- * librdf_new_node - Constructor - create a new librdf_node object with a private identifier
+ * librdf_new_node:
  * @world: redland world object
+ *
+ * Constructor - create a new #librdf_node object with a private identifier.
  * 
  * Calls librdf_new_node_from_blank_identifier(world, NULL) to
  * construct a new redland blank node identifier and make a
  * new librdf_node object for it.
  *
- * Return value: a new &librdf_node object or NULL on failure
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node(librdf_world *world)
@@ -121,12 +127,14 @@ librdf_new_node(librdf_world *world)
     
 
 /**
- * librdf_new_node_from_uri_string_or_uri - INTERNAL - Constructor - create a new librdf_node object from a URI string or URI object
+ * librdf_new_node_from_uri_string_or_uri:
  * @world: redland world object
  * @uri_string: string representing a URI
- * @uri: &librdf_uri object
+ * @uri: #librdf_uri object
+ *
+ * INTERNAL Constructor - create a new #librdf_node object from a URI string or URI object.
  * 
- * Return value: a new &librdf_node object or NULL on failure
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 static librdf_node*
 librdf_new_node_from_uri_string_or_uri(librdf_world *world, 
@@ -220,11 +228,13 @@ librdf_new_node_from_uri_string_or_uri(librdf_world *world,
     
 
 /**
- * librdf_new_node_from_uri_string - Constructor - create a new librdf_node object from a URI string
+ * librdf_new_node_from_uri_string:
  * @world: redland world object
  * @uri_string: string representing a URI
+ *
+ * Constructor - create a new #librdf_node object from a URI string.
  * 
- * Return value: a new &librdf_node object or NULL on failure
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_uri_string(librdf_world *world, 
@@ -240,11 +250,13 @@ librdf_new_node_from_uri_string(librdf_world *world,
 /* Create a new (Resource) Node and set the URI. */
 
 /**
- * librdf_new_node_from_uri - Constructor - create a new resource librdf_node object with a given URI
+ * librdf_new_node_from_uri:
  * @world: redland world object
- * @uri: &rdf_uri object
+ * @uri: #librdf_uri object
  *
- * Return value: a new &librdf_node object or NULL on failure
+ * Constructor - create a new resource #librdf_node object with a given URI.
+ *
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_uri(librdf_world *world, librdf_uri *uri) 
@@ -256,12 +268,14 @@ librdf_new_node_from_uri(librdf_world *world, librdf_uri *uri)
 
 
 /**
- * librdf_new_node_from_uri_local_name - Constructor - create a new resource librdf_node object with a given URI and local name
+ * librdf_new_node_from_uri_local_name:
  * @world: redland world object
- * @uri: &rdf_uri object
+ * @uri: #librdf_uri object
  * @local_name: local name to append to URI
  *
- * Return value: a new &librdf_node object or NULL on failure
+ * Constructor - create a new resource #librdf_node object with a given URI and local name.
+ *
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_uri_local_name(librdf_world *world, 
@@ -287,13 +301,15 @@ librdf_new_node_from_uri_local_name(librdf_world *world,
 
 
 /**
- * librdf_new_node_from_normalised_uri_string - Constructor - create a new librdf_node object from a URI string normalised to a new base URI
+ * librdf_new_node_from_normalised_uri_string:
  * @world: redland world object
  * @uri_string: string representing a URI
  * @source_uri: source URI
  * @base_uri: base URI
+ *
+ * Constructor - create a new #librdf_node object from a URI string normalised to a new base URI.
  * 
- * Return value: a new &librdf_node object or NULL on failure
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_normalised_uri_string(librdf_world *world, 
@@ -320,15 +336,21 @@ librdf_new_node_from_normalised_uri_string(librdf_world *world,
 
 
 /**
- * librdf_new_node_from_literal -  Constructor - create a new literal librdf_node object
+ * librdf_new_node_from_literal:
  * @world: redland world object
  * @string: literal string value
  * @xml_language: literal XML language (or NULL, empty string)
  * @is_wf_xml: non 0 if literal is XML
+ *
+ * Constructor - create a new literal #librdf_node object.
  * 
  * 0.9.12: xml_space argument deleted
  *
- * Return value: new &librdf_node object or NULL on failure
+ * An @xml_language cannot be used when @is_wf_xml is non-0. If both
+ * are given, NULL is returned.  If @xml_language is the empty string,
+ * it is the equivalent to NULL.
+ *
+ * Return value: new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_literal(librdf_world *world, 
@@ -338,6 +360,12 @@ librdf_new_node_from_literal(librdf_world *world,
 {
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(string, string, NULL);
 
+  if(xml_language && !*xml_language)
+    xml_language=NULL;
+
+  if(xml_language && is_wf_xml)
+    return NULL;
+  
   return librdf_new_node_from_typed_literal(world,
                                             string, xml_language,
                                             (is_wf_xml ? 
@@ -347,13 +375,19 @@ librdf_new_node_from_literal(librdf_world *world,
 
 
 /**
- * librdf_new_node_from_typed_literal -  Constructor - create a new typed literal librdf_node object
+ * librdf_new_node_from_typed_literal:
  * @world: redland world object
  * @value: literal string value
  * @xml_language: literal XML language (or NULL, empty string)
  * @datatype_uri: URI of typed literal datatype or NULL
+ *
+ * Constructor - create a new typed literal #librdf_node object.
  * 
- * Return value: new &librdf_node object or NULL on failure
+ * Only one of @xml_language or @datatype_uri may be given.  If both
+ * are given, NULL is returned.  If @xml_language is the empty string,
+ * it is the equivalent to NULL.
+ *
+ * Return value: new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_typed_literal(librdf_world *world, 
@@ -372,6 +406,12 @@ librdf_new_node_from_typed_literal(librdf_world *world,
   
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(value, string, NULL);
 
+  if(xml_language && !*xml_language)
+    xml_language=NULL;
+
+  if(xml_language && datatype_uri)
+    return NULL;
+  
 #ifdef WITH_THREADS
   pthread_mutex_lock(world->nodes_mutex);
 #endif
@@ -488,14 +528,16 @@ librdf_new_node_from_typed_literal(librdf_world *world,
 
 
 /**
- * librdf_new_node_from_blank_identifier -  Constructor - create a new literal librdf_node object from a blank node identifier
+ * librdf_new_node_from_blank_identifier:
  * @world: redland world object
  * @identifier: blank node identifier or NULL
  *
+ * Constructor - create a new literal #librdf_node object from a blank node identifier.
+ *
  * If no identifier string is given, creates a new internal identifier
  * and assigns it.
  * 
- * Return value: new &librdf_node object or NULL on failure
+ * Return value: new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_blank_identifier(librdf_world *world,
@@ -577,10 +619,12 @@ librdf_new_node_from_blank_identifier(librdf_world *world,
 
 
 /**
- * librdf_new_node_from_node - Copy constructor - create a new librdf_node object from an existing librdf_node object
- * @node: &librdf_node object to copy
+ * librdf_new_node_from_node:
+ * @node: #librdf_node object to copy
+ *
+ * Copy constructor - create a new librdf_node object from an existing librdf_node object.
  * 
- * Return value: a new &librdf_node object or NULL on failure
+ * Return value: a new #librdf_node object or NULL on failure
  **/
 librdf_node*
 librdf_new_node_from_node(librdf_node *node) 
@@ -593,8 +637,10 @@ librdf_new_node_from_node(librdf_node *node)
 
 
 /**
- * librdf_free_node - Destructor - destroy an librdf_node object
- * @node: &librdf_node object
+ * librdf_free_node:
+ * @node: #librdf_node object
+ *
+ * Destructor - destroy an #librdf_node object.
  * 
  **/
 void
@@ -683,9 +729,11 @@ librdf_free_node(librdf_node *node)
 /* functions / methods */
 
 /**
- * librdf_node_get_uri - Get the URI for a node object
+ * librdf_node_get_uri:
  * @node: the node object
  *
+ * Get the URI for a node object.
+ *
  * Returns a pointer to the URI object held by the node, it must be
  * copied if it is wanted to be used by the caller.
  * 
@@ -704,8 +752,10 @@ librdf_node_get_uri(librdf_node* node)
 
 
 /**
- * librdf_node_get_type - Get the type of the node
+ * librdf_node_get_type:
  * @node: the node object
+ *
+ * Get the type of the node.
  * 
  * Return value: the node type
  **/
@@ -746,8 +796,10 @@ librdf_node_get_type_as_string(int type)
 
 
 /**
- * librdf_node_get_literal_value - Get the string literal value of the node
+ * librdf_node_get_literal_value:
  * @node: the node object
+ *
+ * Get the string literal value of the node.
  * 
  * Returns a pointer to the literal value held by the node, it must be
  * copied if it is wanted to be used by the caller.
@@ -766,9 +818,11 @@ librdf_node_get_literal_value(librdf_node* node)
 
 
 /**
- * librdf_node_get_literal_value_as_counted_string - Get the string literal value of the node as a counted string
+ * librdf_node_get_literal_value_as_counted_string:
  * @node: the node object
  * @len_p: pointer to location to store length (or NULL)
+ *
+ * Get the string literal value of the node as a counted string.
  * 
  * Returns a pointer to the literal value held by the node, it must be
  * copied if it is wanted to be used by the caller.
@@ -792,8 +846,10 @@ librdf_node_get_literal_value_as_counted_string(librdf_node* node,
 
 
 /**
- * librdf_node_get_literal_value_as_latin1 - Get the string literal value of the node as ISO Latin-1
+ * librdf_node_get_literal_value_as_latin1:
  * @node: the node object
+ *
+ * Get the string literal value of the node as ISO Latin-1.
  * 
  * Returns a newly allocated string containing the conversion of the
  * UTF-8 literal value held by the node.
@@ -815,8 +871,10 @@ librdf_node_get_literal_value_as_latin1(librdf_node* node)
 
 
 /**
- * librdf_node_get_literal_value_language - Get the XML language of the node
+ * librdf_node_get_literal_value_language:
  * @node: the node object
+ *
+ * Get the XML language of the node.
  * 
  * Returns a pointer to the literal language value held by the node, it must
  * be copied if it is wanted to be used by the caller.
@@ -838,8 +896,10 @@ librdf_node_get_literal_value_language(librdf_node* node)
 
 
 /**
- * librdf_node_get_literal_value_is_wf_xml - Get the XML well-formness property of the node
+ * librdf_node_get_literal_value_is_wf_xml:
  * @node: the node object
+ *
+ * Get the XML well-formness property of the node.
  * 
  * Return value: 0 if the XML literal is NOT well formed XML content, or the node is not a literal
  **/
@@ -862,8 +922,10 @@ librdf_node_get_literal_value_is_wf_xml(librdf_node* node)
 
 
 /**
- * librdf_node_get_literal_value_datatype_uri - Get the typed literal datatype URI of the literal node
+ * librdf_node_get_literal_value_datatype_uri:
  * @node: the node object
+ *
+ * Get the typed literal datatype URI of the literal node.
  * 
  * Return value: shared URI of the datatyped literal or NULL if the node is not a literal, or has no datatype URI
  **/
@@ -881,9 +943,11 @@ librdf_node_get_literal_value_datatype_uri(librdf_node* node)
 
 
 /**
- * librdf_node_get_li_ordinal - Get the node li object ordinal value
+ * librdf_node_get_li_ordinal:
  * @node: the node object
  *
+ * Get the node li object ordinal value.
+ *
  * Return value: the li ordinal value or < 1 on failure
  **/
 int
@@ -907,9 +971,11 @@ librdf_node_get_li_ordinal(librdf_node* node) {
 
 
 /**
- * librdf_node_get_blank_identifier - Get the blank node identifier
+ * librdf_node_get_blank_identifier:
  * @node: the node object
  *
+ * Get the blank node identifier.
+ *
  * Return value: the identifier value
  **/
 unsigned char *
@@ -923,8 +989,10 @@ librdf_node_get_blank_identifier(librdf_node* node) {
 
 
 /**
- * librdf_node_is_resource -  Check node is a resource
+ * librdf_node_is_resource:
  * @node: the node object
+ *
+ * Check node is a resource.
  * 
  * Return value: non-zero if the node is a resource (URI)
  **/
@@ -937,8 +1005,10 @@ librdf_node_is_resource(librdf_node* node) {
 
 
 /**
- * librdf_node_is_resource -  Check node is a literal
+ * librdf_node_is_literal:
  * @node: the node object
+ *
+ * Check node is a literal.
  * 
  * Return value: non-zero if the node is a literal
  **/
@@ -951,8 +1021,10 @@ librdf_node_is_literal(librdf_node* node) {
 
 
 /**
- * librdf_node_is_blank -  Check node is a blank nodeID
+ * librdf_node_is_blank:
  * @node: the node object
+ *
+ * Check node is a blank nodeID.
  * 
  * Return value: non-zero if the node is a blank nodeID
  **/
@@ -965,8 +1037,10 @@ librdf_node_is_blank(librdf_node* node) {
 
 
 /**
- * librdf_node_to_string - Format the node as a string
+ * librdf_node_to_string:
  * @node: the node object
+ *
+ * Format the node as a string.
  * 
  * Note a new string is allocated which must be freed by the caller.
  * 
@@ -982,9 +1056,11 @@ librdf_node_to_string(librdf_node* node)
 
 
 /**
- * librdf_node_to_counted_string - Format the node as a counted string
+ * librdf_node_to_counted_string:
  * @node: the node object
  * @len_p: pointer to location to store length
+ *
+ * Format the node as a counted string.
  * 
  * Note a new string is allocated which must be freed by the caller.
  * 
@@ -1066,7 +1142,7 @@ librdf_node_to_counted_string(librdf_node* node, size_t* len_p)
   default:
       librdf_log(node->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
-                 "Do not know how to print node type %d\n", node->type);
+                 "Do not know how to print node type %d", node->type);
     return NULL;
   }
   return s;
@@ -1074,9 +1150,11 @@ librdf_node_to_counted_string(librdf_node* node, size_t* len_p)
 
 
 /**
- * librdf_node_print - pretty print the node to a file descriptor
+ * librdf_node_print:
  * @node: the node
  * @fh: file handle
+ *
+ * Pretty print the node to a file descriptor.
  * 
  * This method is for debugging and the format of the output should
  * not be relied on.
@@ -1103,12 +1181,14 @@ librdf_node_print(librdf_node* node, FILE *fh)
 
 
 /**
- * librdf_node_get_digest - Get a digest representing a librdf_node
+ * librdf_node_get_digest:
  * @node: the node object
+ *
+ * Get a digest representing a librdf_node.
  * 
  * A new digest object is created which must be freed by the caller.
  * 
- * Return value: a new &librdf_digest object or NULL on failure
+ * Return value: a new #librdf_digest object or NULL on failure
  **/
 librdf_digest*
 librdf_node_get_digest(librdf_node* node) 
@@ -1140,7 +1220,8 @@ librdf_node_get_digest(librdf_node* node)
     default:
       librdf_log(world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
-                 "Do not know how to make digest for node type %d\n", node->type);
+                 "Do not know how to make digest for node type %d",
+                 node->type);
       return NULL;
   }
   
@@ -1149,9 +1230,11 @@ librdf_node_get_digest(librdf_node* node)
 
 
 /**
- * librdf_node_equals - Compare two librdf_node objects for equality
- * @first_node: first &librdf_node node
- * @second_node: second &librdf_node node
+ * librdf_node_equals:
+ * @first_node: first #librdf_node node
+ * @second_node: second #librdf_node node
+ *
+ * Compare two librdf_node objects for equality.
  * 
  * Note - for literal nodes, XML language, XML space and well-formness are 
  * presently ignored in the comparison.
@@ -1173,15 +1256,20 @@ librdf_node_equals(librdf_node* first_node, librdf_node* second_node)
 
 
 /**
- * librdf_node_encode - Serialise a node into a buffer
+ * librdf_node_encode:
  * @node: the node to serialise
  * @buffer: the buffer to use
  * @length: buffer size
+ *
+ * Serialise a node into a buffer.
  * 
  * Encodes the given node in the buffer, which must be of sufficient
  * size.  If buffer is NULL, no work is done but the size of buffer
  * required is returned.
  * 
+ * If the node cannot be encoded due to restrictions of the encoding
+ * format, a redland error is generated
+ *
  * Return value: the number of bytes written or 0 on failure.
  **/
 size_t
@@ -1204,7 +1292,15 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
       
       if(length && total_length > length)
         return 0;    
-      
+
+      if(string_length > 0xFFFF) {
+          librdf_log(node->world,
+                     0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
+                     "Cannot encode a URI string of %d bytes length",
+                     string_length);
+        return 0;
+      }
+
       if(buffer) {
         buffer[0]='R';
         buffer[1]=(string_length & 0xff00) >> 8;
@@ -1214,34 +1310,6 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
       break;
       
     case LIBRDF_NODE_TYPE_LITERAL:
-#if 0
-      /* old encoding before 0.9.12 */
-      string=(unsigned char*)node->value.literal.string;
-      string_length=node->value.literal.string_len;
-      if(node->value.literal.xml_language)
-        language_length=strlen(node->value.literal.xml_language);
-      
-      total_length= 6 + string_length + 1; /* +1 for \0 at end */
-      if(language_length)
-        total_length += language_length+1;
-      
-      if(length && total_length > length)
-        return 0;    
-      
-      if(buffer) {
-        buffer[0]='L';
-        buffer[1]=(node->value.literal.is_wf_xml & 0xf) << 8;
-        buffer[2]=(string_length & 0xff00) >> 8;
-        buffer[3]=(string_length & 0x00ff);
-        buffer[4]='\0'; /* unused */
-        buffer[5]=(language_length & 0x00ff);
-        strcpy((char*)buffer+6, (const char*)string);
-        if(language_length)
-          strcpy((char*)buffer+string_length+7, (const char*)node->value.literal.xml_language);
-      }
-      break;
-      
-#endif
       string=(unsigned char*)node->value.literal.string;
       string_length=node->value.literal.string_len;
       if(node->value.literal.xml_language)
@@ -1258,6 +1326,31 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
       
       if(length && total_length > length)
         return 0;    
+
+      if(string_length > 0xFFFF) {
+        librdf_log(node->world,
+                   0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
+                   "Cannot encode a literal string of %d bytes length",
+                   string_length);
+        return 0;
+      }
+
+      if(datatype_uri_length > 0xFFFF) {
+        librdf_log(node->world,
+                   0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
+                   "Cannot encode a datatype URI string of %d bytes length",
+                   datatype_uri_length);
+        return 0;
+      }
+
+      if(language_length > 0xFF) {
+        librdf_log(node->world,
+                   0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
+                   "Cannot encode a language string of %d bytes length",
+                   language_length);
+        return 0;
+      }
+
       
       if(buffer) {
         buffer[0]='M';
@@ -1287,6 +1380,14 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
       if(length && total_length > length)
         return 0;    
       
+      if(string_length > 0xFFFF) {
+        librdf_log(node->world,
+                   0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
+                   "Cannot encode a blank node identifier string of %d bytes length",
+                   string_length);
+        return 0;
+      }
+
       if(buffer) {
         buffer[0]='B';
         buffer[1]=(string_length & 0xff00) >> 8;
@@ -1299,7 +1400,7 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
     default:
       librdf_log(node->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
-                 "Do not know how to encode node type %d\n", node->type);
+                 "Do not know how to encode node type %d", node->type);
       return 0;
   }
   
@@ -1308,11 +1409,13 @@ librdf_node_encode(librdf_node* node, unsigned char *buffer, size_t length)
 
 
 /**
- * librdf_node_decode - Deserialise a node from a buffer
+ * librdf_node_decode:
  * @world: librdf_world
  * @size_p: pointer to bytes used or NULL
  * @buffer: the buffer to use
  * @length: buffer size
+ *
+ * Deserialise a node from a buffer.
  * 
  * Decodes the serialised node (as created by librdf_node_encode() )
  * from the given buffer.
@@ -1424,7 +1527,7 @@ librdf_node_decode(librdf_world *world,
   default:
       librdf_log(world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
-                 "Illegal node encoding '%c' seen\n", buffer[0]);
+                 "Illegal node encoding '%c' seen", buffer[0]);
     return NULL;
   }
   
@@ -1490,7 +1593,7 @@ librdf_node_static_iterator_get_method(void* iterator, int flags)
     default:
       librdf_log(context->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_NODE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -1505,14 +1608,16 @@ librdf_node_static_iterator_finished(void* iterator)
 
 
 /**
- * librdf_node_static_iterator_create - Create an iterator over an array of nodes
- * @nodes: static array of &librdf_node objects
+ * librdf_node_static_iterator_create:
+ * @nodes: static array of #librdf_node objects
  * @size: size of array
+ *
+ * Create an iterator over an array of nodes.
  * 
  * This creates an iterator for an existing static array of librdf_node
  * objects.  It is mostly intended for testing iterator code.
  * 
- * Return value: a &librdf_iterator serialization of the nodes or NULL on failure
+ * Return value: a #librdf_iterator serialization of the nodes or NULL on failure
  **/
 librdf_iterator*
 librdf_node_static_iterator_create(librdf_node** nodes,
@@ -1559,7 +1664,7 @@ int
 main(int argc, char *argv[]) 
 {
   librdf_node *node, *node2, *node3, *node4, *node5, *node6, *node7;
-  char *hp_string1="http://www.ilrt.bristol.ac.uk/people/cmdjb/";
+  char *hp_string1="http://purl.org/net/dajobe/";
   char *hp_string2="http://purl.org/net/dajobe/";
   char *lit_string="Dave Beckett";
   char *genid="genid42";
@@ -1675,7 +1780,7 @@ main(int argc, char *argv[])
   uri2=librdf_new_uri(world, (const unsigned char*)"http://example.org/datatypeURI");
   node6=librdf_new_node_from_typed_literal(world, 
                                            (const unsigned char*)"Datatyped literal value",
-                                           "en-GB", uri2);
+                                           NULL, uri2);
   librdf_free_uri(uri2);
 
   size=librdf_node_encode(node6, NULL, 0);
@@ -1696,6 +1801,19 @@ main(int argc, char *argv[])
   }
   LIBRDF_FREE(cstring, buffer);
    
+  if(librdf_new_node_from_typed_literal(world, 
+                                        (const unsigned char*)"Datatyped literal value",
+                                        "en-GB", uri2)) {
+    fprintf(stderr, "%s: Unexpected success allowing a datatyped literal with a language\n", program);
+    return(1);
+  }
+    
+  if(librdf_new_node_from_literal(world, 
+                                  (const unsigned char*)"XML literal value",
+                                  "en-GB", 1)) {
+    fprintf(stderr, "%s: Unexpected success allowing an XML literal with a language\n", program);
+    return(1);
+  }
     
 
 
