@@ -2,11 +2,10 @@
  *
  * rdf_parser.c - RDF Parser using Raptor
  *
- * $Id: rdf_parser_raptor.c,v 1.79 2004/11/01 20:43:34 cmdjb Exp $
+ * $Id: rdf_parser_raptor.c 10942 2006-05-04 05:01:09Z dajobe $
  *
- * Copyright (C) 2000-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -69,7 +68,12 @@ typedef struct {
 
   /* when reading from a file */
   FILE *fh;
+  /* when true, this FH is closed on finish */
+  int close_fh;
 
+  /* when finished */
+  int finished;
+  
   /* when storing into a model - librdf_parser_raptor_parse_uri_into_model */
   librdf_model *model;
   
@@ -88,9 +92,11 @@ typedef struct {
 
 
 /**
- * librdf_parser_raptor_init - Initialise the raptor RDF parser
+ * librdf_parser_raptor_init:
  * @parser: the parser
  * @context: context
+ *
+ * Initialise the raptor RDF parser.
  * 
  * Return value: non 0 on failure
  **/
@@ -119,8 +125,11 @@ librdf_parser_raptor_init(librdf_parser *parser, void *context)
   
 
 /**
- * librdf_parser_raptor_terminate - Terminate the raptor RDF parser
+ * librdf_parser_raptor_terminate:
  * @context: context
+ *
+ * Terminate the raptor RDF parser.
+ *
  **/
 static void
 librdf_parser_raptor_terminate(void *context) 
@@ -187,7 +196,8 @@ librdf_parser_raptor_new_statement_handler(void *context,
     sprintf(ordinal_buffer, "http://www.w3.org/1999/02/22-rdf-syntax-ns#_%d", ordinal);
     
     node=librdf_new_node_from_uri_string(world, (const unsigned char*)ordinal_buffer);
-  } else if (rstatement->predicate_type == RAPTOR_IDENTIFIER_TYPE_PREDICATE) {
+  } else if (rstatement->predicate_type == RAPTOR_IDENTIFIER_TYPE_RESOURCE ||
+             rstatement->predicate_type == RAPTOR_IDENTIFIER_TYPE_PREDICATE) {
     node=librdf_new_node_from_normalised_uri_string(world,
                                                     librdf_uri_as_string((librdf_uri*)rstatement->predicate),
                                                     scontext->source_uri,
@@ -259,14 +269,10 @@ static void
 librdf_parser_raptor_error_handler(void *data, raptor_locator *locator,
                                    const char *message) 
 {
-  librdf_parser_raptor_stream_context* scontext=(librdf_parser_raptor_stream_context*)data;
-  librdf_parser_raptor_context* pcontext;
-  librdf_parser* parser;
-
-  pcontext=scontext->pcontext;
-  parser=pcontext->parser;
+  librdf_parser_raptor_context* pcontext=(librdf_parser_raptor_context*)data;
 
   pcontext->errors++;
+
   raptor_parse_abort(pcontext->rdf_parser);
 
   librdf_log_simple(pcontext->parser->world, 0, LIBRDF_LOG_ERROR, LIBRDF_FROM_PARSER, locator, message);
@@ -277,10 +283,8 @@ static void
 librdf_parser_raptor_warning_handler(void *data, raptor_locator *locator,
                                      const char *message) 
 {
-  librdf_parser_raptor_stream_context* scontext=(librdf_parser_raptor_stream_context*)data;
-  librdf_parser_raptor_context* pcontext;
+  librdf_parser_raptor_context* pcontext=(librdf_parser_raptor_context*)data;
 
-  pcontext=scontext->pcontext;
   pcontext->warnings++;
 
   librdf_log_simple(pcontext->parser->world, 0, LIBRDF_LOG_WARN, LIBRDF_FROM_PARSER, locator, message);
@@ -302,7 +306,7 @@ librdf_parser_raptor_get_next_statement(librdf_parser_raptor_stream_context *con
   unsigned char buffer[RAPTOR_IO_BUFFER_LEN];
   int status=0;
   
-  if(!context->fh)
+  if(context->finished || !context->fh)
     return 0;
   
   context->current=NULL;
@@ -326,10 +330,8 @@ librdf_parser_raptor_get_next_statement(librdf_parser_raptor_stream_context *con
       break;
   }
 
-  if(feof(context->fh) || status <1) {
-    fclose(context->fh);
-    context->fh=NULL;
-  }
+  if(feof(context->fh) || status <1)
+    context->finished=1;
   
   return status;
 }
@@ -356,24 +358,26 @@ librdf_parser_raptor_generate_id_handler(void *user_data,
 }
 
 
-/**
- * librdf_parser_raptor_parse_file_as_stream - Retrieve the RDF/XML content at URI and parse it into a librdf_stream
+/*
+ * librdf_parser_raptor_parse_file_handle_as_stream:
  * @context: parser context
- * @uri: &librdf_uri URI of RDF/XML content source
- * @base_uri: &librdf_uri URI of the content location or NULL if the same
+ * @fh: FILE* of content source
+ * @close_fh: if true to fclose(fh) on finish
+ * @base_uri: #librdf_uri URI of the content location
  *
+ * Retrieve content from FILE* @fh and parse it into a #librdf_stream.
  *
  **/
 static librdf_stream*
-librdf_parser_raptor_parse_file_as_stream(void *context, librdf_uri *uri,
-                                          librdf_uri *base_uri)
+librdf_parser_raptor_parse_file_handle_as_stream(librdf_world* world,
+                                                 void *context, 
+                                                 FILE *fh, int close_fh,
+                                                 librdf_uri *base_uri)
 {
   librdf_parser_raptor_context* pcontext=(librdf_parser_raptor_context*)context;
   librdf_parser_raptor_stream_context* scontext;
   librdf_stream *stream;
-  char* filename;
   int rc;
-  librdf_world *world=uri->world;
 
   pcontext->errors=0;
   pcontext->warnings=0;
@@ -385,9 +389,9 @@ librdf_parser_raptor_parse_file_as_stream(void *context, librdf_uri *uri,
   raptor_set_statement_handler(pcontext->rdf_parser, scontext, 
                                librdf_parser_raptor_new_statement_handler);
   
-  raptor_set_error_handler(pcontext->rdf_parser, scontext, 
+  raptor_set_error_handler(pcontext->rdf_parser, pcontext, 
                            librdf_parser_raptor_error_handler);
-  raptor_set_warning_handler(pcontext->rdf_parser, scontext,
+  raptor_set_warning_handler(pcontext->rdf_parser, pcontext,
                              librdf_parser_raptor_warning_handler);
 
   raptor_set_generate_id_handler(pcontext->rdf_parser, pcontext,
@@ -395,23 +399,12 @@ librdf_parser_raptor_parse_file_as_stream(void *context, librdf_uri *uri,
   
   
   scontext->pcontext=pcontext;
-  scontext->source_uri = librdf_new_uri_from_uri(uri);
-  if(!base_uri)
-    base_uri=uri;
-  scontext->base_uri = librdf_new_uri_from_uri(base_uri);
-
-  filename=(char*)librdf_uri_to_filename(uri);
-  if(!filename)
-    return NULL;
-  
-  scontext->fh=fopen(filename, "r");
-  if(!scontext->fh) {
-    LIBRDF_DEBUG3("Failed to open file '%s' - %s\n", filename, strerror(errno));
-    SYSTEM_FREE(filename);
-    librdf_parser_raptor_serialise_finished((void*)scontext);
-    return(NULL);
-  }
-  SYSTEM_FREE(filename);
+  if(base_uri)
+    scontext->source_uri = librdf_new_uri_from_uri(base_uri);
+  if(base_uri)
+    scontext->base_uri = librdf_new_uri_from_uri(base_uri);
+  scontext->fh=fh;
+  scontext->close_fh=close_fh;
 
   /* Start the parse */
   rc=raptor_start_parse(pcontext->rdf_parser, (raptor_uri*)base_uri);
@@ -450,12 +443,14 @@ librdf_parser_raptor_parse_uri_as_stream_write_bytes_handler(raptor_www *www,
 
 
 /**
- * librdf_parser_raptor_parse_as_stream_common - Retrieve the content at URI/string and parse it into a librdf_stream
+ * librdf_parser_raptor_parse_as_stream_common:
  * @context: parser context
- * @uri: &librdf_uri URI of ontent source
+ * @uri: #librdf_uri URI of ontent source
  * @string: or content string
  * @length: length of the string or 0 if not yet counted
- * @base_uri: &librdf_uri URI of the content location or NULL if the same
+ * @base_uri: #librdf_uri URI of the content location or NULL if the same
+ *
+ * Retrieve the content at URI/string and parse it into a librdf_stream.
  *
  * Only one of uri or string may be given
  *
@@ -473,9 +468,29 @@ librdf_parser_raptor_parse_as_stream_common(void *context, librdf_uri *uri,
   pcontext->errors=0;
   pcontext->warnings=0;
   
-  if(uri && librdf_uri_is_file_uri(uri))
-    return librdf_parser_raptor_parse_file_as_stream(context, uri, base_uri);
+  if(uri && librdf_uri_is_file_uri(uri)) {
+    char* filename=(char*)librdf_uri_to_filename(uri);
+    FILE *fh;
 
+    if(!filename)
+      return NULL;
+    
+    fh=fopen(filename, "r");
+    if(!fh) {
+      LIBRDF_DEBUG3("Failed to open file '%s' - %s\n", filename, strerror(errno));
+      SYSTEM_FREE(filename);
+      return NULL;
+    }
+
+    /* stream will close FH */
+    stream=librdf_parser_raptor_parse_file_handle_as_stream(pcontext->parser->world,
+                                                            context, fh, 1,
+                                                            base_uri);
+
+    SYSTEM_FREE(filename);
+    return stream;
+  }
+  
 
   scontext=(librdf_parser_raptor_stream_context*)LIBRDF_CALLOC(librdf_parser_raptor_stream_context, 1, sizeof(librdf_parser_raptor_stream_context));
   if(!scontext)
@@ -484,9 +499,9 @@ librdf_parser_raptor_parse_as_stream_common(void *context, librdf_uri *uri,
   raptor_set_statement_handler(pcontext->rdf_parser, scontext, 
                                librdf_parser_raptor_new_statement_handler);
   
-  raptor_set_error_handler(pcontext->rdf_parser, scontext, 
+  raptor_set_error_handler(pcontext->rdf_parser, pcontext, 
                            librdf_parser_raptor_error_handler);
-  raptor_set_warning_handler(pcontext->rdf_parser, scontext,
+  raptor_set_warning_handler(pcontext->rdf_parser, pcontext,
                              librdf_parser_raptor_warning_handler);
 
   raptor_set_generate_id_handler(pcontext->rdf_parser, pcontext,
@@ -556,10 +571,12 @@ librdf_parser_raptor_parse_as_stream_common(void *context, librdf_uri *uri,
 
 
 /**
- * librdf_parser_raptor_parse_uri_as_stream - Retrieve the content at URI and parse it into a librdf_stream
+ * librdf_parser_raptor_parse_uri_as_stream:
  * @context: parser context
- * @uri: &librdf_uri URI of content source
- * @base_uri: &librdf_uri URI of the content location or NULL if the same
+ * @uri: #librdf_uri URI of content source
+ * @base_uri: #librdf_uri URI of the content location or NULL if the same
+ *
+ * Retrieve the content at URI and parse it into a librdf_stream.
  *
  *
  **/
@@ -574,10 +591,12 @@ librdf_parser_raptor_parse_uri_as_stream(void *context, librdf_uri *uri,
 
 
 /**
- * librdf_parser_raptor_parse_string_as_stream - Parse the content in a string and return a librdf_stream
+ * librdf_parser_raptor_parse_string_as_stream:
  * @context: parser context
  * @string: string content to parse
- * @base_uri: &librdf_uri URI of the content location or NULL if the same
+ * @base_uri: #librdf_uri URI of the content location or NULL if the same
+ *
+ * Parse the content in a string and return a librdf_stream.
  *
  *
  **/
@@ -593,13 +612,15 @@ librdf_parser_raptor_parse_string_as_stream(void *context,
 
 
 /**
- * librdf_parser_raptor_parse_counted_string_as_stream - Parse a counted string of content to a librdf_stream of statements
+ * librdf_parser_raptor_parse_counted_string_as_stream:
  * @context: parser context
  * @string: string content to parse
  * @length: length of the string content (must be >0)
  * @base_uri: the base URI to use
+ *
+ * Parse a counted string of content to a librdf_stream of statements.
  * 
- * Return value: &librdf_stream of statements or NULL
+ * Return value: #librdf_stream of statements or NULL
  **/
 static librdf_stream*
 librdf_parser_raptor_parse_counted_string_as_stream(void *context,
@@ -613,13 +634,15 @@ librdf_parser_raptor_parse_counted_string_as_stream(void *context,
 }
 
 /**
- * librdf_parser_raptor_parse_uri_into_model - Retrieve the RDF/XML content at URI and store it into a librdf_model
+ * librdf_parser_raptor_parse_uri_into_model:
  * @context: parser context
- * @uri: &librdf_uri URI of RDF/XML content source
+ * @uri: #librdf_uri URI of RDF/XML content source
  * @string: string content to parser
  * @length: length of the string or 0 if not yet counted
- * @base_uri: &librdf_uri URI of the content location
- * @model: &librdf_model of model
+ * @base_uri: #librdf_uri URI of the content location
+ * @model: #librdf_model of model
+ *
+ * Retrieve the RDF/XML content at URI and store it into a librdf_model.
  *
  * Parses the content at @uri or @string and store it in the given model.
  * A base URI must be given if @uri is NULL, when @string is used.
@@ -648,9 +671,9 @@ librdf_parser_raptor_parse_into_model_common(void *context,
   raptor_set_statement_handler(pcontext->rdf_parser, scontext, 
                                librdf_parser_raptor_new_statement_handler);
   
-  raptor_set_error_handler(pcontext->rdf_parser, scontext, 
+  raptor_set_error_handler(pcontext->rdf_parser, pcontext, 
                            librdf_parser_raptor_error_handler);
-  raptor_set_warning_handler(pcontext->rdf_parser, scontext,
+  raptor_set_warning_handler(pcontext->rdf_parser, pcontext,
                              librdf_parser_raptor_warning_handler);
 
   raptor_set_generate_id_handler(pcontext->rdf_parser, pcontext,
@@ -696,11 +719,13 @@ librdf_parser_raptor_parse_into_model_common(void *context,
 
 
 /**
- * librdf_parser_raptor_parse_uri_into_model - Retrieve the RDF/XML content at URI and store it into a librdf_model
+ * librdf_parser_raptor_parse_uri_into_model:
  * @context: parser context
- * @uri: &librdf_uri URI of RDF/XML content source
- * @base_uri: &librdf_uri URI of the content location (or NULL if the same as @uri)
- * @model: &librdf_model of model
+ * @uri: #librdf_uri URI of RDF/XML content source
+ * @base_uri: #librdf_uri URI of the content location (or NULL if the same as @uri)
+ * @model: #librdf_model of model
+ *
+ * Retrieve the RDF/XML content at URI and store it into a librdf_model.
  *
  * Retrieves all statements and stores them in the given model.
  *
@@ -717,11 +742,13 @@ librdf_parser_raptor_parse_uri_into_model(void *context, librdf_uri *uri,
 
 
 /**
- * librdf_parser_raptor_parse_string_into_model - Parse the RDF/XML content in a string and store it into a librdf_model
+ * librdf_parser_raptor_parse_string_into_model:
  * @context: parser context
  * @string: content to parse
- * @base_uri: &librdf_uri URI of the content location
- * @model: &librdf_model of model
+ * @base_uri: #librdf_uri URI of the content location
+ * @model: #librdf_model of model
+ *
+ * Parse the RDF/XML content in a string and store it into a librdf_model.
  *
  * Stores the statements found parsing string and stores in the given model.
  *
@@ -740,12 +767,14 @@ librdf_parser_raptor_parse_string_into_model(void *context,
 
 
 /**
- * librdf_parser_raptor_parse_counted_string_into_model - Parse a counted string of content into an librdf_model
+ * librdf_parser_raptor_parse_counted_string_into_model:
  * @context: parser context
  * @string: the content to parse
  * @length: length of content (must be >0)
  * @base_uri: the base URI to use
  * @model: the model to use
+ *
+ * Parse a counted string of content into an librdf_model.
  * 
  * Return value: non 0 on failure
  **/
@@ -763,8 +792,10 @@ librdf_parser_raptor_parse_counted_string_into_model(void *context,
 
 
 /**
- * librdf_parser_raptor_serialise_end_of_stream - Check for the end of the stream of statements from the raptor RDF parser
- * @context: the context passed in by &librdf_stream
+ * librdf_parser_raptor_serialise_end_of_stream:
+ * @context: the context passed in by #librdf_stream
+ *
+ * Check for the end of the stream of statements from the raptor RDF parser.
  * 
  * Return value: non 0 at end of stream
  **/
@@ -778,8 +809,10 @@ librdf_parser_raptor_serialise_end_of_stream(void* context)
 
 
 /**
- * librdf_parser_raptor_serialise_next_statement - Move to the next librdf_statement in the stream of statements from the raptor RDF parse
- * @context: the context passed in by &librdf_stream
+ * librdf_parser_raptor_serialise_next_statement:
+ * @context: the context passed in by #librdf_stream
+ *
+ * Move to the next librdf_statement in the stream of statements from the raptor RDF parse.
  * 
  * Return value: non 0 at end of stream
  **/
@@ -809,11 +842,13 @@ librdf_parser_raptor_serialise_next_statement(void* context)
 
 
 /**
- * librdf_parser_raptor_serialise_get_statement - Get the current librdf_statement from the stream of statements from the raptor RDF parse
- * @context: the context passed in by &librdf_stream
+ * librdf_parser_raptor_serialise_get_statement:
+ * @context: the context passed in by #librdf_stream
  * @flags: the context get method flags
+ *
+ * Get the current librdf_statement from the stream of statements from the raptor RDF parse.
  * 
- * Return value: a new &librdf_statement or NULL on error or if no statements found.
+ * Return value: a new #librdf_statement or NULL on error or if no statements found.
  **/
 static void*
 librdf_parser_raptor_serialise_get_statement(void* context, int flags)
@@ -830,7 +865,7 @@ librdf_parser_raptor_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->pcontext->parser->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_PARSER, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 
@@ -838,8 +873,11 @@ librdf_parser_raptor_serialise_get_statement(void* context, int flags)
 
 
 /**
- * librdf_parser_raptor_serialise_finished - Finish the serialisation of the statement stream from the raptor RDF parse
- * @context: the context passed in by &librdf_stream
+ * librdf_parser_raptor_serialise_finished:
+ * @context: the context passed in by #librdf_stream
+ *
+ * Finish the serialisation of the statement stream from the raptor RDF parse.
+ *
  **/
 static void
 librdf_parser_raptor_serialise_finished(void* context)
@@ -862,6 +900,9 @@ librdf_parser_raptor_serialise_finished(void* context)
       librdf_free_statement(statement);
     librdf_list_clear(&scontext->statements);
 
+    if(scontext->fh && scontext->close_fh)
+      fclose(scontext->fh); 
+ 
     LIBRDF_FREE(librdf_parser_raptor_context, scontext);
   }
 }
@@ -1012,8 +1053,10 @@ static raptor_uri_handler librdf_raptor_uri_handler = {
 
 
 /**
- * librdf_parser_raptor_register_factory - Register the raptor RDF parser with the RDF parser factory
+ * librdf_parser_raptor_register_factory:
  * @factory: factory
+ *
+ * Register the raptor RDF parser with the RDF parser factory.
  * 
  **/
 static void
@@ -1035,8 +1078,11 @@ librdf_parser_raptor_register_factory(librdf_parser_factory *factory)
 
 
 /**
- * librdf_parser_raptor_constructor - Initialise the raptor RDF parser module
+ * librdf_parser_raptor_constructor:
  * @world: redland world object
+ *
+ * Initialise the raptor RDF parser module.
+ *
  **/
 void
 librdf_parser_raptor_constructor(librdf_world *world)
@@ -1076,8 +1122,11 @@ librdf_parser_raptor_constructor(librdf_world *world)
 
 
 /**
- * librdf_parser_raptor_destructor - Terminate the raptor RDF parser module
+ * librdf_parser_raptor_destructor:
  * @world: redland world object
+ *
+ * Terminate the raptor RDF parser module.
+ *
  **/
 void
 librdf_parser_raptor_destructor(void)
