@@ -2,11 +2,10 @@
  *
  * rdf_query.c - RDF Query Language/Syntax and Execution Interface
  *
- * $Id: rdf_query.c,v 1.55 2005/05/20 14:25:25 cmdjb Exp $
+ * $Id: rdf_query.c 10854 2006-04-25 06:40:57Z dajobe $
  *
- * Copyright (C) 2002-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2002-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2002-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -53,8 +52,10 @@ static void librdf_delete_query_factories(librdf_world *world);
 
 
 /**
- * librdf_init_query - INTERNAL - Initialise the librdf_query module
+ * librdf_init_query:
  * @world: redland world object
+ *
+ * INTERNAL - Initialise the librdf_query module.
  * 
  * Initialises and registers all
  * compiled query modules.  Must be called before using any of the query
@@ -70,8 +71,11 @@ librdf_init_query(librdf_world *world)
 
 
 /**
- * librdf_finish_query - INTERNAL - Terminate the librdf_query module
+ * librdf_finish_query:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_query module.
+ *
  **/
 void
 librdf_finish_query(librdf_world *world) 
@@ -107,11 +111,13 @@ librdf_delete_query_factories(librdf_world *world)
 /* class methods */
 
 /**
- * librdf_query_register_factory - Register a query factory
+ * librdf_query_register_factory:
  * @world: redland world object
  * @name: the query language name
  * @uri_string: the query language URI string (or NULL if none)
  * @factory: pointer to function to call to register the factory
+ *
+ * Register a query factory.
  * 
  **/
 void
@@ -158,7 +164,7 @@ librdf_query_register_factory(librdf_world *world, const char *name,
       LIBRDF_FREE(librdf_query, query);
       librdf_log(world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_QUERY, NULL,
-                 "query language %s already registered\n", h->name);
+                 "query language %s already registered", h->name);
       return;
     }
   }
@@ -176,10 +182,12 @@ librdf_query_register_factory(librdf_world *world, const char *name,
 
 
 /**
- * librdf_get_query_factory - Get a query factory by name
+ * librdf_get_query_factory:
  * @world: redland world object
  * @name: the factory name or NULL for the default factory
  * @uri: the factory URI or NULL for the default factory
+ *
+ * Get a query factory by name.
  * 
  * Return value: the factory object or NULL if there is no such factory
  **/
@@ -219,14 +227,16 @@ librdf_get_query_factory(librdf_world *world,
 
 
 /**
- * librdf_new_query - Constructor - create a new librdf_query object
+ * librdf_new_query:
  * @world: redland world object
  * @name: the name identifying the query language
  * @uri: the URI identifying the query language (or NULL)
- * @base_uri: the base URI of the query string (or NULL)
  * @query_string: the query string
+ * @base_uri: the base URI of the query string (or NULL)
  *
- * Return value: a new &librdf_query object or NULL on failure
+ * Constructor - create a new #librdf_query object.
+ *
+ * Return value: a new #librdf_query object or NULL on failure
  */
 librdf_query*
 librdf_new_query (librdf_world *world,
@@ -246,12 +256,12 @@ librdf_new_query (librdf_world *world,
 
 /**
  * librdf_new_query_from_query - Copy constructor - create a new librdf_query object from an existing one
- * @old_query: the existing query &librdf_query to use
+ * @old_query: the existing query #librdf_query to use
  *
  * Should create a new query in the same context as the existing one
  * as appropriate.
  *
- * Return value: a new &librdf_query object or NULL on failure
+ * Return value: a new #librdf_query object or NULL on failure
  */
 librdf_query*
 librdf_new_query_from_query(librdf_query* old_query) 
@@ -300,7 +310,7 @@ librdf_new_query_from_query(librdf_query* old_query)
 
 
 /**
- * librdf_new_query_from_factory - Constructor - create a new librdf_query object
+ * librdf_new_query_from_factory:
  * @world: redland world object
  * @factory: the factory to use to construct the query
  * @name: query language name
@@ -308,7 +318,9 @@ librdf_new_query_from_query(librdf_query* old_query)
  * @query_string: the query string
  * @base_uri: base URI of the query string (or NULL)
  *
- * Return value: a new &librdf_query object or NULL on failure
+ * Constructor - create a new #librdf_query object.
+ *
+ * Return value: a new #librdf_query object or NULL on failure
  */
 librdf_query*
 librdf_new_query_from_factory(librdf_world *world,
@@ -352,9 +364,10 @@ librdf_new_query_from_factory(librdf_world *world,
 
 
 /**
- * librdf_free_query - Destructor - destroy a librdf_query object
- * @query: &librdf_query object
+ * librdf_free_query:
+ * @query: #librdf_query object
  * 
+ * Destructor - destroy a #librdf_query object.
  **/
 void
 librdf_free_query(librdf_query* query) 
@@ -409,14 +422,16 @@ librdf_query_remove_query_result(librdf_query *query,
 
 
 /**
- * librdf_query_execute - Run the query on a model
- * @query: &librdf_query object
+ * librdf_query_execute:
+ * @query: #librdf_query object
  * @model: model to operate query on
+ *
+ * Run the query on a model.
  * 
  * Runs the query against the (previously registered) model
- * and returns a &librdf_query_results for the result objects.
+ * and returns a #librdf_query_results for the result objects.
  * 
- * Return value:  &librdf_query_results or NULL on failure
+ * Return value:  #librdf_query_results or NULL on failure
  **/
 librdf_query_results*
 librdf_query_execute(librdf_query* query, librdf_model* model)
@@ -436,8 +451,10 @@ librdf_query_execute(librdf_query* query, librdf_model* model)
 
 
 /**
- * librdf_query_get_limit - Get the query-specified limit on results
- * @query: &librdf_query query object
+ * librdf_query_get_limit:
+ * @query: #librdf_query query object
+ *
+ * Get the query-specified limit on results.
  *
  * This is the limit given in the query on the number of results allowed.
  *
@@ -454,10 +471,12 @@ librdf_query_get_limit(librdf_query *query)
 
 
 /**
- * librdf_query_set_limit - Set the query-specified limit on results
- * @query: &librdf_query query object
+ * librdf_query_set_limit:
+ * @query: #librdf_query query object
  * @limit: the limit on results, >=0 to set a limit, <0 to have no limit
  *
+ * Set the query-specified limit on results.
+ *
  * This is the limit given in the query on the number of results allowed.
  *
  * Return value: non-0 on failure
@@ -475,8 +494,10 @@ librdf_query_set_limit(librdf_query *query, int limit)
 
 
 /**
- * librdf_query_get_offset - Get the query-specified offset on results
- * @query: &librdf_query query object
+ * librdf_query_get_offset:
+ * @query: #librdf_query query object
+ *
+ * Get the query-specified offset on results.
  *
  * This is the offset given in the query on the number of results allowed.
  *
@@ -493,10 +514,12 @@ librdf_query_get_offset(librdf_query *query)
 
 
 /**
- * librdf_query_set_offset - Set the query-specified offset on results
- * @query: &librdf_query query object
+ * librdf_query_set_offset:
+ * @query: #librdf_query query object
  * @offset: offset for results, >=0 to set an offset, <0 to have no offset
  *
+ * Set the query-specified offset on results.
+ *
  * This is the offset given in the query on the number of results allowed.
  *
  * Return value: non-0 on failure
@@ -645,7 +668,7 @@ main(int argc, char *argv[])
                                                 format_uri, NULL,
                                                 &string_length);
   fprintf(stdout, "%s: Got query results string of length %d\n", program,
-          string_length);
+          (int)string_length);
 
   librdf_free_uri(format_uri);
   free(string);
