@@ -2,11 +2,10 @@
  *
  * rdf_query_rasqal.c - RDF Query with Rasqal
  *
- * $Id: rdf_query_rasqal.c,v 1.34 2005/05/18 14:14:00 cmdjb Exp $
+ * $Id: rdf_query_rasqal.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2004-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2004-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2004-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -962,7 +961,7 @@ librdf_query_rasqal_query_results_get_statement(void* context, int flags) {
     default:
       librdf_log(scontext->query->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_QUERY, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 
