@@ -2,11 +2,10 @@
  *
  * rdf_serializer.c - RDF Serializer (RDF triples to syntax) interface
  *
- * $Id: rdf_serializer.c,v 1.44 2005/04/17 20:07:41 cmdjb Exp $
+ * $Id: rdf_serializer.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2002-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2002-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2002-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -77,12 +76,14 @@ librdf_delete_serializer_factories(librdf_world *world)
 
 
 /**
- * librdf_serializer_register_factory - Register a serializer factory 
+ * librdf_serializer_register_factory:
  * @world: redland world object
  * @name: the name of the serializer
  * @mime_type: MIME type of the syntax (optional)
  * @uri_string: URI of the syntax (optional)
  * @factory: function to be called to register the factor parameters
+ *
+ * Register a serializer factory .
  * 
  **/
 void
@@ -151,11 +152,13 @@ librdf_serializer_register_factory(librdf_world *world,
 
 
 /**
- * librdf_get_serializer_factory - Get a serializer factory by name
+ * librdf_get_serializer_factory:
  * @world: redland world object
  * @name: the name of the factory (NULL or empty string if don't care)
  * @mime_type: the MIME type of the syntax (NULL or empty string if not used)
  * @type_uri: URI of syntax (NULL if not used)
+ *
+ * Get a serializer factory by name.
  * 
  * If all fields are NULL, this means any parser supporting
  * MIME Type "application/rdf+xml"
@@ -221,13 +224,15 @@ librdf_get_serializer_factory(librdf_world *world,
 
 
 /**
- * librdf_new_serializer - Constructor - create a new librdf_serializer object
+ * librdf_new_serializer:
  * @world: redland world object
  * @name: the serializer factory name
  * @mime_type: the MIME type of the syntax (NULL if not used)
  * @type_uri: URI of syntax (NULL if not used)
+ *
+ * Constructor - create a new #librdf_serializer object.
  * 
- * Return value: new &librdf_serializer object or NULL
+ * Return value: new #librdf_serializer object or NULL
  **/
 librdf_serializer*
 librdf_new_serializer(librdf_world *world, 
@@ -245,11 +250,13 @@ librdf_new_serializer(librdf_world *world,
 
 
 /**
- * librdf_new_serializer_from_factory - Constructor - create a new librdf_serializer object
+ * librdf_new_serializer_from_factory:
  * @world: redland world object
  * @factory: the serializer factory to use to create this serializer
+ *
+ * Constructor - create a new #librdf_serializer object.
  * 
- * Return value: new &librdf_serializer object or NULL
+ * Return value: new #librdf_serializer object or NULL
  **/
 librdf_serializer*
 librdf_new_serializer_from_factory(librdf_world *world, 
@@ -281,8 +288,10 @@ librdf_new_serializer_from_factory(librdf_world *world,
 
 
 /**
- * librdf_free_serializer - Destructor - destroys a librdf_serializer object
+ * librdf_free_serializer:
  * @serializer: the serializer
+ *
+ * Destructor - destroys a #librdf_serializer object.
  * 
  **/
 void
@@ -303,13 +312,15 @@ librdf_free_serializer(librdf_serializer *serializer)
 /* methods */
 
 /**
- * librdf_serializer_serialize_model - Write a serialized librdf_mode to a FILE*
+ * librdf_serializer_serialize_model:
  * @serializer: the serializer
  * @handle: file handle to serialize to
  * @base_uri: the base URI to use (or NULL)
- * @model: the &librdf_model model to use
- * 
- * DEPRECATED: Use librdf_serializer_serialize_model_to_file_handle
+ * @model: the #librdf_model model to use
+ *
+ * @Deprecated: Use librdf_serializer_serialize_model_to_file_handle()
+ *
+ * Write a serialized #librdf_model to a FILE*.
  *
  * Return value: non 0 on failure
  **/
@@ -325,11 +336,13 @@ librdf_serializer_serialize_model(librdf_serializer* serializer,
 
 
 /**
- * librdf_serializer_serialize_model_to_file_handle - Write a serialized librdf_model to a FILE*
+ * librdf_serializer_serialize_model_to_file_handle:
  * @serializer: the serializer
  * @handle: file handle to serialize to
  * @base_uri: the base URI to use (or NULL)
- * @model: the &librdf_model model to use
+ * @model: the #librdf_model model to use
+ *
+ * Write a serialized #librdf_model to a FILE*.
  * 
  * Return value: non 0 on failure
  **/
@@ -349,11 +362,13 @@ librdf_serializer_serialize_model_to_file_handle(librdf_serializer* serializer,
 
 
 /**
- * librdf_serializer_serialize_model_to_file - Write a serialized librdf_model to a file
+ * librdf_serializer_serialize_model_to_file:
  * @serializer: the serializer
  * @name: filename to serialize to
  * @base_uri: the base URI to use (or NULL)
- * @model: the &librdf_model model to use
+ * @model: the #librdf_model model to use
+ *
+ * Write a serialized #librdf_model to a file.
  * 
  * Return value: non 0 on failure
  **/
@@ -381,11 +396,13 @@ librdf_serializer_serialize_model_to_file(librdf_serializer* serializer,
 
 
 /**
- * librdf_serializer_serialize_model_to_counted_string - Write a serialized librdf_model to a counted string
+ * librdf_serializer_serialize_model_to_counted_string:
  * @serializer: the serializer
  * @base_uri: the base URI to use (or NULL)
- * @model: the &librdf_model model to use
+ * @model: the #librdf_model model to use
  * @length_p: pointer to store length or NULL
+ *
+ * Write a serialized #librdf_model to a counted string.
  * 
  * Return value: non 0 on failure
  **/
@@ -408,12 +425,14 @@ librdf_serializer_serialize_model_to_counted_string(librdf_serializer* serialize
 
 
 /**
- * librdf_serializer_serialize_model_to_string - Write a serialized librdf_model to a string
+ * librdf_serializer_serialize_model_to_string:
  * @serializer: the serializer
  * @base_uri: the base URI to use (or NULL)
- * @model: the &librdf_model model to use
+ * @model: the #librdf_model model to use
+ *
+ * Write a serialized #librdf_model to a string.
  * 
- * Return value: non 0 on failure
+ * Return value: NULL on failure
  **/
 unsigned char*
 librdf_serializer_serialize_model_to_string(librdf_serializer* serializer,
@@ -430,8 +449,38 @@ librdf_serializer_serialize_model_to_string(librdf_serializer* serializer,
 
 
 /**
- * librdf_init_serializer - INTERNAL - Initialise the librdf_serializer class
+ * librdf_serializer_serialize_model_to_iostream:
+ * @serializer: the serializer
+ * @base_uri: the base URI to use (or NULL)
+ * @model: the #librdf_model model to use
+ * @iostr: the #raptor_iostream to write to
+ *
+ * Write a serialized #librdf_model to a #raptor_iostream.
+ * 
+ * Return value: non-0 on failure
+ **/
+int
+librdf_serializer_serialize_model_to_iostream(librdf_serializer* serializer,
+                                              librdf_uri* base_uri,
+                                              librdf_model *model,
+                                              raptor_iostream* iostr)
+{
+  LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(serializer, librdf_serializer, 1);
+  LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(model, librdf_model, 1);
+
+  return serializer->factory->serialize_model_to_iostream(serializer->context,
+                                                          base_uri, model,
+                                                          iostr);
+}
+
+
+
+/**
+ * librdf_init_serializer:
  * @world: redland world object
+ *
+ * INTERNAL - Initialise the librdf_serializer class.
+ *
  **/
 void
 librdf_init_serializer(librdf_world *world) 
@@ -441,8 +490,11 @@ librdf_init_serializer(librdf_world *world)
 
 
 /**
- * librdf_finish_serializer - INTERNAL - Terminate the librdf_serializer class
+ * librdf_finish_serializer:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_serializer class.
+ *
  **/
 void
 librdf_finish_serializer(librdf_world *world) 
@@ -452,12 +504,14 @@ librdf_finish_serializer(librdf_world *world)
 
 
 /**
- * librdf_serializer_set_error - Set the serializer error handling function
+ * librdf_serializer_set_error:
  * @serializer: the serializer
  * @user_data: user data to pass to function
  * @error_fn: pointer to the function
+ *
+ * @Deprecated: Does nothing
  * 
- * DEPRECATED: Does nothing
+ * Set the serializer error handling function.
  * 
  **/
 void
@@ -468,12 +522,14 @@ librdf_serializer_set_error(librdf_serializer* serializer, void *user_data,
 
 
 /**
- * librdf_serializer_set_warning - Set the serializer warning handling function
+ * librdf_serializer_set_warning:
  * @serializer: the serializer
  * @user_data: user data to pass to function
  * @warning_fn: pointer to the function
- * 
- * DEPRECATED: Does nothing
+ *
+ * @Deprecated: Does nothing
+ *
+ * Set the serializer warning handling function.
  * 
  **/
 void
@@ -484,9 +540,11 @@ librdf_serializer_set_warning(librdf_serializer* serializer, void *user_data,
 
 
 /**
- * librdf_serializer_get_feature - Get the value of a serializer feature
+ * librdf_serializer_get_feature:
  * @serializer: serializer object
  * @feature: URI of feature
+ *
+ * Get the value of a serializer feature.
  * 
  * Return value: the value of the feature or NULL if no such feature
  * exists or the value is empty.
@@ -504,10 +562,12 @@ librdf_serializer_get_feature(librdf_serializer* serializer, librdf_uri *feature
 }
 
 /**
- * librdf_serializer_set_feature - Set the value of a serializer feature
+ * librdf_serializer_set_feature:
  * @serializer: serializer object
  * @feature: URI of feature
  * @value: value to set
+ *
+ * Set the value of a serializer feature.
  * 
  * Return value: non 0 on failure (negative if no such feature)
  **/
@@ -527,10 +587,12 @@ librdf_serializer_set_feature(librdf_serializer* serializer,
 }
 
 /**
- * librdf_serializer_set_namespace - Set a namespace URI/prefix mapping
+ * librdf_serializer_set_namespace:
  * @serializer: serializer object
  * @uri: URI of namespace
  * @prefix: prefix to use
+ *
+ * Set a namespace URI/prefix mapping.
  * 
  * NOTE: May not be implemented yet - depends on raptor_serializer work.
  * 
