@@ -2,11 +2,10 @@
  *
  * rdf_serializer_raptor.c - RDF Serializers via Raptor
  *
- * $Id: rdf_serializer_raptor.c,v 1.29 2005/04/08 16:50:01 cmdjb Exp $
+ * $Id: rdf_serializer_raptor.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2002-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2002-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2002-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -51,9 +50,11 @@ typedef struct {
 
 
 /**
- * librdf_serializer_raptor_init - Initialise the N-Triples RDF serializer
+ * librdf_serializer_raptor_init:
  * @serializer: the serializer
  * @context: context
+ *
+ * Initialise the N-Triples RDF serializer.
  * 
  * Return value: non 0 on failure
  **/
@@ -74,8 +75,11 @@ librdf_serializer_raptor_init(librdf_serializer *serializer, void *context)
 
 
 /**
- * librdf_serializer_raptor_terminate - Terminate the raptor RDF serializer
+ * librdf_serializer_raptor_terminate:
  * @context: context
+ *
+ * Terminate the raptor RDF serializer.
+ *
  **/
 static void
 librdf_serializer_raptor_terminate(void *context) 
@@ -88,11 +92,13 @@ librdf_serializer_raptor_terminate(void *context)
 
 
 /**
- * librdf_serializer_raptor_get_feature - Get a raptor parser feature
+ * librdf_serializer_raptor_get_feature:
  * @context: context
- * @feature: &librdf_uri of feature
+ * @feature: #librdf_uri of feature
  *
- * Return value: new &librdf_node value or NULL on failure
+ * Get a raptor parser feature.
+ *
+ * Return value: new #librdf_node value or NULL on failure
  **/
 static librdf_node*
 librdf_serializer_raptor_get_feature(void *context, librdf_uri* feature) {
@@ -174,14 +180,16 @@ librdf_serializer_raptor_serialize_statement(raptor_serializer *rserializer,
   } else {
     librdf_log(statement->world,
                0, LIBRDF_LOG_ERROR, LIBRDF_FROM_SERIALIZER, NULL,
-               "Do not know how to serialize triple subject type %d\n", librdf_node_get_type(subject));
+               "Do not know how to serialize triple subject type %d",
+               librdf_node_get_type(subject));
     return 1;
   }
 
   if(!librdf_node_is_resource(predicate)) {
     librdf_log(statement->world,
                0, LIBRDF_LOG_ERROR, LIBRDF_FROM_SERIALIZER, NULL,
-               "Do not know how to print triple predicate type %d\n", librdf_node_get_type(predicate));
+               "Do not know how to print triple predicate type %d",
+               librdf_node_get_type(predicate));
     return 1;
   }
 
@@ -215,7 +223,8 @@ librdf_serializer_raptor_serialize_statement(raptor_serializer *rserializer,
     default:
       librdf_log(statement->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_SERIALIZER, NULL,
-                 "Do not know how to print triple object type %d\n", librdf_node_get_type(object));
+                 "Do not know how to print triple object type %d",
+                 librdf_node_get_type(object));
       return 1;
   }
 
@@ -253,8 +262,9 @@ librdf_serializer_raptor_serialize_model_to_file_handle(void *context,
 {
   librdf_serializer_raptor_context* scontext=(librdf_serializer_raptor_context*)context;
   int rc=0;
-  
-  librdf_stream *stream=librdf_model_as_stream(model);
+  librdf_stream *stream;
+
+  stream=librdf_model_as_stream(model);
   if(!stream)
     return 1;
 
@@ -296,8 +306,9 @@ librdf_serializer_raptor_serialize_model_to_counted_string(void *context,
   unsigned char *string=NULL;
   size_t string_length=0;
   int rc=0;
-  
-  librdf_stream *stream=librdf_model_as_stream(model);
+  librdf_stream *stream;
+
+  stream=librdf_model_as_stream(model);
   if(!stream)
     return NULL;
 
@@ -341,10 +352,58 @@ librdf_serializer_raptor_serialize_model_to_counted_string(void *context,
 }
 
 
+static int
+librdf_serializer_raptor_serialize_model_to_iostream(void *context,
+                                                     librdf_uri* base_uri,
+                                                     librdf_model *model,
+                                                     raptor_iostream* iostr)
+{
+  librdf_serializer_raptor_context* scontext=(librdf_serializer_raptor_context*)context;
+  int rc=0;
+  librdf_stream *stream;
+  
+  if(!iostr)
+    return 1;
+  
+  stream=librdf_model_as_stream(model);
+  if(!stream)
+    return 1;
+
+  /* start the serialize */
+  rc=raptor_serialize_start(scontext->rdf_serializer, 
+                            (raptor_uri*)base_uri, iostr);
+
+  if(rc) {
+    librdf_free_stream(stream);    
+    raptor_free_iostream(iostr);
+    return 1;
+  }
+    
+  scontext->errors=0;
+  scontext->warnings=0;
+  raptor_serializer_set_error_handler(scontext->rdf_serializer, scontext, 
+                                      librdf_serializer_raptor_error_handler);
+  raptor_serializer_set_warning_handler(scontext->rdf_serializer, scontext, 
+                                        librdf_serializer_raptor_warning_handler);
+    
+  while(!librdf_stream_end(stream)) {
+    librdf_statement *statement=librdf_stream_get_object(stream);
+    librdf_serializer_raptor_serialize_statement(scontext->rdf_serializer, 
+                                                 statement);
+    librdf_stream_next(stream);
+  }
+  librdf_free_stream(stream);
+  raptor_serialize_end(scontext->rdf_serializer);
+
+  return 0;
+}
+
 
 /**
- * librdf_serializer_raptor_register_factory - Register the N-riples serializer with the RDF serializer factory
+ * librdf_serializer_raptor_register_factory:
  * @factory: factory
+ *
+ * Register the N-riples serializer with the RDF serializer factory.
  * 
  **/
 static void
@@ -361,12 +420,16 @@ librdf_serializer_raptor_register_factory(librdf_serializer_factory *factory)
 
   factory->serialize_model_to_file_handle = librdf_serializer_raptor_serialize_model_to_file_handle;
   factory->serialize_model_to_counted_string = librdf_serializer_raptor_serialize_model_to_counted_string;
+  factory->serialize_model_to_iostream = librdf_serializer_raptor_serialize_model_to_iostream;
 }
 
 
 /**
- * librdf_serializer_raptor_constructor - Initialise the raptor RDF serializer module
+ * librdf_serializer_raptor_constructor:
  * @world: redland world object
+ *
+ * Initialise the raptor RDF serializer module.
+ *
  **/
 void
 librdf_serializer_raptor_constructor(librdf_world *world)
