@@ -2,11 +2,10 @@
  *
  * rdf_storage.c - RDF Storage (Triple store) interface
  *
- * $Id: rdf_storage.c,v 1.86 2005/05/18 16:05:31 cmdjb Exp $
+ * $Id: rdf_storage.c 8543 2006-01-26 06:34:54Z cmdjb $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -65,8 +64,10 @@ static librdf_iterator* librdf_storage_node_stream_to_node_create(librdf_storage
 
 
 /**
- * librdf_init_storage - INTERNAL - Initialise the librdf_storage module
+ * librdf_init_storage:
  * @world: redland world object
+ *
+ * INTERNAL - Initialise the librdf_storage module.
  * 
  * Initialises and registers all
  * compiled storage modules.  Must be called before using any of the storage
@@ -78,6 +79,9 @@ librdf_init_storage(librdf_world *world)
 #ifdef STORAGE_MYSQL
   librdf_init_storage_mysql(world);
 #endif
+#ifdef STORAGE_POSTGRESQL
+  librdf_init_storage_postgresql(world);
+#endif
 #ifdef STORAGE_TSTORE
   librdf_init_storage_tstore(world);
 #endif
@@ -95,8 +99,11 @@ librdf_init_storage(librdf_world *world)
 
 
 /**
- * librdf_finish_storage - INTERNAL - Terminate the librdf_storage module
+ * librdf_finish_storage:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_storage module.
+ *
  **/
 void
 librdf_finish_storage(librdf_world *world) 
@@ -135,12 +142,13 @@ librdf_delete_storage_factories(void)
 /* class methods */
 
 /**
- * librdf_storage_register_factory - Register a storage factory
+ * librdf_storage_register_factory:
  * @world: redland world object
  * @name: the storage factory name
  * @label: the storage factory label
  * @factory: pointer to function to call to register the factory
- * 
+ *
+ * Register a storage factory.
  **/
 void
 librdf_storage_register_factory(librdf_world* world,
@@ -174,7 +182,7 @@ librdf_storage_register_factory(librdf_world* world,
       LIBRDF_FREE(librdf_storage, storage);
       librdf_log(world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "storage %s already registered\n", h->name);
+                 "storage %s already registered", h->name);
       return;
     }
   }
@@ -200,8 +208,10 @@ librdf_storage_register_factory(librdf_world* world,
 
 
 /**
- * librdf_get_storage_factory - Get a storage factory by name
+ * librdf_get_storage_factory:
  * @name: the factory name or NULL for the default factory
+ *
+ * Get a storage factory by name.
  * 
  * Return value: the factory object or NULL if there is no such factory
  **/
@@ -235,10 +245,12 @@ librdf_get_storage_factory (const char *name)
 
 
 /**
- * librdf_storage_enumerate - Get information on storages
+ * librdf_storage_enumerate:
  * @counter: index into the list of storages
  * @name: pointer to store the name of the storage (or NULL)
  * @label: pointer to store syntax readable label (or NULL)
+ *
+ * Get information on storages.
  * 
  * Return value: non 0 on failure of if counter is out of range
  **/
@@ -267,16 +279,19 @@ librdf_storage_enumerate(const unsigned int counter,
 
 
 /**
- * librdf_new_storage - Constructor - create a new librdf_storage object
+ * librdf_new_storage:
  * @world: redland world object
  * @storage_name: the storage factory name
  * @name: an identifier for the storage
  * @options_string: options to initialise storage
  *
+ * Constructor - create a new #librdf_storage object.
+ *
  * The options are encoded as described in librdf_hash_from_string()
  * and can be NULL if none are required.
  *
- * Return value: a new &librdf_storage object or NULL on failure
+ * Return value: a new #librdf_storage object or NULL on failure
+ *
  */
 librdf_storage*
 librdf_new_storage (librdf_world *world, 
@@ -308,15 +323,18 @@ librdf_new_storage (librdf_world *world,
 
 
 /**
- * librdf_new_storage_with_options - Constructor - create a new librdf_storage object
+ * librdf_new_storage_with_options:
  * @world: redland world object
  * @storage_name: the storage factory name
  * @name: an identifier for the storage
- * @options: &librdf_hash of options to use
+ * @options: #librdf_hash of options to use
+ *
+ * Constructor - create a new #librdf_storage object.
  *
  * The options can be NULL if none are required.
  *
- * Return value: a new &librdf_storage object or NULL on failure
+ * Return value: a new #librdf_storage object or NULL on failure
+ *
  */
 librdf_storage*
 librdf_new_storage_with_options (librdf_world *world, 
@@ -344,7 +362,7 @@ librdf_new_storage_with_options (librdf_world *world,
 
 /**
  * librdf_new_storage_from_storage - Copy constructor - create a new librdf_storage object from an existing one
- * @old_storage: the existing storage &librdf_storage to use
+ * @old_storage: the existing storage #librdf_storage to use
  *
  * Should create a new storage in the same context as the existing one
  * as appropriate for the storage.  For example, in a RDBMS storage
@@ -353,7 +371,8 @@ librdf_new_storage_with_options (librdf_world *world,
  * a new identifier for the storage, maybe based on the existing
  * storage identifier.
  *
- * Return value: a new &librdf_storage object or NULL on failure
+ * Return value: a new #librdf_storage object or NULL on failure
+ *
  */
 librdf_storage*
 librdf_new_storage_from_storage(librdf_storage* old_storage) 
@@ -364,8 +383,9 @@ librdf_new_storage_from_storage(librdf_storage* old_storage)
 
   if(!old_storage->factory->clone) {
     librdf_log(old_storage->world,
-                 0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-               "clone method not implemented for storage factory %s", old_storage->factory->name);
+               0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
+               "clone method not implemented for storage factory %s", 
+               old_storage->factory->name);
     return NULL;
   }
 
@@ -404,16 +424,19 @@ librdf_new_storage_from_storage(librdf_storage* old_storage)
 
 
 /**
- * librdf_new_storage_from_factory - Constructor - create a new librdf_storage object
+ * librdf_new_storage_from_factory:
  * @world: redland world object
  * @factory: the factory to use to construct the storage
  * @name: name to use for storage
- * @options: &librdf_hash of options to initialise storage
+ * @options: #librdf_hash of options to initialise storage
+ *
+ * Constructor - create a new #librdf_storage object.
  *
  * If the options are present, they become owned by the storage
  * and should no longer be used.
  *
- * Return value: a new &librdf_storage object or NULL on failure
+ * Return value: a new #librdf_storage object or NULL on failure
+ *
  */
 librdf_storage*
 librdf_new_storage_from_factory (librdf_world *world,
@@ -461,9 +484,10 @@ librdf_new_storage_from_factory (librdf_world *world,
 
 
 /**
- * librdf_free_storage - Destructor - destroy a librdf_storage object
- * @storage: &librdf_storage object
- * 
+ * librdf_free_storage:
+ * @storage: #librdf_storage object
+ *
+ * Destructor - destroy a #librdf_storage object.
  **/
 void
 librdf_free_storage (librdf_storage* storage) 
@@ -498,10 +522,12 @@ librdf_storage_remove_reference(librdf_storage *storage)
 /* methods */
 
 /**
- * librdf_storage_open - Start a model / storage association
- * @storage: &librdf_storage object
+ * librdf_storage_open:
+ * @storage: #librdf_storage object
  * @model: model stored
  *
+ * Start a model / storage association.
+ *
  * This is ended with librdf_storage_close()
  * 
  * Return value: non 0 on failure
@@ -516,8 +542,10 @@ librdf_storage_open(librdf_storage* storage, librdf_model* model)
 
 
 /**
- * librdf_storage_close - End a model / storage association
- * @storage: &librdf_storage object
+ * librdf_storage_close:
+ * @storage: #librdf_storage object
+ *
+ * End a model / storage association.
  * 
  * Return value: non 0 on failure
  **/
@@ -531,8 +559,10 @@ librdf_storage_close(librdf_storage* storage)
 
 
 /**
- * librdf_storage_size - Get the number of statements stored
- * @storage: &librdf_storage object
+ * librdf_storage_size:
+ * @storage: #librdf_storage object
+ *
+ * Get the number of statements stored.
  * 
  * Return value: The number of statements or < 0 if cannot be determined
  **/
@@ -546,9 +576,11 @@ librdf_storage_size(librdf_storage* storage)
 
 
 /**
- * librdf_storage_add_statement - Add a statement to a storage
- * @storage: &librdf_storage object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_add_statement:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage.
  * 
  * The passed-in statement is copied when added to the store, not
  * shared with the store.  
@@ -572,9 +604,11 @@ librdf_storage_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_add_statements - Add a stream of statements to the storage
- * @storage: &librdf_storage object
- * @statement_stream: &librdf_stream of statements
+ * librdf_storage_add_statements:
+ * @storage: #librdf_storage object
+ * @statement_stream: #librdf_stream of statements
+ *
+ * Add a stream of statements to the storage.
  * 
  * If any of the statements already exists in the store, they are not
  * added unless Redland contexts are being used.
@@ -612,9 +646,11 @@ librdf_storage_add_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_remove_statement - Remove a statement from the storage
- * @storage: &librdf_storage object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_remove_statement:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from the storage.
  * 
  * Return value: non 0 on failure
  **/
@@ -632,9 +668,11 @@ librdf_storage_remove_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_contains_statement - Test if a given statement is present in the storage
- * @storage: &librdf_storage object
- * @statement: &librdf_statement statement to check
+ * librdf_storage_contains_statement:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement statement to check
+ *
+ * Test if a given statement is present in the storage.
  *
  * Return value: non 0 if the storage contains the statement
  **/
@@ -650,10 +688,12 @@ librdf_storage_contains_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_serialise - Serialise the storage as a librdf_stream of statemetns
- * @storage: &librdf_storage object
+ * librdf_storage_serialise:
+ * @storage: #librdf_storage object
+ *
+ * Serialise the storage as a librdf_stream of statemetns.
  * 
- * Return value: &librdf_stream of statements or NULL on failure
+ * Return value: #librdf_stream of statements or NULL on failure
  **/
 librdf_stream*
 librdf_storage_serialise(librdf_storage* storage) 
@@ -663,15 +703,17 @@ librdf_storage_serialise(librdf_storage* storage)
 
 
 /**
- * librdf_storage_find_statements - search the storage for matching statements
- * @storage: &librdf_storage object
- * @statement: &librdf_statement partial statement to find
+ * librdf_storage_find_statements:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement partial statement to find
+ *
+ * Search the storage for matching statements.
  * 
  * Searches the storage for a (partial) statement as described in
- * librdf_statement_match() and returns a &librdf_stream of
- * matching &librdf_statement objects.
+ * librdf_statement_match() and returns a #librdf_stream of
+ * matching #librdf_statement objects.
  * 
- * Return value:  &librdf_stream of matching statements (may be empty) or NULL on failure
+ * Return value:  #librdf_stream of matching statements (may be empty) or NULL on failure
  **/
 librdf_stream*
 librdf_storage_find_statements(librdf_storage* storage,
@@ -779,7 +821,7 @@ librdf_storage_stream_to_node_iterator_get_method(void* iterator, int flags)
         default: /* error */
           librdf_log(statement->world,
                      0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                     "Unknown statement part %d\n", context->want);
+                     "Unknown statement part %d", context->want);
           node=NULL;
       }
       break;
@@ -791,7 +833,7 @@ librdf_storage_stream_to_node_iterator_get_method(void* iterator, int flags)
     default:
       librdf_log(statement->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       node=NULL;
   }
   
@@ -833,7 +875,7 @@ librdf_storage_stream_to_node_iterator_finished(void* iterator)
  *
  * node1 and node2 cannot both be NULL
  * 
- * Return value: a new &librdf_iterator or NULL on failure
+ * Return value: a new #librdf_iterator or NULL on failure
  **/
 static librdf_iterator*
 librdf_storage_node_stream_to_node_create(librdf_storage* storage,
@@ -878,7 +920,7 @@ librdf_storage_node_stream_to_node_create(librdf_storage* storage,
       librdf_free_statement(partial_statement);
       librdf_log(storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Illegal statement part %d seen\n", want);
+                 "Illegal statement part %d seen", want);
       return NULL;
   }
   
@@ -910,15 +952,17 @@ librdf_storage_node_stream_to_node_create(librdf_storage* storage,
 
 
 /**
- * librdf_storage_get_sources - return the sources (subjects) of arc in an RDF graph given arc (predicate) and target (object)
- * @storage: &librdf_storage object
- * @arc: &librdf_node arc
- * @target: &librdf_node target
+ * librdf_storage_get_sources:
+ * @storage: #librdf_storage object
+ * @arc: #librdf_node arc
+ * @target: #librdf_node target
+ *
+ * Return the sources (subjects) of arc in an RDF graph given arc (predicate) and target (object).
  * 
  * Searches the storage for arcs matching the given arc and target
- * and returns a list of the source &librdf_node objects as an iterator
+ * and returns a list of the source #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_storage_get_sources(librdf_storage *storage,
@@ -937,15 +981,17 @@ librdf_storage_get_sources(librdf_storage *storage,
 
 
 /**
- * librdf_storage_get_arcs - return the arcs (predicates) of an arc in an RDF graph given source (subject) and target (object)
- * @storage: &librdf_storage object
- * @source: &librdf_node source
- * @target: &librdf_node target
+ * librdf_storage_get_arcs:
+ * @storage: #librdf_storage object
+ * @source: #librdf_node source
+ * @target: #librdf_node target
+ *
+ * Return the arcs (predicates) of an arc in an RDF graph given source (subject) and target (object).
  * 
  * Searches the storage for arcs matching the given source and target
- * and returns a list of the arc &librdf_node objects as an iterator
+ * and returns a list of the arc #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_storage_get_arcs(librdf_storage *storage,
@@ -964,15 +1010,17 @@ librdf_storage_get_arcs(librdf_storage *storage,
 
 
 /**
- * librdf_storage_get_targets - return the targets (objects) of an arc in an RDF graph given source (subject) and arc (predicate)
- * @storage: &librdf_storage object
- * @source: &librdf_node source
- * @arc: &librdf_node arc
+ * librdf_storage_get_targets:
+ * @storage: #librdf_storage object
+ * @source: #librdf_node source
+ * @arc: #librdf_node arc
+ *
+ * Return the targets (objects) of an arc in an RDF graph given source (subject) and arc (predicate).
  * 
  * Searches the storage for targets matching the given source and arc
- * and returns a list of the source &librdf_node objects as an iterator
+ * and returns a list of the source #librdf_node objects as an iterator
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_storage_get_targets(librdf_storage *storage,
@@ -991,11 +1039,13 @@ librdf_storage_get_targets(librdf_storage *storage,
 
 
 /**
- * librdf_storage_get_arcs_in - return the properties pointing to the given resource
- * @storage: &librdf_storage object
- * @node: &librdf_node resource node
+ * librdf_storage_get_arcs_in:
+ * @storage: #librdf_storage object
+ * @node: #librdf_node resource node
+ *
+ * Return the properties pointing to the given resource.
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_storage_get_arcs_in(librdf_storage *storage, librdf_node *node) 
@@ -1012,11 +1062,13 @@ librdf_storage_get_arcs_in(librdf_storage *storage, librdf_node *node)
 
 
 /**
- * librdf_storage_get_arcs_out - return the properties pointing from the given resource
- * @storage: &librdf_storage object
- * @node: &librdf_node resource node
+ * librdf_storage_get_arcs_out:
+ * @storage: #librdf_storage object
+ * @node: #librdf_node resource node
+ *
+ * Return the properties pointing from the given resource.
  * 
- * Return value:  &librdf_iterator of &librdf_node objects (may be empty) or NULL on failure
+ * Return value:  #librdf_iterator of #librdf_node objects (may be empty) or NULL on failure
  **/
 librdf_iterator*
 librdf_storage_get_arcs_out(librdf_storage *storage, librdf_node *node) 
@@ -1029,10 +1081,12 @@ librdf_storage_get_arcs_out(librdf_storage *storage, librdf_node *node)
 
 
 /**
- * librdf_storage_has_arc_in - check if a node has a given property pointing to it
- * @storage: &librdf_storage object
- * @node: &librdf_node resource node
- * @property: &librdf_node property node
+ * librdf_storage_has_arc_in:
+ * @storage: #librdf_storage object
+ * @node: #librdf_node resource node
+ * @property: #librdf_node property node
+ *
+ * Check if a node has a given property pointing to it.
  * 
  * Return value: non 0 if arc property does point to the resource node
  **/
@@ -1063,10 +1117,12 @@ librdf_storage_has_arc_in(librdf_storage *storage, librdf_node *node,
 
 
 /**
- * librdf_storage_has_arc_out - check if a node has a given property pointing from it
- * @storage: &librdf_storage object
- * @node: &librdf_node resource node
- * @property: &librdf_node property node
+ * librdf_storage_has_arc_out:
+ * @storage: #librdf_storage object
+ * @node: #librdf_node resource node
+ * @property: #librdf_node property node
+ *
+ * Check if a node has a given property pointing from it.
  * 
  * Return value: non 0 if arc property does point from the resource node
  **/
@@ -1098,10 +1154,12 @@ librdf_storage_has_arc_out(librdf_storage *storage, librdf_node *node,
 
 
 /**
- * librdf_storage_context_add_statement - Add a statement to a storage in a context
- * @storage: &librdf_storage object
- * @context: &librdf_node context node
- * @statement: &librdf_statement statement to add
+ * librdf_storage_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context: #librdf_node context node
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage in a context.
  * 
  * If @context is NULL, this is equivalent to librdf_storage_add_statement
  *
@@ -1125,10 +1183,12 @@ librdf_storage_context_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_context_add_statements - Add statements to a storage with a context
- * @storage: &librdf_storage object
- * @context: &librdf_node context
- * @stream: &librdf_stream stream object
+ * librdf_storage_context_add_statements:
+ * @storage: #librdf_storage object
+ * @context: #librdf_node context
+ * @stream: #librdf_stream stream object
+ *
+ * Add statements to a storage with a context.
  * 
  * If @context is NULL, this is equivalent to librdf_storage_add_statements
  *
@@ -1172,10 +1232,12 @@ librdf_storage_context_add_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_context_remove_statement - Remove a statement from a storage in a context
- * @storage: &librdf_storage object
- * @context: &librdf_node context node
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context: #librdf_node context node
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage in a context.
  * 
  * If @context is NULL, this is equivalent to librdf_storage_remove_statement
  *
@@ -1197,9 +1259,11 @@ librdf_storage_context_remove_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_context_remove_statements - Remove statements from a storage with the given context
- * @storage: &librdf_storage object
- * @context: &librdf_uri context
+ * librdf_storage_context_remove_statements:
+ * @storage: #librdf_storage object
+ * @context: #librdf_uri context
+ *
+ * Remove statements from a storage with the given context.
  * 
  * If @context is NULL, this is equivalent to librdf_storage_remove_statements
  *
@@ -1236,11 +1300,13 @@ librdf_storage_context_remove_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_context_as_stream - List all statements in a storage context
- * @storage: &librdf_storage object
- * @context: &librdf_node context node
+ * librdf_storage_context_as_stream:
+ * @storage: #librdf_storage object
+ * @context: #librdf_node context node
+ *
+ * List all statements in a storage context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 librdf_stream*
 librdf_storage_context_as_stream(librdf_storage* storage, librdf_node* context)
@@ -1252,14 +1318,16 @@ librdf_storage_context_as_stream(librdf_storage* storage, librdf_node* context)
 
 
 /**
- * librdf_storage_context_serialise - List all statements in a storage context (DEPRECATED)
- * @storage: &librdf_storage object
- * @context: &librdf_node context node
+ * librdf_storage_context_serialise:
+ * @storage: #librdf_storage object
+ * @context: #librdf_node context node
+ *
+ * List all statements in a storage context (DEPRECATED).
  * 
  * DEPRECATED to reduce confusion with the librdf_serializer class.
  * Please use librdf_storage_context_as_stream.
  *
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 librdf_stream*
 librdf_storage_context_serialise(librdf_storage* storage,
@@ -1271,28 +1339,56 @@ librdf_storage_context_serialise(librdf_storage* storage,
 }
 
 
+/**
+ * librdf_storage_supports_query:
+ * @storage: #librdf_storage object
+ * @query: #librdf_query query object
+ * 
+ * Check if a storage system supports a query language.
+ * 
+ * Not implemented.
+ *
+ * Return value: non-0 if the query is supported.
+ **/
 int
 librdf_storage_supports_query(librdf_storage* storage, librdf_query *query)
 {
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(storage, librdf_storage, 0);
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(query, librdf_query, 0);
 
-  /* FIXME - no storage system supports a query language at present */
   return 0;
 }
 
 
+/**
+ * librdf_storage_query_execute:
+ * @storage: #librdf_storage object
+ * @query: #librdf_query query object
+ * 
+ * Run the given query against the storage.
+ * 
+ * Not implemented.
+ *
+ * Return value: #librdf_query_results or NULL on failure
+ **/
 librdf_query_results*
 librdf_storage_query_execute(librdf_storage* storage, librdf_query *query) 
 {
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(storage, librdf_storage, NULL);
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(query, librdf_query, NULL);
 
-  /* FIXME - no storage system supports querying yet */
   return NULL;
 }
 
 
+/**
+ * librdf_storage_sync:
+ * @storage: #librdf_storage object
+ * 
+ * Synchronise the storage to the storage implementation.
+ * 
+ * Return value: non-0 on failure
+ **/
 int
 librdf_storage_sync(librdf_storage* storage) 
 {
@@ -1305,17 +1401,19 @@ librdf_storage_sync(librdf_storage* storage)
 
 
 /**
- * librdf_storage_find_statements_in_context - search the storage for matching statements in a given context
- * @storage: &librdf_storage object
- * @statement: &librdf_statement partial statement to find
- * @context_node: context &librdf_node (or NULL)
+ * librdf_storage_find_statements_in_context:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement partial statement to find
+ * @context_node: context #librdf_node (or NULL)
+ *
+ * Search the storage for matching statements in a given context.
  * 
  * Searches the storage for a (partial) statement as described in
  * librdf_statement_match() in the given context and returns a
- * &librdf_stream of matching &librdf_statement objects.  If
+ * #librdf_stream of matching #librdf_statement objects.  If
  * context is NULL, this is equivalent to librdf_storage_find_statements.
  * 
- * Return value: &librdf_stream of matching statements (may be empty) or NULL on failure
+ * Return value: #librdf_stream of matching statements (may be empty) or NULL on failure
  **/
 librdf_stream*
 librdf_storage_find_statements_in_context(librdf_storage* storage, librdf_statement* statement, librdf_node* context_node) 
@@ -1347,13 +1445,15 @@ librdf_storage_find_statements_in_context(librdf_storage* storage, librdf_statem
 
 
 /**
- * librdf_storage_get_contexts - return the list of contexts in the store
- * @storage: &librdf_storage object
+ * librdf_storage_get_contexts:
+ * @storage: #librdf_storage object
+ *
+ * Return the list of contexts in the store.
  * 
- * Returns an iterator of &librdf_node context nodes for each
+ * Returns an iterator of #librdf_node context nodes for each
  * context in the store.
  *
- * Return value: &librdf_iterator of context nodes or NULL on failure or if contexts are not supported
+ * Return value: #librdf_iterator of context nodes or NULL on failure or if contexts are not supported
  **/
 librdf_iterator*
 librdf_storage_get_contexts(librdf_storage* storage) 
@@ -1369,11 +1469,13 @@ librdf_storage_get_contexts(librdf_storage* storage)
 
 
 /**
- * librdf_storage_get_feature - get the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
+ * librdf_storage_get_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a storage feature.
  * 
- * Return value: new &librdf_node feature value or NULL if no such feature
+ * Return value: new #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 librdf_node*
@@ -1389,10 +1491,12 @@ librdf_storage_get_feature(librdf_storage* storage, librdf_uri* feature)
 
 
 /**
- * librdf_storage_set_feature - set the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
- * @value: &librdf_node feature property value
+ * librdf_storage_set_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ * @value: #librdf_node feature property value
+ *
+ * Set the value of a storage feature.
  * 
  * Return value: non 0 on failure (negative if no such feature)
  **/
@@ -1411,21 +1515,23 @@ librdf_storage_set_feature(librdf_storage* storage, librdf_uri* feature,
 
 
 /**
- * librdf_storage_find_statements_with_options - search the storage for matching statements with match options
- * @storage: &librdf_storage object
- * @statement: &librdf_statement partial statement to find
- * @context_node: &librdf_node context node or NULL.
- * @options: &librdf_hash of matching options or NULL
+ * librdf_storage_find_statements_with_options:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement partial statement to find
+ * @context_node: #librdf_node context node or NULL.
+ * @options: #librdf_hash of matching options or NULL
+ *
+ * Search the storage for matching statements with match options.
  * 
  * Searches the storage for a (partial) statement as described in
- * librdf_statement_match() and returns a &librdf_stream of
- * matching &librdf_statement objects.
+ * librdf_statement_match() and returns a #librdf_stream of
+ * matching #librdf_statement objects.
  * 
  * If options is given then the match is made according to
  * the given options.  If options is NULL, this is equivalent
  * to librdf_storage_find_statements_in_context.
  * 
- * Return value:  &librdf_stream of matching statements (may be empty) or NULL on failure
+ * Return value:  #librdf_stream of matching statements (may be empty) or NULL on failure
  **/
 librdf_stream*
 librdf_storage_find_statements_with_options(librdf_storage* storage,
