@@ -2,11 +2,10 @@
  *
  * rdf_storage_hashes.c - RDF Storage as Hashes Implementation
  *
- * $Id: rdf_storage_hashes.c,v 1.79 2005/05/18 16:05:32 cmdjb Exp $
+ * $Id: rdf_storage_hashes.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2000-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -45,7 +44,6 @@
 
 #include <redland.h>
 #include <rdf_storage.h>
-#include <rdf_storage_hashes.h>
 
 
 typedef struct 
@@ -498,6 +496,8 @@ librdf_storage_hashes_open(librdf_storage* storage, librdf_model* model)
 /**
  * librdf_storage_hashes_close:
  * @storage: 
+ *
+ * .
  * 
  * Close the storage hashes storage, and free all content since there is no 
  * persistance.
@@ -894,7 +894,7 @@ librdf_storage_hashes_serialise_get_statement(void* context, int flags)
       default:
         librdf_log(scontext->iterator->world,
                    0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                   "Unimplemented flags %d seen\n", flags);
+                   "Unimplemented flags %d seen", flags);
         return NULL;
     }
   }
@@ -946,7 +946,7 @@ librdf_storage_hashes_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unimplemented flags %d seen\n", flags);
+                 "Unimplemented flags %d seen", flags);
       return NULL;
   }
 }
@@ -985,13 +985,15 @@ librdf_storage_hashes_serialise_finished(void* context)
  * librdf_storage_hashes_find_statements:
  * @storage: the storage
  * @statement: the statement to match
+ *
+ * .
  * 
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
- * Uses &librdf_statement_match to do the matching.
+ * Uses #librdf_statement_match to do the matching.
  * 
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_hashes_find_statements(librdf_storage* storage, librdf_statement* statement)
@@ -1095,7 +1097,7 @@ librdf_storage_hashes_node_iterator_get_method(void* iterator, int flags)
   if(flags != LIBRDF_ITERATOR_GET_METHOD_GET_OBJECT) {
     librdf_log(context->iterator->world,
                0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-               "Unimplemented iterator method %d\n", flags);
+               "Unimplemented iterator method %d", flags);
     return NULL;
   }
 
@@ -1127,7 +1129,7 @@ librdf_storage_hashes_node_iterator_get_method(void* iterator, int flags)
     default: /* error */
       librdf_log(context->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Illegal statement part %d seen\n", context->want);
+                 "Illegal statement part %d seen", context->want);
       return NULL;
   }
 
@@ -1168,7 +1170,7 @@ librdf_storage_hashes_node_iterator_get_method(void* iterator, int flags)
     default: /* error */
       librdf_log(context->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Illegal statement part %d seen\n", context->want);
+                 "Illegal statement part %d seen", context->want);
       return NULL;
   }
   
@@ -1210,7 +1212,7 @@ librdf_storage_hashes_node_iterator_finished(void* iterator)
  * @hash_index: the index of the hash to iterate over
  * @want: the field required from the hash value
  * 
- * Return value: a new &librdf_iterator or NULL on failure
+ * Return value: a new #librdf_iterator or NULL on failure
  **/
 static librdf_iterator*
 librdf_storage_hashes_node_iterator_create(librdf_storage* storage, 
@@ -1282,7 +1284,7 @@ librdf_storage_hashes_node_iterator_create(librdf_storage* storage,
       LIBRDF_FREE(librdf_storage_hashes_node_iterator_context, icontext);
       librdf_log(storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Illegal statement part %d seen\n", want);
+                 "Illegal statement part %d seen", want);
       return NULL;
   }
 
@@ -1370,10 +1372,12 @@ librdf_storage_hashes_find_targets(librdf_storage* storage,
 }
 
 /**
- * librdf_storage_hashes_context_add_statement - Add a statement to a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_hashes_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -1399,7 +1403,8 @@ librdf_storage_hashes_context_add_statement(librdf_storage* storage,
 
   size=librdf_node_encode(context_node, NULL, 0);
   key.data=(char*)LIBRDF_MALLOC(cstring, size);
-  key.size=librdf_node_encode(context_node, (unsigned char*)key.data, size);
+  key.size=librdf_node_encode(context_node, 
+                               (unsigned char*)key.data, size);
 
   size=librdf_statement_encode(statement, NULL, 0);
 
@@ -1415,10 +1420,12 @@ librdf_storage_hashes_context_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_hashes_context_remove_statement - Remove a statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_hashes_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -1443,7 +1450,8 @@ librdf_storage_hashes_context_remove_statement(librdf_storage* storage,
   
   size=librdf_node_encode(context_node, NULL, 0);
   key.data=(char*)LIBRDF_MALLOC(cstring, size);
-  key.size=librdf_node_encode(context_node, (unsigned char*)key.data, size);
+  key.size=librdf_node_encode(context_node,
+                               (unsigned char*)key.data, size);
 
   size=librdf_statement_encode(statement, NULL, 0);
 
@@ -1472,11 +1480,13 @@ typedef struct {
 
 
 /**
- * librdf_storage_hashes_context_serialise - List all statements in a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_hashes_context_serialise:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ *
+ * List all statements in a storage context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 static librdf_stream*
 librdf_storage_hashes_context_serialise(librdf_storage* storage,
@@ -1608,7 +1618,7 @@ librdf_storage_hashes_context_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unimplemented flags %d seen\n", flags);
+                 "Unimplemented flags %d seen", flags);
       return NULL;
   }
 
@@ -1714,7 +1724,7 @@ librdf_storage_hashes_get_contexts_get_method(void* iterator, int flags)
     default:
       librdf_log(icontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       result=NULL;
       break;
   }
@@ -1744,10 +1754,12 @@ librdf_storage_hashes_get_contexts_finished(void* iterator)
 
 
 /**
- * librdf_storage_hashes_context_get_contexts - List all context nodes in a storage
- * @storage: &librdf_storage object
+ * librdf_storage_hashes_context_get_contexts:
+ * @storage: #librdf_storage object
+ *
+ * List all context nodes in a storage.
  * 
- * Return value: &librdf_iterator of context_nodes or NULL on failure or no contexts
+ * Return value: #librdf_iterator of context_nodes or NULL on failure or no contexts
  **/
 static librdf_iterator*
 librdf_storage_hashes_get_contexts(librdf_storage* storage) 
@@ -1798,11 +1810,13 @@ librdf_storage_hashes_get_contexts(librdf_storage* storage)
 
 
 /**
- * librdf_storage_hashes_get_feature - get the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
+ * librdf_storage_hashes_get_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a storage feature.
  * 
- * Return value: new &librdf_node feature value or NULL if no such feature
+ * Return value: new #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 static librdf_node*
