@@ -2,11 +2,10 @@
  *
  * rdf_storage_list.c - RDF Storage in memory as a list implementation
  *
- * $Id: rdf_storage_list.c,v 1.53 2005/05/18 16:05:34 cmdjb Exp $
+ * $Id: rdf_storage_list.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2000-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -186,6 +185,8 @@ librdf_storage_list_open(librdf_storage* storage, librdf_model* model)
 /**
  * librdf_storage_list_close:
  * @storage: the storage
+ *
+ * .
  * 
  * Close the storage list storage, and free all content since there is no 
  * persistance.
@@ -405,7 +406,7 @@ librdf_storage_list_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -430,13 +431,15 @@ librdf_storage_list_serialise_finished(void* context)
  * librdf_storage_list_find_statements:
  * @storage: the storage
  * @statement: the statement to match
+ *
+ * .
  * 
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
- * Uses &librdf_statement_match to do the matching.
+ * Uses #librdf_statement_match to do the matching.
  * 
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_list_find_statements(librdf_storage* storage, librdf_statement* statement)
@@ -456,10 +459,12 @@ librdf_storage_list_find_statements(librdf_storage* storage, librdf_statement* s
 
 
 /**
- * librdf_storage_list_context_add_statement - Add a statement to a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_list_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -530,10 +535,12 @@ librdf_storage_list_context_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_list_context_remove_statement - Remove a statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_list_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -600,11 +607,13 @@ typedef struct {
 
 
 /**
- * librdf_storage_list_context_serialise - List all statements in a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_list_context_serialise:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ *
+ * List all statements in a storage context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 static librdf_stream*
 librdf_storage_list_context_serialise(librdf_storage* storage,
@@ -713,7 +722,7 @@ librdf_storage_list_context_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
   
@@ -810,7 +819,7 @@ librdf_storage_list_get_contexts_get_method(void* iterator, int flags)
     default:
       librdf_log(icontext->iterator->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       result=NULL;
       break;
   }
@@ -840,10 +849,12 @@ librdf_storage_list_get_contexts_finished(void* iterator)
 
 
 /**
- * librdf_storage_list_context_get_contexts - List all context nodes in a storage
- * @storage: &librdf_storage object
+ * librdf_storage_list_context_get_contexts:
+ * @storage: #librdf_storage object
+ *
+ * List all context nodes in a storage.
  * 
- * Return value: &librdf_iterator of context_nodes or NULL on failure or no contexts
+ * Return value: #librdf_iterator of context_nodes or NULL on failure or no contexts
  **/
 static librdf_iterator*
 librdf_storage_list_get_contexts(librdf_storage* storage) 
@@ -891,11 +902,13 @@ librdf_storage_list_get_contexts(librdf_storage* storage)
 
 
 /**
- * librdf_storage_list_get_feature - get the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
+ * librdf_storage_list_get_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a storage feature.
  * 
- * Return value: &librdf_node feature value or NULL if no such feature
+ * Return value: #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 static librdf_node*
