@@ -2,17 +2,13 @@
  *
  * rdf_storage_mysql.c - RDF Storage in MySQL DB interface definition.
  *
- * $Id: rdf_storage_mysql.c,v 1.44 2005/05/29 16:09:51 cmdjb Exp $
+ * $Id: rdf_storage_mysql.c 10852 2006-04-25 06:40:15Z dajobe $
  *
  * Based in part on rdf_storage_list and rdf_storage_parka.
  *
  * Copyright (C) 2003-2005 Morten Frederiksen - http://purl.org/net/morten/
- *
- * and
- *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -37,6 +33,9 @@
 
 #ifdef WIN32
 #include <win32_rdf_config.h>
+#include <config-win.h>
+#include <winsock.h>
+#include <assert.h>
 #endif
 
 #include <stdio.h>
@@ -383,6 +382,8 @@ librdf_storage_mysql_release_handle(librdf_storage* storage, MYSQL *handle)
  * @name: model name
  * @options: host, port, database, user, password [, new] [, bulk] [, merge].
  *
+ * .
+ *
  * Create connection to database.  Defaults to port 3306 if not given.
  *
  * The boolean bulk option can be set to true if optimized inserts (table
@@ -400,7 +401,7 @@ librdf_storage_mysql_init(librdf_storage* storage, char *name,
 {
   librdf_storage_mysql_context *context=(librdf_storage_mysql_context*)storage->context;
   const char create_table_statements[]="\
-  CREATE TABLE IF NOT EXISTS Statements%llu (\
+  CREATE TABLE IF NOT EXISTS Statements" UINT64_T_FMT " (\
   Subject bigint unsigned NOT NULL,\
   Predicate bigint unsigned NOT NULL,\
   Object bigint unsigned NOT NULL,\
@@ -437,8 +438,8 @@ librdf_storage_mysql_init(librdf_storage* storage, char *name,
   Name text NOT NULL,\
   PRIMARY KEY ID (ID)\
 ) TYPE=MyISAM DELAY_KEY_WRITE=1";
-  const char create_model[]="INSERT INTO Models (ID,Name) VALUES (%llu,'%s')";
-  const char check_model[]="SELECT HIGH_PRIORITY 1 FROM Models WHERE ID=%llu AND Name='%s'";
+  const char create_model[]="INSERT INTO Models (ID,Name) VALUES (" UINT64_T_FMT ",'%s')";
+  const char check_model[]="SELECT HIGH_PRIORITY 1 FROM Models WHERE ID=" UINT64_T_FMT " AND Name='%s'";
   int status=0;
   char *escaped_name=NULL;
   char *query=NULL;
@@ -517,7 +518,7 @@ librdf_storage_mysql_init(librdf_storage* storage, char *name,
     if(!(query=(char*)LIBRDF_MALLOC(cstring,strlen(create_model)+20+
                                     strlen(escaped_name)+1)))
       status=1;
-    sprintf(query, create_model, context->model, name);
+    sprintf(query, create_model, context->model, escaped_name);
     if(!status && mysql_real_query(handle, query, strlen(query)) &&
        mysql_errno(handle) != ER_DUP_ENTRY) {
       librdf_log(storage->world, 0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
@@ -650,6 +651,8 @@ librdf_storage_mysql_merge(librdf_storage* storage)
  * librdf_storage_mysql_terminate:
  * @storage: the storage
  *
+ * .
+ *
  * Close the storage and database connections.
  *
  * Return value: None.
@@ -682,6 +685,8 @@ librdf_storage_mysql_terminate(librdf_storage* storage)
  * @storage: the storage
  * @model: the model
  *
+ * .
+ *
  * Create or open model in database (nop).
  *
  * Return value: Non-zero on failure.
@@ -696,6 +701,8 @@ librdf_storage_mysql_open(librdf_storage* storage, librdf_model* model)
  * librdf_storage_mysql_close:
  * @storage: the storage
  *
+ * .
+ *
  * Close model (nop).
  *
  * Return value: Non-zero on failure.
@@ -707,9 +714,11 @@ librdf_storage_mysql_close(librdf_storage* storage)
 }
 
 /**
- * librdf_storage_mysql_sync - Flush all tables, making sure they are saved on disk.
+ * librdf_storage_mysql_sync:
  * @storage: the storage
  *
+ * Flush all tables, making sure they are saved on disk.
+ *
  * Return value: Non-zero on failure.
  **/
 static int
@@ -728,6 +737,8 @@ librdf_storage_mysql_sync(librdf_storage* storage)
  * librdf_storage_mysql_size:
  * @storage: the storage
  *
+ * .
+ *
  * Close model (nop).
  *
  * Return value: Negative on failure.
@@ -736,7 +747,7 @@ static int
 librdf_storage_mysql_size(librdf_storage* storage)
 {
   librdf_storage_mysql_context *context=(librdf_storage_mysql_context*)storage->context;
-  char model_size[]="SELECT HIGH_PRIORITY COUNT(*) FROM Statements%llu";
+  char model_size[]="SELECT HIGH_PRIORITY COUNT(*) FROM Statements" UINT64_T_FMT;
   char *query;
   MYSQL_RES *res;
   MYSQL_ROW row;
@@ -791,6 +802,8 @@ librdf_storage_mysql_add_statement(librdf_storage* storage,
  * @storage: the storage
  * @statement_stream: the stream of statements
  *
+ * .
+ *
  * Add statements in stream to storage, without context.
  *
  * Return value: Non-zero on failure.
@@ -843,7 +856,7 @@ librdf_storage_mysql_node_hash(librdf_storage* storage,
     hash=librdf_storage_mysql_hash(storage, "R", (char*)uri, nodelen);
 
     if(add) {
-      char create_resource[]="INSERT INTO Resources (ID,URI) VALUES (%llu,'%s')";
+      char create_resource[]="INSERT INTO Resources (ID,URI) VALUES (" UINT64_T_FMT ",'%s')";
       /* Escape URI for db query */
       char *escaped_uri;
       if(!(escaped_uri=(char*)LIBRDF_MALLOC(cstring, nodelen*2+1))) {
@@ -865,7 +878,8 @@ librdf_storage_mysql_node_hash(librdf_storage* storage,
       if(mysql_real_query(handle, query, strlen(query)) &&
          mysql_errno(handle) != ER_DUP_ENTRY) {
         librdf_log(storage->world, 0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                   "MySQL insert into Resources failed with error %s", mysql_error(handle));
+                   "MySQL insert into Resources failed with error %s",
+                   mysql_error(handle));
         LIBRDF_FREE(cstring,query);
         librdf_storage_mysql_release_handle(storage, handle);
         return 0;
@@ -907,7 +921,7 @@ librdf_storage_mysql_node_hash(librdf_storage* storage,
     LIBRDF_FREE(cstring,nodestring);
 
     if(add) {
-      char create_literal[]="INSERT INTO Literals (ID,Value,Language,Datatype) VALUES (%llu,'%s','%s','%s')";
+      char create_literal[]="INSERT INTO Literals (ID,Value,Language,Datatype) VALUES (" UINT64_T_FMT ",'%s','%s','%s')";
       /* Escape value, lang and datatype for db query */
       char *escaped_value, *escaped_lang, *escaped_datatype;
       if(!(escaped_value=(char*)LIBRDF_MALLOC(cstring, valuelen*2+1)) ||
@@ -963,7 +977,7 @@ librdf_storage_mysql_node_hash(librdf_storage* storage,
     hash=librdf_storage_mysql_hash(storage, "B", (char*)name, nodelen);
 
     if(add) {
-      char create_bnode[]="INSERT INTO Bnodes (ID,Name) VALUES (%llu,'%s')";
+      char create_bnode[]="INSERT INTO Bnodes (ID,Name) VALUES (" UINT64_T_FMT ",'%s')";
       /* Escape name for db query */
       char *escaped_name;
       if(!(escaped_name=(char*)LIBRDF_MALLOC(cstring, nodelen*2+1))) {
@@ -1014,9 +1028,9 @@ static int
 librdf_storage_mysql_start_bulk(librdf_storage* storage)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char disable_statement_keys[]="ALTER TABLE Statements%llu DISABLE KEYS";
+  char disable_statement_keys[]="ALTER TABLE Statements" UINT64_T_FMT " DISABLE KEYS";
   char disable_literal_keys[]="ALTER TABLE Literals DISABLE KEYS";
-  char lock_tables[]="LOCK TABLES Statements%llu WRITE, Resources WRITE, Bnodes WRITE, Literals WRITE";
+  char lock_tables[]="LOCK TABLES Statements" UINT64_T_FMT " WRITE, Resources WRITE, Bnodes WRITE, Literals WRITE";
   char lock_tables_extra[]=", Statements WRITE";
   char *query=NULL;
   MYSQL *handle;
@@ -1081,7 +1095,7 @@ static int
 librdf_storage_mysql_stop_bulk(librdf_storage* storage)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char enable_statement_keys[]="ALTER TABLE Statements%llu ENABLE KEYS";
+  char enable_statement_keys[]="ALTER TABLE Statements" UINT64_T_FMT " ENABLE KEYS";
   char enable_literal_keys[]="ALTER TABLE Literals ENABLE KEYS";
   char unlock_tables[]="UNLOCK TABLES";
   char flush_statements[]="FLUSH TABLE Statements";
@@ -1141,9 +1155,11 @@ librdf_storage_mysql_stop_bulk(librdf_storage* storage)
 /**
  * librdf_storage_mysql_context_add_statements:
  * @storage: the storage
- * @context_node: &librdf_node object
+ * @context_node: #librdf_node object
  * @statement_stream: the stream of statements
  *
+ * .
+ *
  * Add statements in stream to storage, with context.
  *
  * Return value: Non-zero on failure.
@@ -1182,10 +1198,12 @@ librdf_storage_mysql_context_add_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_context_add_statement - Add a statement to a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_mysql_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage context.
  *
  * Return value: non 0 on failure
  **/
@@ -1210,9 +1228,9 @@ librdf_storage_mysql_context_add_statement(librdf_storage* storage,
 
 /*
  * librdf_storage_mysql_context_add_statement_helper - Perform actual addition of a statement to a storage context
- * @storage: &librdf_storage object
+ * @storage: #librdf_storage object
  * @ctxt: u64 context hash
- * @statement: &librdf_statement statement to add
+ * @statement: #librdf_statement statement to add
  *
  * Return value: non-zero on failure
  **/
@@ -1221,7 +1239,7 @@ librdf_storage_mysql_context_add_statement_helper(librdf_storage* storage,
                                           u64 ctxt, librdf_statement* statement)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char insert_statement[]="INSERT INTO Statements%llu (Subject,Predicate,Object,Context) VALUES (%llu,%llu,%llu,%llu)";
+  char insert_statement[]="INSERT INTO Statements" UINT64_T_FMT " (Subject,Predicate,Object,Context) VALUES (" UINT64_T_FMT "," UINT64_T_FMT "," UINT64_T_FMT "," UINT64_T_FMT ")";
   u64 subject, predicate, object;
   char *query;
   MYSQL *handle;
@@ -1265,10 +1283,12 @@ librdf_storage_mysql_context_add_statement_helper(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_contains_statement - Test if a given complete statement is present in the model
+ * librdf_storage_mysql_contains_statement:
  * @storage: the storage
  * @statement: a complete statement
  *
+ * Test if a given complete statement is present in the model.
+ *
  * Return value: Non-zero if the model contains the statement.
  **/
 static int
@@ -1276,7 +1296,7 @@ librdf_storage_mysql_contains_statement(librdf_storage* storage,
                                         librdf_statement* statement)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char find_statement[]="SELECT HIGH_PRIORITY 1 FROM Statements%llu WHERE Subject=%llu AND Predicate=%llu AND Object=%llu limit 1";
+  char find_statement[]="SELECT HIGH_PRIORITY 1 FROM Statements" UINT64_T_FMT " WHERE Subject=" UINT64_T_FMT " AND Predicate=" UINT64_T_FMT " AND Object=" UINT64_T_FMT " limit 1";
   u64 subject, predicate, object;
   char *query;
   MYSQL_RES *res;
@@ -1330,9 +1350,11 @@ librdf_storage_mysql_contains_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_remove_statement - Remove a statement from storage
- * @storage: &librdf_storage object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_mysql_remove_statement:
+ * @storage: #librdf_storage object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from storage.
  *
  * Return value: non-zero on failure
  **/
@@ -1344,10 +1366,12 @@ librdf_storage_mysql_remove_statement(librdf_storage* storage, librdf_statement*
 
 
 /**
- * librdf_storage_mysql_context_remove_statement - Remove a statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_mysql_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage context.
  *
  * Return value: non-zero on failure
  **/
@@ -1357,8 +1381,8 @@ librdf_storage_mysql_context_remove_statement(librdf_storage* storage,
                                              librdf_statement* statement)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char delete_statement[]="DELETE FROM Statements%llu WHERE Subject=%llu AND Predicate=%llu AND Object=%llu";
-  char delete_statement_with_context[]="DELETE FROM Statements%llu WHERE Subject=%llu AND Predicate=%llu AND Object=%llu AND Context=%llu";
+  char delete_statement[]="DELETE FROM Statements" UINT64_T_FMT " WHERE Subject=" UINT64_T_FMT " AND Predicate=" UINT64_T_FMT " AND Object=" UINT64_T_FMT;
+  char delete_statement_with_context[]="DELETE FROM Statements" UINT64_T_FMT " WHERE Subject=" UINT64_T_FMT " AND Predicate=" UINT64_T_FMT " AND Object=" UINT64_T_FMT " AND Context=" UINT64_T_FMT;
   u64 subject, predicate, object, ctxt=0;
   char *query;
   MYSQL *handle;
@@ -1419,9 +1443,11 @@ librdf_storage_mysql_context_remove_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_context_remove_statements - Remove all statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_mysql_context_remove_statements:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ *
+ * Remove all statement from a storage context.
  *
  * Return value: non-zero on failure
  **/
@@ -1430,8 +1456,8 @@ librdf_storage_mysql_context_remove_statements(librdf_storage* storage,
                                                librdf_node* context_node)
 {
   librdf_storage_mysql_context* context=(librdf_storage_mysql_context*)storage->context;
-  char delete_context[]="DELETE FROM Statements%llu WHERE Context=%llu";
-  char delete_model[]="DELETE FROM Statements%llu";
+  char delete_context[]="DELETE FROM Statements" UINT64_T_FMT " WHERE Context=" UINT64_T_FMT;
+  char delete_model[]="DELETE FROM Statements" UINT64_T_FMT;
   char flush_statements[]="FLUSH TABLE Statements";
   u64 ctxt=0;
   char *query;
@@ -1492,12 +1518,14 @@ librdf_storage_mysql_context_remove_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_serialise - Return a stream of all statements in a storage
+ * librdf_storage_mysql_serialise:
  * @storage: the storage
  *
  * Return a stream of all statements in a storage.
  *
- * Return value: a &librdf_stream or NULL on failure
+ * Return a stream of all statements in a storage.
+ *
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_mysql_serialise(librdf_storage* storage)
@@ -1507,15 +1535,17 @@ librdf_storage_mysql_serialise(librdf_storage* storage)
 
 
 /**
- * librdf_storage_mysql_find_statements - Find a graph of statements in storage.
+ * librdf_storage_mysql_find_statements:
  * @storage: the storage
  * @statement: the statement to match
  *
+ * Find a graph of statements in storage.
+ *
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
  *
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_mysql_find_statements(librdf_storage* storage,
@@ -1526,11 +1556,13 @@ librdf_storage_mysql_find_statements(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_context_serialise - List all statements in a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_mysql_context_serialise:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
  *
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * List all statements in a storage context.
+ *
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 static librdf_stream*
 librdf_storage_mysql_context_serialise(librdf_storage* storage,
@@ -1541,16 +1573,18 @@ librdf_storage_mysql_context_serialise(librdf_storage* storage,
 
 
 /**
- * librdf_storage_mysql_find_statements_in_context - Find a graph of statements in a storage context.
+ * librdf_storage_mysql_find_statements_in_context:
  * @storage: the storage
  * @statement: the statement to match
  * @context_node: the context to search
  *
+ * Find a graph of statements in a storage context.
+ *
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
  *
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_mysql_find_statements_in_context(librdf_storage* storage, librdf_statement* statement,
@@ -1561,17 +1595,19 @@ librdf_storage_mysql_find_statements_in_context(librdf_storage* storage, librdf_
 
 
 /**
- * librdf_storage_mysql_find_statements_with_options - Find a graph of statements in a storage context with options.
+ * librdf_storage_mysql_find_statements_with_options:
  * @storage: the storage
  * @statement: the statement to match
  * @context_node: the context to search
- * @options: &librdf_hash of match options or NULL
+ * @options: #librdf_hash of match options or NULL
+ *
+ * Find a graph of statements in a storage context with options.
  *
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
  *
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_mysql_find_statements_with_options(librdf_storage* storage, 
@@ -1623,10 +1659,10 @@ librdf_storage_mysql_find_statements_with_options(librdf_storage* storage,
   strcpy(query, "SELECT HIGH_PRIORITY");
   *where='\0';
   if(sos->is_literal_match)
-    sprintf(joins, " FROM Literals AS L LEFT JOIN Statements%llu as S ON L.ID=S.Object",
+    sprintf(joins, " FROM Literals AS L LEFT JOIN Statements" UINT64_T_FMT " as S ON L.ID=S.Object",
             context->model);
   else
-    sprintf(joins, " FROM Statements%llu AS S", context->model);
+    sprintf(joins, " FROM Statements" UINT64_T_FMT " AS S", context->model);
 
   if(statement) {
     subject=librdf_statement_get_subject(statement);
@@ -1636,7 +1672,7 @@ librdf_storage_mysql_find_statements_with_options(librdf_storage* storage,
 
   /* Subject */
   if(statement && subject) {
-    sprintf(tmp, "S.Subject=%llu",
+    sprintf(tmp, "S.Subject=" UINT64_T_FMT "",
             librdf_storage_mysql_node_hash(storage,subject,0));
     if(!strlen(where))
       strcat(where, " WHERE ");
@@ -1654,7 +1690,7 @@ librdf_storage_mysql_find_statements_with_options(librdf_storage* storage,
 
   /* Predicate */
   if(statement && predicate) {
-    sprintf(tmp, "S.Predicate=%llu",
+    sprintf(tmp, "S.Predicate=" UINT64_T_FMT "",
             librdf_storage_mysql_node_hash(storage, predicate, 0));
     if(!strlen(where))
       strcat(where, " WHERE ");
@@ -1678,7 +1714,7 @@ librdf_storage_mysql_find_statements_with_options(librdf_storage* storage,
   /* Object */
   if(statement && object) {
     if(!sos->is_literal_match) {
-      sprintf(tmp,"S.Object=%llu",
+      sprintf(tmp,"S.Object=" UINT64_T_FMT "",
               librdf_storage_mysql_node_hash(storage, object, 0));
       if(!strlen(where))
         strcat(where, " WHERE ");
@@ -1733,7 +1769,7 @@ librdf_storage_mysql_find_statements_with_options(librdf_storage* storage,
 
   /* Context */
   if(context_node) {
-    sprintf(tmp,"S.Context=%llu",
+    sprintf(tmp,"S.Context=" UINT64_T_FMT "",
             librdf_storage_mysql_node_hash(storage,context_node,0));
     if(!strlen(where))
       strcat(where, " WHERE ");
@@ -2026,9 +2062,11 @@ librdf_storage_mysql_find_statements_in_context_finished(void* context)
  * librdf_storage_mysql_get_contexts:
  * @storage: the storage
  *
+ * .
+ *
  * Return an iterator with the context nodes present in storage.
  *
- * Return value: a &librdf_iterator or NULL on failure
+ * Return value: a #librdf_iterator or NULL on failure
  **/
 static librdf_iterator*
 librdf_storage_mysql_get_contexts(librdf_storage* storage)
@@ -2038,7 +2076,7 @@ librdf_storage_mysql_get_contexts(librdf_storage* storage)
   const char select_contexts[]="\
 SELECT HIGH_PRIORITY DISTINCT R.URI AS CoR, B.Name AS CoB, \
 L.Value AS CoV, L.Language AS CoL, L.Datatype AS CoD \
-FROM Statements%llu as S \
+FROM Statements" UINT64_T_FMT " as S \
 LEFT JOIN Resources AS R ON S.Context=R.ID \
 LEFT JOIN Bnodes AS B ON S.Context=B.ID \
 LEFT JOIN Literals AS L ON S.Context=L.ID";
@@ -2188,11 +2226,13 @@ librdf_storage_mysql_get_contexts_finished(void* context)
 
 
 /**
- * librdf_storage_mysql_get_feature - get the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
+ * librdf_storage_mysql_get_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a storage feature.
  * 
- * Return value: &librdf_node feature value or NULL if no such feature
+ * Return value: #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 static librdf_node*
