@@ -2,11 +2,10 @@
  *
  * rdf_storage_sqlite.c - RDF Storage using SQLite implementation
  *
- * $Id: rdf_storage_sqlite.c,v 1.40 2005/05/20 14:07:54 cmdjb Exp $
+ * $Id: rdf_storage_sqlite.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2004-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2004-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2004-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -597,7 +596,7 @@ librdf_storage_sqlite_node_helper(librdf_storage* storage,
     default:
       librdf_log(node->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Do not know how to store node type %d\n", node->type);
+                 "Do not know how to store node type %d", node->type);
     return 1;
   }
 
@@ -742,8 +741,10 @@ librdf_storage_sqlite_open(librdf_storage* storage, librdf_model* model)
 
 
 /**
- * librdf_storage_sqlite_close - Close the sqlite storage
+ * librdf_storage_sqlite_close:
  * @storage: the storage
+ *
+ * Close the sqlite storage.
  * 
  * Return value: non 0 on failure
  **/
@@ -1316,7 +1317,7 @@ librdf_storage_sqlite_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -1382,13 +1383,15 @@ typedef struct {
  * librdf_storage_sqlite_find_statements:
  * @storage: the storage
  * @statement: the statement to match
+ *
+ * .
  * 
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
- * Uses &librdf_statement_match to do the matching.
+ * Uses #librdf_statement_match to do the matching.
  * 
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_sqlite_find_statements(librdf_storage* storage,
@@ -1566,7 +1569,7 @@ librdf_storage_sqlite_find_statements_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -1615,10 +1618,12 @@ librdf_storage_sqlite_find_statements_finished(void* context)
 
 
 /**
- * librdf_storage_sqlite_context_add_statement - Add a statement to a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_sqlite_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -1689,10 +1694,12 @@ librdf_storage_sqlite_context_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_sqlite_context_remove_statement - Remove a statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_sqlite_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -1744,11 +1751,13 @@ typedef struct {
 
 
 /**
- * librdf_storage_sqlite_context_serialise - Sqlite all statements in a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_sqlite_context_serialise:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ *
+ * Sqlite all statements in a storage context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 static librdf_stream*
 librdf_storage_sqlite_context_serialise(librdf_storage* storage,
@@ -1909,7 +1918,7 @@ librdf_storage_sqlite_context_serialise_get_statement(void* context, int flags)
     default:
       librdf_log(scontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -2131,7 +2140,7 @@ librdf_storage_sqlite_get_contexts_get_method(void* iterator, int flags)
     default:
       librdf_log(icontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       result=NULL;
       break;
   }
@@ -2177,10 +2186,12 @@ librdf_storage_sqlite_get_contexts_finished(void* iterator)
 
 
 /**
- * librdf_storage_sqlite_context_get_contexts - Sqlite all context nodes in a storage
- * @storage: &librdf_storage object
+ * librdf_storage_sqlite_context_get_contexts:
+ * @storage: #librdf_storage object
+ *
+ * Sqlite all context nodes in a storage.
  * 
- * Return value: &librdf_iterator of context_nodes or NULL on failure or no contexts
+ * Return value: #librdf_iterator of context_nodes or NULL on failure or no contexts
  **/
 static librdf_iterator*
 librdf_storage_sqlite_get_contexts(librdf_storage* storage) 
@@ -2260,11 +2271,13 @@ librdf_storage_sqlite_get_contexts(librdf_storage* storage)
 
 
 /**
- * librdf_storage_sqlite_get_feature - get the value of a storage feature
- * @storage: &librdf_storage object
- * @feature: &librdf_uri feature property
+ * librdf_storage_sqlite_get_feature:
+ * @storage: #librdf_storage object
+ * @feature: #librdf_uri feature property
+ *
+ * Get the value of a storage feature.
  * 
- * Return value: &librdf_node feature value or NULL if no such feature
+ * Return value: #librdf_node feature value or NULL if no such feature
  * exists or the value is empty.
  **/
 static librdf_node*
