@@ -2,11 +2,10 @@
  *
  * rdf_storage_tstore.c - RDF Storage using 3store
  *
- * $Id: rdf_storage_tstore.c,v 1.13 2004/11/01 20:43:35 cmdjb Exp $
+ * $Id: rdf_storage_tstore.c 8534 2006-01-26 04:57:33Z cmdjb $
  *
- * Copyright (C) 2003-2004, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2003-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2003-2004, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -154,6 +153,8 @@ librdf_storage_tstore_open(librdf_storage* storage, librdf_model* model)
 /**
  * librdf_storage_tstore_close:
  * @storage: the storage
+ *
+ * .
  * 
  * Close the storage list storage, and free all content since there is no 
  * persistance.
@@ -212,9 +213,11 @@ librdf_storage_tstore_statement_from_rs_triple(librdf_world* world,
 
   if(triple->subject) {
     if(!strncmp(triple->subject, "_:",2))
-      subject_node=librdf_new_node_from_blank_identifier(world, triple->subject+2);
+      subject_node=librdf_new_node_from_blank_identifier(world, 
+                                                         (const unsigned char *)triple->subject+2);
     else
-      subject_node=librdf_new_node_from_uri_string(world, triple->subject);
+      subject_node=librdf_new_node_from_uri_string(world, 
+                                                   (const unsigned char *)triple->subject);
 
     if(!subject_node)
       return NULL;
@@ -223,7 +226,8 @@ librdf_storage_tstore_statement_from_rs_triple(librdf_world* world,
     subject_node=NULL;
   
   if(triple->predicate) {
-    predicate_node=librdf_new_node_from_uri_string(world, triple->predicate);
+    predicate_node=librdf_new_node_from_uri_string(world,
+                                                   (const unsigned char *)triple->predicate);
 
     if(!predicate_node) {
       librdf_free_node(subject_node);
@@ -234,11 +238,15 @@ librdf_storage_tstore_statement_from_rs_triple(librdf_world* world,
   
   if(triple->object) {
     if(triple->literal)
-      object_node=librdf_new_node_from_typed_literal(world, triple->object, NULL, NULL);
+      object_node=librdf_new_node_from_typed_literal(world, 
+                                                     (const unsigned char *)triple->object,
+                                                     NULL, NULL);
     else if(!strncmp(triple->object, ":", 2))
-      object_node=librdf_new_node_from_blank_identifier(world, triple->object+2);
+      object_node=librdf_new_node_from_blank_identifier(world, 
+                                                        (const unsigned char *)triple->object+2);
     else
-      object_node=librdf_new_node_from_uri_string(world, triple->object);
+      object_node=librdf_new_node_from_uri_string(world, 
+                                                  (const unsigned char *)triple->object);
 
     if(!object_node) {
       librdf_free_node(subject_node);
@@ -256,21 +264,21 @@ librdf_storage_tstore_statement_from_rs_triple(librdf_world* world,
 static rs_triple*
 librdf_storage_tstore_statement_as_rs_triple(librdf_statement *statement)
 {
-  librdf_node *subject_node=LIBRDF_NODE_STATEMENT_SUBJECT(statement);
-  librdf_node *predicate_node=LIBRDF_NODE_STATEMENT_PREDICATE(statement);
-  librdf_node *object_node=LIBRDF_NODE_STATEMENT_OBJECT(statement);
+  librdf_node *subject_node=statement->subject;
+  librdf_node *predicate_node=statement->predicate;
+  librdf_node *object_node=statement->object;
   rs_triple* triple=LIBRDF_MALLOC(rs_triple, sizeof(rs_triple));
 
   if(subject_node) {
     if(librdf_node_is_blank(subject_node))
-      triple->subject=librdf_node_get_blank_identifier(subject_node);
+      triple->subject=(char*)librdf_node_get_blank_identifier(subject_node);
     else
-      triple->subject=librdf_uri_as_string(librdf_node_get_uri(subject_node));
+      triple->subject=(char*)librdf_uri_as_string(librdf_node_get_uri(subject_node));
   } else
     triple->subject=NULL;
 
   if(predicate_node)
-    triple->predicate=librdf_uri_as_string(librdf_node_get_uri(predicate_node));
+    triple->predicate=(char*)librdf_uri_as_string(librdf_node_get_uri(predicate_node));
   else
     triple->predicate=NULL;
   
@@ -278,12 +286,12 @@ librdf_storage_tstore_statement_as_rs_triple(librdf_statement *statement)
   triple->literal = 0;
   if(object_node) {
     if(librdf_node_is_literal(object_node)) {
-      triple->object=librdf_node_get_literal_value(object_node);
+      triple->object=(char*)librdf_node_get_literal_value(object_node);
       triple->literal = 1;
     } else if(librdf_node_is_blank(object_node)) {
-      triple->object=librdf_node_get_blank_identifier(object_node);
+      triple->object=(char*)librdf_node_get_blank_identifier(object_node);
     } else {
-      triple->object=librdf_uri_as_string(librdf_node_get_uri(object_node));
+      triple->object=(char*)librdf_uri_as_string(librdf_node_get_uri(object_node));
     }
   } else
     triple->object=NULL;
@@ -372,9 +380,9 @@ librdf_storage_tstore_serialise_get_statement(void* context, int flags)
     case LIBRDF_ITERATOR_GET_METHOD_GET_CONTEXT:
       return NULL;
     default:
-      librdf_log(scontext->iterator->world,
+      librdf_log(scontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -419,13 +427,15 @@ typedef struct {
  * librdf_storage_tstore_find_statements:
  * @storage: the storage
  * @statement: the statement to match
+ *
+ * .
  * 
  * Return a stream of statements matching the given statement (or
  * all statements if NULL).  Parts (subject, predicate, object) of the
  * statement can be empty in which case any statement part will match that.
- * Uses &librdf_statement_match to do the matching.
+ * Uses #librdf_statement_match to do the matching.
  * 
- * Return value: a &librdf_stream or NULL on failure
+ * Return value: a #librdf_stream or NULL on failure
  **/
 static librdf_stream*
 librdf_storage_tstore_find_statements(librdf_storage* storage, librdf_statement* statement)
@@ -521,9 +531,9 @@ librdf_storage_tstore_find_get_statement(void* context, int flags)
     case LIBRDF_ITERATOR_GET_METHOD_GET_CONTEXT:
       return NULL;
     default:
-      librdf_log(scontext->iterator->world,
+      librdf_log(scontext->storage->world,
                  0, LIBRDF_LOG_ERROR, LIBRDF_FROM_STORAGE, NULL,
-                 "Unknown iterator method flag %d\n", flags);
+                 "Unknown iterator method flag %d", flags);
       return NULL;
   }
 }
@@ -560,10 +570,12 @@ librdf_storage_tstore_find_finished(void* context)
 }
 
 /**
- * librdf_storage_tstore_context_add_statement - Add a statement to a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to add
+ * librdf_storage_tstore_context_add_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to add
+ *
+ * Add a statement to a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -573,9 +585,9 @@ librdf_storage_tstore_context_add_statement(librdf_storage* storage,
                                             librdf_statement* statement) 
 {
   librdf_storage_tstore_context* context=(librdf_storage_tstore_context*)storage->context;
-  librdf_node *subject_node=LIBRDF_NODE_STATEMENT_SUBJECT(statement);
-  librdf_node *predicate_node=LIBRDF_NODE_STATEMENT_PREDICATE(statement);
-  librdf_node *object_node=LIBRDF_NODE_STATEMENT_OBJECT(statement);
+  librdf_node *subject_node=statement->subject;
+  librdf_node *predicate_node=statement->predicate;
+  librdf_node *object_node=statement->object;
   char *subject;
   char *predicate;
   char *object;
@@ -583,22 +595,22 @@ librdf_storage_tstore_context_add_statement(librdf_storage* storage,
 
   
   if(librdf_node_is_blank(subject_node)) {
-    subject=librdf_node_get_blank_identifier(subject_node);
+    subject=(char*)librdf_node_get_blank_identifier(subject_node);
   } else
-    subject=librdf_uri_as_string(librdf_node_get_uri(subject_node));
+    subject=(char*)librdf_uri_as_string(librdf_node_get_uri(subject_node));
   
 
-  predicate=librdf_uri_as_string(librdf_node_get_uri(predicate_node));
+  predicate=(char*)librdf_uri_as_string(librdf_node_get_uri(predicate_node));
   
   /* Assumptions - FIXME */
   if(librdf_node_is_literal(object_node)) {
-    object=librdf_node_get_literal_value(object_node);
+    object=(char*)librdf_node_get_literal_value(object_node);
     type = ObjLiteral;
   } else if(librdf_node_is_blank(object_node)) {
-    object=librdf_node_get_blank_identifier(object_node);
+    object=(char*)librdf_node_get_blank_identifier(object_node);
     type = ObjURI;
   } else {
-    object=librdf_uri_as_string(librdf_node_get_uri(object_node));
+    object=(char*)librdf_uri_as_string(librdf_node_get_uri(object_node));
     type = ObjURI;
   }
   
@@ -611,10 +623,12 @@ librdf_storage_tstore_context_add_statement(librdf_storage* storage,
 
 
 /**
- * librdf_storage_tstore_context_remove_statement - Remove a statement from a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
- * @statement: &librdf_statement statement to remove
+ * librdf_storage_tstore_context_remove_statement:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ * @statement: #librdf_statement statement to remove
+ *
+ * Remove a statement from a storage context.
  * 
  * Return value: non 0 on failure
  **/
@@ -640,11 +654,13 @@ typedef struct {
 
 
 /**
- * librdf_storage_tstore_context_serialise - List all statements in a storage context
- * @storage: &librdf_storage object
- * @context_node: &librdf_node object
+ * librdf_storage_tstore_context_serialise:
+ * @storage: #librdf_storage object
+ * @context_node: #librdf_node object
+ *
+ * List all statements in a storage context.
  * 
- * Return value: &librdf_stream of statements or NULL on failure or context is empty
+ * Return value: #librdf_stream of statements or NULL on failure or context is empty
  **/
 static librdf_stream*
 librdf_storage_tstore_context_serialise(librdf_storage* storage,
