@@ -2,11 +2,10 @@
  *
  * rdf_uri.c - RDF URI interface
  *
- * $Id: rdf_uri.c,v 1.70 2005/05/23 13:19:20 cmdjb Exp $
+ * $Id: rdf_uri.c 10856 2006-04-25 06:53:48Z dajobe $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, Copyright (C) 2000-2006, Copyright (C) 2000-2006, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -53,9 +52,11 @@
 
 
 /**
- * librdf_init_uri - INTERNAL - Initialise the librdf_uri class
+ * librdf_init_uri:
  * @world: redland world object
  *
+ * INTERNAL - Initialise the librdf_uri class.
+ *
  **/
 void
 librdf_init_uri(librdf_world *world)
@@ -77,8 +78,11 @@ librdf_init_uri(librdf_world *world)
 
 
 /**
- * librdf_finish_uri - INTERNAL - Terminate the librdf_uri class
+ * librdf_finish_uri:
  * @world: redland world object
+ *
+ * INTERNAL - Terminate the librdf_uri class.
+ *
  **/
 void
 librdf_finish_uri(librdf_world *world)
@@ -92,14 +96,16 @@ librdf_finish_uri(librdf_world *world)
 
 
 /**
- * librdf_new_uri - Constructor - create a new librdf_uri object from a URI string
+ * librdf_new_uri:
  * @world: redland world object
  * @uri_string: URI in string form
+ *
+ * Constructor - create a new #librdf_uri object from a URI string.
  * 
  * A new URI is constructed from a copy of the string.  If the
  * string is a NULL pointer or empty (0 length) then the result is NULL.
  *
- * Return value: a new &librdf_uri object or NULL on failure
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri (librdf_world *world, 
@@ -190,10 +196,12 @@ librdf_new_uri (librdf_world *world,
 
 
 /**
- * librdf_new_uri_from_uri - Copy constructor - create a new librdf_uri object from an existing librdf_uri object
- * @old_uri: &librdf_uri object
+ * librdf_new_uri_from_uri:
+ * @old_uri: #librdf_uri object
+ *
+ * Copy constructor - create a new librdf_uri object from an existing librdf_uri object.
  * 
- * Return value: a new &librdf_uri object or NULL on failure
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri_from_uri (librdf_uri* old_uri) {
@@ -206,11 +214,13 @@ librdf_new_uri_from_uri (librdf_uri* old_uri) {
 
 
 /**
- * librdf_new_uri_from_uri_local_name - Copy constructor - create a new librdf_uri object from an existing librdf_uri object and a local name
- * @old_uri: &librdf_uri object
+ * librdf_new_uri_from_uri_local_name:
+ * @old_uri: #librdf_uri object
  * @local_name: local name to append to URI
+ *
+ * Copy constructor - create a new librdf_uri object from an existing librdf_uri object and a local name.
  * 
- * Return value: a new &librdf_uri object or NULL on failure
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri_from_uri_local_name (librdf_uri* old_uri, 
@@ -239,12 +249,14 @@ librdf_new_uri_from_uri_local_name (librdf_uri* old_uri,
 
 
 /**
- * librdf_new_uri_normalised_to_base - Constructor - create a new librdf_uri object from a URI string stripped of the source URI, made relative to the base URI
+ * librdf_new_uri_normalised_to_base:
  * @uri_string: URI in string form
  * @source_uri: source URI to remove
  * @base_uri: base URI to add
+ *
+ * Constructor - create a new #librdf_uri object from a URI string stripped of the source URI, made relative to the base URI.
  * 
- * Return value: a new &librdf_uri object or NULL on failure
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri_normalised_to_base(const unsigned char *uri_string,
@@ -303,14 +315,16 @@ librdf_new_uri_normalised_to_base(const unsigned char *uri_string,
 
 
 /**
- * librdf_new_uri_relative_to_base - Constructor - create a new librdf_uri object from a URI string relative to a base URI
+ * librdf_new_uri_relative_to_base:
  * @base_uri: absolute base URI
  * @uri_string: relative URI string
  *
+ * Constructor - create a new #librdf_uri object from a URI string relative to a base URI.
+ *
  * An empty uri_string or NULL is equivalent to 
  * librdf_new_uri_from_uri(base_uri)
  * 
- * Return value: a new &librdf_uri object or NULL on failure
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri_relative_to_base(librdf_uri* base_uri,
@@ -345,11 +359,13 @@ librdf_new_uri_relative_to_base(librdf_uri* base_uri,
 
 
 /**
- * librdf_new_uri_from_filename - Constructor - create a new librdf_uri object from a filename
- * @world: Redland &librdf_world object
+ * librdf_new_uri_from_filename:
+ * @world: Redland #librdf_world object
  * @filename: filename
  *
- * Return value: a new &librdf_uri object or NULL on failure
+ * Constructor - create a new #librdf_uri object from a filename.
+ *
+ * Return value: a new #librdf_uri object or NULL on failure
  **/
 librdf_uri*
 librdf_new_uri_from_filename(librdf_world* world, const char *filename) {
@@ -371,8 +387,10 @@ librdf_new_uri_from_filename(librdf_world* world, const char *filename) {
 
 
 /**
- * librdf_free_uri - Destructor - destroy a librdf_uri object
- * @uri: &librdf_uri object
+ * librdf_free_uri:
+ * @uri: #librdf_uri object
+ *
+ * Destructor - destroy a #librdf_uri object.
  * 
  **/
 void
@@ -425,8 +443,10 @@ librdf_free_uri (librdf_uri* uri)
 
 
 /**
- * librdf_uri_as_string - Get a pointer to the string representation of the URI
- * @uri: &librdf_uri object
+ * librdf_uri_as_string:
+ * @uri: #librdf_uri object
+ *
+ * Get a pointer to the string representation of the URI.
  * 
  * Returns a shared pointer to the URI string representation. 
  * Note: does not allocate a new string so the caller must not free it.
@@ -443,9 +463,11 @@ librdf_uri_as_string (librdf_uri *uri)
 
 
 /**
- * librdf_uri_as_counted_string - Get a pointer to the string representation of the URI with length
- * @uri: &librdf_uri object
+ * librdf_uri_as_counted_string:
+ * @uri: #librdf_uri object
  * @len_p: pointer to location to store length
+ *
+ * Get a pointer to the string representation of the URI with length.
  * 
  * Returns a shared pointer to the URI string representation. 
  * Note: does not allocate a new string so the caller must not free it.
@@ -464,13 +486,15 @@ librdf_uri_as_counted_string(librdf_uri *uri, size_t* len_p)
 
 
 /**
- * librdf_uri_get_digest - Get a digest for the URI
- * @uri: &librdf_uri object
+ * librdf_uri_get_digest:
+ * @uri: #librdf_uri object
+ *
+ * Get a digest for the URI.
  * 
  * Generates a digest object for the URI.  The digest factory used is
  * determined at class initialisation time by librdf_init_uri().
  * 
- * Return value: new &librdf_digest object or NULL on failure.
+ * Return value: new #librdf_digest object or NULL on failure.
  **/
 librdf_digest*
 librdf_uri_get_digest(librdf_uri* uri) 
@@ -492,9 +516,12 @@ librdf_uri_get_digest(librdf_uri* uri)
 
 
 /**
- * librdf_uri_print - Print the URI to the given file handle
- * @uri: &librdf_uri object
- * @fh: &FILE handle
+ * librdf_uri_print:
+ * @uri: #librdf_uri object
+ * @fh: file handle
+ *
+ * Print the URI to the given file handle.
+ *
  **/
 void
 librdf_uri_print (librdf_uri* uri, FILE *fh) 
@@ -506,8 +533,10 @@ librdf_uri_print (librdf_uri* uri, FILE *fh)
 
 
 /**
- * librdf_uri_to_string - Format the URI as a string
- * @uri: &librdf_uri object
+ * librdf_uri_to_string:
+ * @uri: #librdf_uri object
+ *
+ * Format the URI as a string.
  * 
  * Note: this method allocates a new string since this is a _to_ method
  * and the caller must free the resulting memory.
@@ -524,9 +553,11 @@ librdf_uri_to_string (librdf_uri* uri)
 
 
 /**
- * librdf_uri_to_counted_string - Format the URI as a counted string
- * @uri: &librdf_uri object
+ * librdf_uri_to_counted_string:
+ * @uri: #librdf_uri object
  * @len_p: pointer to location to store length
+ *
+ * Format the URI as a counted string.
  * 
  * Note: this method allocates a new string since this is a _to_ method
  * and the caller must free the resulting memory.
@@ -556,9 +587,11 @@ librdf_uri_to_counted_string (librdf_uri* uri, size_t* len_p)
 
 
 /**
- * librdf_uri_equals - Compare two librdf_uri objects for equality
- * @first_uri: &librdf_uri object 1
- * @second_uri: &librdf_uri object 2
+ * librdf_uri_equals:
+ * @first_uri: #librdf_uri object 1
+ * @second_uri: #librdf_uri object 2
+ *
+ * Compare two librdf_uri objects for equality.
  * 
  * Return value: non 0 if the objects are equal
  **/
@@ -575,8 +608,10 @@ librdf_uri_equals(librdf_uri* first_uri, librdf_uri* second_uri)
 
 
 /**
- * librdf_uri_is_file_uri - Test if a URI points to a filename
- * @uri: &librdf_uri object
+ * librdf_uri_is_file_uri:
+ * @uri: #librdf_uri object
+ *
+ * Test if a URI points to a filename.
  * 
  * Return value: 0 if the URI points to a file
  **/
@@ -585,17 +620,19 @@ librdf_uri_is_file_uri(librdf_uri* uri)
 {
   LIBRDF_ASSERT_OBJECT_POINTER_RETURN_VALUE(uri, librdf_uri, 1);
 
-  return raptor_uri_is_file_uri(uri->string);
+  return raptor_uri_uri_string_is_file_uri(uri->string);
 }
 
 
 /**
- * librdf_uri_to_filename - Return pointer to filename of URI
- * @uri: &librdf_uri object
+ * librdf_uri_to_filename:
+ * @uri: #librdf_uri object
+ *
+ * Return pointer to filename of URI.
  * 
  * Returns a pointer to a newly allocated buffer that
  * the caller must free.  This will fail if the URI
- * is not a file: URI.  This can be checked with &librdf_uri_is_file_uri
+ * is not a file: URI.  This can be checked with #librdf_uri_is_file_uri
  *
  * Return value: pointer to filename or NULL on failure
  **/
@@ -623,7 +660,7 @@ int main(int argc, char *argv[]);
 int
 main(int argc, char *argv[]) 
 {
-  const unsigned char *hp_string=(const unsigned char*)"http://www.ilrt.bristol.ac.uk/people/cmdjb/";
+  const unsigned char *hp_string=(const unsigned char*)"http://purl.org/net/dajobe/";
   librdf_uri *uri1, *uri2, *uri3, *uri4, *uri5, *uri6, *uri7, *uri8, *uri9;
   librdf_digest *d;
   char *program=argv[0];
