@@ -2,11 +2,10 @@
  *
  * win32_rdf_config.h - redland WIN32 hard-coded config
  *
- * $Id: win32_rdf_config.h,v 1.10 2005/05/29 17:18:26 cmdjb Exp $
+ * $Id: win32_rdf_config.h 10947 2006-05-05 14:20:56Z dajobe $
  *
- * Copyright (C) 2004-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2004-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2004-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -40,8 +39,8 @@ extern "C" {
 #define HAVE_STDLIB_H 1
 
 /* For using expat on win32 */
-#define RAPTOR_XML_EXPAT 1
-#define HAVE_EXPAT_H 1
+/*#define RAPTOR_XML_EXPAT 1
+#define HAVE_EXPAT_H 1*/
 
 #define HAVE_STRICMP 1
 
@@ -75,43 +74,40 @@ extern "C" {
  */
 
 /* BDB has close method with 2 args */
-/* #undef HAVE_BDB_CLOSE_2_ARGS */
+#define HAVE_BDB_CLOSE_2_ARGS 1
 
 /* BDB defines DBC */
-/* #undef HAVE_BDB_CURSOR */
+#define HAVE_BDB_CURSOR 1
 
 /* BDB cursor method has 4 arguments */
-/* #undef HAVE_BDB_CURSOR_4_ARGS */
+#define HAVE_BDB_CURSOR_4_ARGS 1
 
 /* BDB defines DB_TXN */
-/* #undef HAVE_BDB_DB_TXN */
+#define HAVE_BDB_DB_TXN 1
 
 /* BDB has fd method with 2 args */
-/* #undef HAVE_BDB_FD_2_ARGS */
+#define HAVE_BDB_FD_2_ARGS 1
 
 /* Have BDB hash support */
-/* #undef HAVE_BDB_HASH */
+#define HAVE_BDB_HASH 1
 
 /* BDB has open method with 6 args */
 /* #undef HAVE_BDB_OPEN_6_ARGS */
 
 /* BDB has open method with 7 args */
-/* #undef HAVE_BDB_OPEN_7_ARGS */
+#define HAVE_BDB_OPEN_7_ARGS 1
 
 /* BDB has set_flags method */
-/* #undef HAVE_BDB_SET_FLAGS */
+#define HAVE_BDB_SET_FLAGS 1
 
 /* BDB has dbopen method */
 /* #undef HAVE_DBOPEN */
 
 /* BDB has db_create method */
-/* #undef HAVE_DB_CREATE */
+#define HAVE_DB_CREATE 1
 
 /* Define to 1 if you have the <db.h> header file. */
-/* #undef HAVE_DB_H */
-
-/* BDB has db_open method */
-/* #undef HAVE_DB_OPEN */
+#define HAVE_DB_H 1
 
 /* Define to 1 if you have the <dlfcn.h> header file. */
 /* undef HAVE_DLFCN_H */
@@ -165,7 +161,7 @@ extern "C" {
 #define HAVE_MKTEMP 1
 
 /* MySQL libraries are present */
-/* #undef HAVE_MYSQL */
+#define HAVE_MYSQL 1
 
 /* Define to 1 if you have the <openssl/crypto.h> header file. */
 /* #undef HAVE_OPENSSL_CRYPTO_H */
@@ -228,7 +224,7 @@ extern "C" {
 /* #undef LIBRDF_DISABLE_ASSERT_MESSAGES */
 
 /* Release version as a decimal */
-#define LIBRDF_VERSION_DECIMAL 10002
+#define LIBRDF_VERSION_DECIMAL 10004
 
 /* Major version number */
 #define LIBRDF_VERSION_MAJOR 1
@@ -237,7 +233,7 @@ extern "C" {
 #define LIBRDF_VERSION_MINOR 0
 
 /* Release version number */
-#define LIBRDF_VERSION_RELEASE 2
+#define LIBRDF_VERSION_RELEASE 4
 
 /* The size of a `unsigned char', as computed by sizeof. */
 #define SIZEOF_UNSIGNED_CHAR 1
@@ -254,14 +250,32 @@ extern "C" {
 /* The size of a `unsigned long long', as computed by sizeof. */
 #define SIZEOF_UNSIGNED_LONG_LONG 8
 
+/* SQLite API version */
+#define SQLITE_API 3
+
 /* Define to 1 if you have the ANSI C header files. */
 #define STDC_HEADERS 1
 
+/* Building file storage */
+#define STORAGE_FILE 1
+
+/* Building MySQL storage */
+#define STORAGE_MYSQL 1
+
+/* Building PostgreSQL storage */
+/*#undef STORAGE_POSTGRESQL*/
+
+/* Building SQLite storage */
+#define STORAGE_SQLITE 1
+
+/* Building 3store storage */
+/*#undef STORAGE_TSTORE*/
+
 /* Define to 1 if you can safely include both <sys/time.h> and <time.h>. */
 /* #define TIME_WITH_SYS_TIME*/
 
 /* Version number of package */
-#define VERSION "1.0.2"
+#define VERSION "1.0.4"
 
 /* Use POSIX threads */
 /* #undef WITH_THREADS */
@@ -278,6 +292,12 @@ extern "C" {
 #include <io.h>
 #include <memory.h>
 
+/* get _isnan() since it is not in math.h */
+#include <float.h>
+#ifndef isnan
+#define isnan(d) (_isnan(d))
+#endif
+
 #ifdef __cplusplus
 }
 #endif
