@@ -2,11 +2,10 @@
  *
  * rdfproc.c - Redland RDF processor
  *
- * $Id: rdfproc.c,v 1.56 2005/05/18 11:13:46 cmdjb Exp $
+ * $Id: rdfproc.c 8536 2006-01-26 05:04:45Z cmdjb $
  *
- * Copyright (C) 2000-2005, David Beckett http://purl.org/net/dajobe/
- * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
- * University of Bristol, UK http://www.bristol.ac.uk/
+ * Copyright (C) 2000-2006, David Beckett http://purl.org/net/dajobe/
+ * Copyright (C) 2000-2005, University of Bristol, UK http://www.bristol.ac.uk/
  * 
  * This package is Free Software and part of Redland http://librdf.org/
  * 
@@ -789,7 +788,7 @@ main(int argc, char *argv[])
       }
 
       if (librdf_query_results_is_bindings(results)) {
-        fprintf(stderr, "%s: Query returned bindings results:\n", program);
+        fprintf(stdout, "%s: Query returned bindings results:\n", program);
         
         while(!librdf_query_results_finished(results)) {
           fputs("result: [", stdout);
